/****************************************************************************
** Meta object code from reading C++ file 'debugcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/kdevplatform/shell/debugcontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'debugcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop15DebugControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::DebugController::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop15DebugControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::DebugController",
        "killAllDebuggersNow",
        "",
        "stopDebugger",
        "interruptDebugger",
        "run",
        "runToCursor",
        "jumpToCursor",
        "stepOver",
        "stepIntoInstruction",
        "stepInto",
        "stepOverInstruction",
        "stepOut",
        "toggleBreakpoint",
        "showCurrentLine",
        "debuggerStateChanged",
        "KDevelop::IDebugSession::DebuggerState",
        "state",
        "showStepInSource",
        "QUrl",
        "file",
        "line",
        "clearExecutionPoint",
        "textDocumentCreated",
        "KDevelop::IDocument*",
        "document",
        "areaChanged",
        "Sublime::Area*",
        "newArea"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'killAllDebuggersNow'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopDebugger'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'interruptDebugger'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'run'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'runToCursor'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'jumpToCursor'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stepOver'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stepIntoInstruction'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stepInto'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stepOverInstruction'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'stepOut'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleBreakpoint'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showCurrentLine'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'debuggerStateChanged'
        QtMocHelpers::SlotData<void(KDevelop::IDebugSession::DebuggerState)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'showStepInSource'
        QtMocHelpers::SlotData<void(const QUrl &, int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'clearExecutionPoint'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'textDocumentCreated'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 },
        }}),
        // Slot 'areaChanged'
        QtMocHelpers::SlotData<void(Sublime::Area *)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DebugController, qt_meta_tag_ZN8KDevelop15DebugControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::DebugController::staticMetaObject = { {
    QMetaObject::SuperData::link<IDebugController::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop15DebugControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop15DebugControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop15DebugControllerE_t>.metaTypes,
    nullptr
} };

void KDevelop::DebugController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DebugController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->killAllDebuggersNow(); break;
        case 1: _t->stopDebugger(); break;
        case 2: _t->interruptDebugger(); break;
        case 3: _t->run(); break;
        case 4: _t->runToCursor(); break;
        case 5: _t->jumpToCursor(); break;
        case 6: _t->stepOver(); break;
        case 7: _t->stepIntoInstruction(); break;
        case 8: _t->stepInto(); break;
        case 9: _t->stepOverInstruction(); break;
        case 10: _t->stepOut(); break;
        case 11: _t->toggleBreakpoint(); break;
        case 12: _t->showCurrentLine(); break;
        case 13: _t->debuggerStateChanged((*reinterpret_cast<std::add_pointer_t<KDevelop::IDebugSession::DebuggerState>>(_a[1]))); break;
        case 14: _t->showStepInSource((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->clearExecutionPoint(); break;
        case 16: _t->textDocumentCreated((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 17: _t->areaChanged((*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DebugController::*)()>(_a, &DebugController::killAllDebuggersNow, 0))
            return;
    }
}

const QMetaObject *KDevelop::DebugController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::DebugController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop15DebugControllerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(this);
    return IDebugController::qt_metacast(_clname);
}

int KDevelop::DebugController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IDebugController::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::DebugController::killAllDebuggersNow()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
