/********************************************************************************
** Form generated from reading UI file 'checkswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHECKSWIDGET_H
#define UI_CHECKSWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KMessageWidget"
#include "KTreeWidgetSearchLine"

namespace Clazy {

class Ui_ChecksWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *topLayout;
    QPushButton *resetButton;
    KTreeWidgetSearchLine *filterEdit;
    QSplitter *splitter;
    QTreeWidget *checksTree;
    QTextEdit *descriptionView;
    KMessageWidget *messageLabel;

    void setupUi(QWidget *Clazy__ChecksWidget)
    {
        if (Clazy__ChecksWidget->objectName().isEmpty())
            Clazy__ChecksWidget->setObjectName("Clazy__ChecksWidget");
        Clazy__ChecksWidget->resize(606, 284);
        verticalLayout = new QVBoxLayout(Clazy__ChecksWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        topLayout = new QHBoxLayout();
        topLayout->setObjectName("topLayout");
        resetButton = new QPushButton(Clazy__ChecksWidget);
        resetButton->setObjectName("resetButton");

        topLayout->addWidget(resetButton);

        filterEdit = new KTreeWidgetSearchLine(Clazy__ChecksWidget);
        filterEdit->setObjectName("filterEdit");

        topLayout->addWidget(filterEdit);


        verticalLayout->addLayout(topLayout);

        splitter = new QSplitter(Clazy__ChecksWidget);
        splitter->setObjectName("splitter");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(splitter->sizePolicy().hasHeightForWidth());
        splitter->setSizePolicy(sizePolicy);
        splitter->setOrientation(Qt::Horizontal);
        splitter->setChildrenCollapsible(false);
        checksTree = new QTreeWidget(splitter);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        checksTree->setHeaderItem(__qtreewidgetitem);
        checksTree->setObjectName("checksTree");
        splitter->addWidget(checksTree);
        checksTree->header()->setVisible(false);
        descriptionView = new QTextEdit(splitter);
        descriptionView->setObjectName("descriptionView");
        descriptionView->setReadOnly(true);
        splitter->addWidget(descriptionView);

        verticalLayout->addWidget(splitter);

        messageLabel = new KMessageWidget(Clazy__ChecksWidget);
        messageLabel->setObjectName("messageLabel");
        messageLabel->setCloseButtonVisible(false);

        verticalLayout->addWidget(messageLabel);


        retranslateUi(Clazy__ChecksWidget);

        QMetaObject::connectSlotsByName(Clazy__ChecksWidget);
    } // setupUi

    void retranslateUi(QWidget *Clazy__ChecksWidget)
    {
        resetButton->setText(tr2i18n("Reset Checks", "@action:button"));
        messageLabel->setText(tr2i18n("Since nothing is selected Clazy will use all checks from levels 0 and 1.", nullptr));
        (void)Clazy__ChecksWidget;
    } // retranslateUi

};

} // namespace Clazy

namespace Clazy {
namespace Ui {
    class ChecksWidget: public Ui_ChecksWidget {};
} // namespace Ui
} // namespace Clazy

#endif // CHECKSWIDGET_H

