/****************************************************************************
** Meta object code from reading C++ file 'midebuggerplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/debuggercommon/midebuggerplugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'midebuggerplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6KDevMI16MIDebuggerPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevMI::MIDebuggerPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN6KDevMI16MIDebuggerPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevMI::MIDebuggerPlugin",
        "clearMessage",
        "",
        "KDevelop::IStatus*",
        "showMessage",
        "message",
        "timeout",
        "hideProgress",
        "showProgress",
        "minimum",
        "maximum",
        "value",
        "showErrorMessage",
        "raiseDebuggerConsoleViews",
        "slotDebugExternalProcess",
        "DBusProxy*",
        "proxy",
        "slotExamineCore",
        "slotAttachProcess"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clearMessage'
        QtMocHelpers::SignalData<void(KDevelop::IStatus *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'showMessage'
        QtMocHelpers::SignalData<void(KDevelop::IStatus *, const QString &, int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QString, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'showMessage'
        QtMocHelpers::SignalData<void(KDevelop::IStatus *, const QString &)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'hideProgress'
        QtMocHelpers::SignalData<void(KDevelop::IStatus *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'showProgress'
        QtMocHelpers::SignalData<void(KDevelop::IStatus *, int, int, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
        // Signal 'showErrorMessage'
        QtMocHelpers::SignalData<void(const QString &, int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'raiseDebuggerConsoleViews'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDebugExternalProcess'
        QtMocHelpers::SlotData<void(DBusProxy *)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'slotExamineCore'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotAttachProcess'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MIDebuggerPlugin, qt_meta_tag_ZN6KDevMI16MIDebuggerPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevMI::MIDebuggerPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<KDevelop::IPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KDevMI16MIDebuggerPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KDevMI16MIDebuggerPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6KDevMI16MIDebuggerPluginE_t>.metaTypes,
    nullptr
} };

void KDevMI::MIDebuggerPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MIDebuggerPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clearMessage((*reinterpret_cast<std::add_pointer_t<KDevelop::IStatus*>>(_a[1]))); break;
        case 1: _t->showMessage((*reinterpret_cast<std::add_pointer_t<KDevelop::IStatus*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 2: _t->showMessage((*reinterpret_cast<std::add_pointer_t<KDevelop::IStatus*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->hideProgress((*reinterpret_cast<std::add_pointer_t<KDevelop::IStatus*>>(_a[1]))); break;
        case 4: _t->showProgress((*reinterpret_cast<std::add_pointer_t<KDevelop::IStatus*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 5: _t->showErrorMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 6: _t->raiseDebuggerConsoleViews(); break;
        case 7: _t->slotDebugExternalProcess((*reinterpret_cast<std::add_pointer_t<DBusProxy*>>(_a[1]))); break;
        case 8: _t->slotExamineCore(); break;
        case 9: _t->slotAttachProcess(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IStatus* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IStatus* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IStatus* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IStatus* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IStatus* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MIDebuggerPlugin::*)(KDevelop::IStatus * )>(_a, &MIDebuggerPlugin::clearMessage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebuggerPlugin::*)(KDevelop::IStatus * , const QString & , int )>(_a, &MIDebuggerPlugin::showMessage, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebuggerPlugin::*)(KDevelop::IStatus * )>(_a, &MIDebuggerPlugin::hideProgress, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebuggerPlugin::*)(KDevelop::IStatus * , int , int , int )>(_a, &MIDebuggerPlugin::showProgress, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebuggerPlugin::*)(const QString & , int )>(_a, &MIDebuggerPlugin::showErrorMessage, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebuggerPlugin::*)()>(_a, &MIDebuggerPlugin::raiseDebuggerConsoleViews, 6))
            return;
    }
}

const QMetaObject *KDevMI::MIDebuggerPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevMI::MIDebuggerPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KDevMI16MIDebuggerPluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KDevelop::IStatus"))
        return static_cast< KDevelop::IStatus*>(this);
    if (!strcmp(_clname, "org.kdevelop.IStatus"))
        return static_cast< KDevelop::IStatus*>(this);
    return KDevelop::IPlugin::qt_metacast(_clname);
}

int KDevMI::MIDebuggerPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDevelop::IPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KDevMI::MIDebuggerPlugin::clearMessage(KDevelop::IStatus * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDevMI::MIDebuggerPlugin::showMessage(KDevelop::IStatus * _t1, const QString & _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void KDevMI::MIDebuggerPlugin::hideProgress(KDevelop::IStatus * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KDevMI::MIDebuggerPlugin::showProgress(KDevelop::IStatus * _t1, int _t2, int _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 5
void KDevMI::MIDebuggerPlugin::showErrorMessage(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KDevMI::MIDebuggerPlugin::raiseDebuggerConsoleViews()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
