/****************************************************************************
** Meta object code from reading C++ file 'breakpointwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/kdevplatform/debugger/breakpoint/breakpointwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'breakpointwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop16BreakpointWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::BreakpointWidget::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop16BreakpointWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::BreakpointWidget",
        "slotAddBlankBreakpoint",
        "",
        "slotAddBlankWatchpoint",
        "slotAddBlankReadWatchpoint",
        "slotAddBlankAccessWatchpoint",
        "slotRemoveBreakpoint",
        "slotUpdateBreakpointDetail",
        "slotDataInserted",
        "column",
        "QVariant",
        "value",
        "slotOpenFile",
        "QModelIndex",
        "breakpointIdx",
        "breakpointHit",
        "row",
        "slotDisableAllBreakpoints",
        "slotEnableAllBreakpoints",
        "slotRemoveAllBreakpoints",
        "slotPopupMenuAboutToShow"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotAddBlankBreakpoint'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddBlankWatchpoint'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddBlankReadWatchpoint'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddBlankAccessWatchpoint'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveBreakpoint'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateBreakpointDetail'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDataInserted'
        QtMocHelpers::SlotData<void(int, const QVariant &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'slotOpenFile'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'breakpointHit'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'slotDisableAllBreakpoints'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEnableAllBreakpoints'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveAllBreakpoints'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPopupMenuAboutToShow'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BreakpointWidget, qt_meta_tag_ZN8KDevelop16BreakpointWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::BreakpointWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<AutoOrientedSplitter::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop16BreakpointWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop16BreakpointWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop16BreakpointWidgetE_t>.metaTypes,
    nullptr
} };

void KDevelop::BreakpointWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BreakpointWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotAddBlankBreakpoint(); break;
        case 1: _t->slotAddBlankWatchpoint(); break;
        case 2: _t->slotAddBlankReadWatchpoint(); break;
        case 3: _t->slotAddBlankAccessWatchpoint(); break;
        case 4: _t->slotRemoveBreakpoint(); break;
        case 5: _t->slotUpdateBreakpointDetail(); break;
        case 6: _t->slotDataInserted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 7: _t->slotOpenFile((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 8: _t->breakpointHit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->slotDisableAllBreakpoints(); break;
        case 10: _t->slotEnableAllBreakpoints(); break;
        case 11: _t->slotRemoveAllBreakpoints(); break;
        case 12: _t->slotPopupMenuAboutToShow(); break;
        default: ;
        }
    }
}

const QMetaObject *KDevelop::BreakpointWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::BreakpointWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop16BreakpointWidgetE_t>.strings))
        return static_cast<void*>(this);
    return AutoOrientedSplitter::qt_metacast(_clname);
}

int KDevelop::BreakpointWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AutoOrientedSplitter::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}
QT_WARNING_POP
