// This file is generated by kconfig_compiler_kf6 from androidpreferencessettings.kcfg.
// All changes you do to this file will be lost.
#ifndef ANDROIDPREFERENCESSETTINGS_H
#define ANDROIDPREFERENCESSETTINGS_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class AndroidPreferencesSettings : public KConfigSkeleton
{
  public:

    AndroidPreferencesSettings( );
    ~AndroidPreferencesSettings() override;

    /**
      Get cmakeToolchain
    */
    QString cmakeToolchain() const
    {
      return mCmakeToolchain;
    }

    /**
      Is cmakeToolchain Immutable
    */
    bool isCmakeToolchainImmutable() const
    {
      return isImmutable( QStringLiteral( "cmakeToolchain" ) );
    }

    /**
      Get ndk
    */
    QString ndk() const
    {
      return mNdk;
    }

    /**
      Is ndk Immutable
    */
    bool isNdkImmutable() const
    {
      return isImmutable( QStringLiteral( "ndk" ) );
    }

    /**
      Get sdk
    */
    QString sdk() const
    {
      return mSdk;
    }

    /**
      Is sdk Immutable
    */
    bool isSdkImmutable() const
    {
      return isImmutable( QStringLiteral( "sdk" ) );
    }

    /**
      Get arch
    */
    QString arch() const
    {
      return mArch;
    }

    /**
      Is arch Immutable
    */
    bool isArchImmutable() const
    {
      return isImmutable( QStringLiteral( "arch" ) );
    }

    /**
      Get toolchain
    */
    QString toolchain() const
    {
      return mToolchain;
    }

    /**
      Is toolchain Immutable
    */
    bool isToolchainImmutable() const
    {
      return isImmutable( QStringLiteral( "toolchain" ) );
    }

    /**
      Get abi
    */
    QString abi() const
    {
      return mAbi;
    }

    /**
      Is abi Immutable
    */
    bool isAbiImmutable() const
    {
      return isImmutable( QStringLiteral( "abi" ) );
    }

    /**
      Get gcc
    */
    QString gcc() const
    {
      return mGcc;
    }

    /**
      Is gcc Immutable
    */
    bool isGccImmutable() const
    {
      return isImmutable( QStringLiteral( "gcc" ) );
    }

    /**
      Get api
    */
    QString api() const
    {
      return mApi;
    }

    /**
      Is api Immutable
    */
    bool isApiImmutable() const
    {
      return isImmutable( QStringLiteral( "api" ) );
    }

    /**
      Get buildtools
    */
    QString buildtools() const
    {
      return mBuildtools;
    }

    /**
      Is buildtools Immutable
    */
    bool isBuildtoolsImmutable() const
    {
      return isImmutable( QStringLiteral( "buildtools" ) );
    }

  protected:

    // Android
    QString mCmakeToolchain;
    QString mNdk;
    QString mSdk;
    QString mArch;
    QString mToolchain;
    QString mAbi;
    QString mGcc;
    QString mApi;
    QString mBuildtools;
};

#endif

