/********************************************************************************
** Form generated from reading UI file 'welcomepageview.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WELCOMEPAGEVIEW_H
#define UI_WELCOMEPAGEVIEW_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktitlewidget.h"
#include "kurllabel.h"

QT_BEGIN_NAMESPACE

class Ui_WelcomePageView
{
public:
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *toolsLayout;
    QHBoxLayout *hboxLayout;
    QLabel *appIconLabel;
    QLabel *appNameLabel;
    QSpacerItem *verticalSpacer;
    QVBoxLayout *verticalLayout_2;
    KTitleWidget *helpSectionTitle;
    QVBoxLayout *verticalLayout;
    KUrlLabel *homepageLinkLabel;
    KUrlLabel *learnAboutLinkLabel;
    KUrlLabel *joinTeamLinkLabel;
    KUrlLabel *handbookLinkLabel;
    QFrame *pageFrame;
    QVBoxLayout *verticalLayout_5;
    QHBoxLayout *buttonLayout;
    QPushButton *newProjectButton;
    QPushButton *openProjectButton;
    QPushButton *fetchProjectButton;
    QPushButton *recentProjectsButton;
    QSpacerItem *horizontalSpacer;
    QStackedWidget *sessionsOrWelcomeWidget;
    QWidget *page;
    QVBoxLayout *verticalLayout_3;
    KTitleWidget *titleWidget;
    QListView *sessionsListView;
    QWidget *page_2;
    QVBoxLayout *verticalLayout_4;
    QLabel *welcomeText;

    void setupUi(QWidget *WelcomePageView)
    {
        if (WelcomePageView->objectName().isEmpty())
            WelcomePageView->setObjectName("WelcomePageView");
        WelcomePageView->resize(698, 509);
        horizontalLayout = new QHBoxLayout(WelcomePageView);
        horizontalLayout->setSpacing(20);
        horizontalLayout->setObjectName("horizontalLayout");
        toolsLayout = new QVBoxLayout();
        toolsLayout->setObjectName("toolsLayout");
        toolsLayout->setContentsMargins(15, 15, 15, 15);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setSpacing(5);
        hboxLayout->setObjectName("hboxLayout");
        appIconLabel = new QLabel(WelcomePageView);
        appIconLabel->setObjectName("appIconLabel");

        hboxLayout->addWidget(appIconLabel);

        appNameLabel = new QLabel(WelcomePageView);
        appNameLabel->setObjectName("appNameLabel");
        QFont font;
        font.setPointSize(20);
        appNameLabel->setFont(font);

        hboxLayout->addWidget(appNameLabel);

        hboxLayout->setStretch(1, 1);

        toolsLayout->addLayout(hboxLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        toolsLayout->addItem(verticalSpacer);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setSpacing(10);
        verticalLayout_2->setObjectName("verticalLayout_2");
        helpSectionTitle = new KTitleWidget(WelcomePageView);
        helpSectionTitle->setObjectName("helpSectionTitle");

        verticalLayout_2->addWidget(helpSectionTitle);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(10);
        verticalLayout->setObjectName("verticalLayout");
        homepageLinkLabel = new KUrlLabel(WelcomePageView);
        homepageLinkLabel->setObjectName("homepageLinkLabel");
        homepageLinkLabel->setGlowEnabled(false);

        verticalLayout->addWidget(homepageLinkLabel);

        learnAboutLinkLabel = new KUrlLabel(WelcomePageView);
        learnAboutLinkLabel->setObjectName("learnAboutLinkLabel");
        learnAboutLinkLabel->setGlowEnabled(false);

        verticalLayout->addWidget(learnAboutLinkLabel);

        joinTeamLinkLabel = new KUrlLabel(WelcomePageView);
        joinTeamLinkLabel->setObjectName("joinTeamLinkLabel");
        joinTeamLinkLabel->setGlowEnabled(false);

        verticalLayout->addWidget(joinTeamLinkLabel);

        handbookLinkLabel = new KUrlLabel(WelcomePageView);
        handbookLinkLabel->setObjectName("handbookLinkLabel");
        handbookLinkLabel->setGlowEnabled(false);

        verticalLayout->addWidget(handbookLinkLabel);


        verticalLayout_2->addLayout(verticalLayout);


        toolsLayout->addLayout(verticalLayout_2);


        horizontalLayout->addLayout(toolsLayout);

        pageFrame = new QFrame(WelcomePageView);
        pageFrame->setObjectName("pageFrame");
        pageFrame->setAutoFillBackground(true);
        pageFrame->setFrameShape(QFrame::StyledPanel);
        verticalLayout_5 = new QVBoxLayout(pageFrame);
        verticalLayout_5->setSpacing(20);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(15, 15, 15, 15);
        buttonLayout = new QHBoxLayout();
        buttonLayout->setSpacing(6);
        buttonLayout->setObjectName("buttonLayout");
        newProjectButton = new QPushButton(pageFrame);
        newProjectButton->setObjectName("newProjectButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("project-development-new-template")));
        newProjectButton->setIcon(icon);

        buttonLayout->addWidget(newProjectButton);

        openProjectButton = new QPushButton(pageFrame);
        openProjectButton->setObjectName("openProjectButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("project-open")));
        openProjectButton->setIcon(icon1);

        buttonLayout->addWidget(openProjectButton);

        fetchProjectButton = new QPushButton(pageFrame);
        fetchProjectButton->setObjectName("fetchProjectButton");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("edit-download")));
        fetchProjectButton->setIcon(icon2);

        buttonLayout->addWidget(fetchProjectButton);

        recentProjectsButton = new QPushButton(pageFrame);
        recentProjectsButton->setObjectName("recentProjectsButton");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("document-open-recent")));
        recentProjectsButton->setIcon(icon3);

        buttonLayout->addWidget(recentProjectsButton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        buttonLayout->addItem(horizontalSpacer);


        verticalLayout_5->addLayout(buttonLayout);

        sessionsOrWelcomeWidget = new QStackedWidget(pageFrame);
        sessionsOrWelcomeWidget->setObjectName("sessionsOrWelcomeWidget");
        page = new QWidget();
        page->setObjectName("page");
        verticalLayout_3 = new QVBoxLayout(page);
        verticalLayout_3->setSpacing(10);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        titleWidget = new KTitleWidget(page);
        titleWidget->setObjectName("titleWidget");

        verticalLayout_3->addWidget(titleWidget);

        sessionsListView = new QListView(page);
        sessionsListView->setObjectName("sessionsListView");
        sessionsListView->setMouseTracking(true);
        sessionsListView->setFrameShape(QFrame::NoFrame);
        sessionsListView->setSelectionMode(QAbstractItemView::SingleSelection);
        sessionsListView->setSelectionBehavior(QAbstractItemView::SelectRows);
        sessionsListView->setUniformItemSizes(true);

        verticalLayout_3->addWidget(sessionsListView);

        sessionsOrWelcomeWidget->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        verticalLayout_4 = new QVBoxLayout(page_2);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        welcomeText = new QLabel(page_2);
        welcomeText->setObjectName("welcomeText");
        welcomeText->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        welcomeText->setWordWrap(true);

        verticalLayout_4->addWidget(welcomeText);

        sessionsOrWelcomeWidget->addWidget(page_2);

        verticalLayout_5->addWidget(sessionsOrWelcomeWidget);


        horizontalLayout->addWidget(pageFrame);

        horizontalLayout->setStretch(1, 1);

        retranslateUi(WelcomePageView);

        sessionsOrWelcomeWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(WelcomePageView);
    } // setupUi

    void retranslateUi(QWidget *WelcomePageView)
    {
        appIconLabel->setText(QString());
        appNameLabel->setText(tr2i18n("KDevelop", nullptr));
        helpSectionTitle->setText(tr2i18n("Need Help?", nullptr));
        homepageLinkLabel->setText(tr2i18n("KDevelop.org", nullptr));
        learnAboutLinkLabel->setText(tr2i18n("Learn about KDevelop", nullptr));
        joinTeamLinkLabel->setText(tr2i18n("Join KDevelop's team!", nullptr));
        handbookLinkLabel->setText(tr2i18n("Handbook", nullptr));
        newProjectButton->setText(tr2i18n("New Project", nullptr));
        openProjectButton->setText(tr2i18n("Open Project", nullptr));
        fetchProjectButton->setText(tr2i18n("Fetch Project", nullptr));
        recentProjectsButton->setText(tr2i18n("Recent Projects", nullptr));
        titleWidget->setText(tr2i18n("Sessions", nullptr));
        welcomeText->setText(tr2i18n("<h3>Welcome to KDevelop!</h3>\n"
"<p>You can start working on a project by opening an existing or creating a new one via the above buttons.</p>\n"
"<p>If you need help, please check out the <a href=\"https://userbase.kde.org/KDevelop\">User Manual.</a></p>", nullptr));
        (void)WelcomePageView;
    } // retranslateUi

};

namespace Ui {
    class WelcomePageView: public Ui_WelcomePageView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WELCOMEPAGEVIEW_H

