/****************************************************************************
** Meta object code from reading C++ file 'patchreviewtoolview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/patchreview/patchreviewtoolview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'patchreviewtoolview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19PatchReviewToolViewE_t {};
} // unnamed namespace

template <> constexpr inline auto PatchReviewToolView::qt_create_metaobjectdata<qt_meta_tag_ZN19PatchReviewToolViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PatchReviewToolView",
        "dialogClosed",
        "",
        "PatchReviewToolView*",
        "stateChanged",
        "startingNewReview",
        "fileDoubleClicked",
        "QModelIndex",
        "i",
        "nextHunk",
        "prevHunk",
        "prevFile",
        "nextFile",
        "seekFile",
        "forwards",
        "patchChanged",
        "slotAppliedChanged",
        "newState",
        "finishReview",
        "runTests",
        "selectAll",
        "deselectAll",
        "fileItemChanged",
        "QStandardItem*",
        "item",
        "documentActivated",
        "KDevelop::IDocument*",
        "customContextMenuRequested",
        "QPoint",
        "p",
        "testJobResult",
        "KJob*",
        "job",
        "testJobPercent",
        "percent"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dialogClosed'
        QtMocHelpers::SignalData<void(PatchReviewToolView *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(PatchReviewToolView *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'startingNewReview'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fileDoubleClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'nextHunk'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'prevHunk'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'prevFile'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'nextFile'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'seekFile'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'patchChanged'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAppliedChanged'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'finishReview'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'runTests'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deselectAll'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fileItemChanged'
        QtMocHelpers::SlotData<void(QStandardItem *)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'documentActivated'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 2 },
        }}),
        // Slot 'customContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Slot 'testJobResult'
        QtMocHelpers::SlotData<void(KJob *)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
        // Slot 'testJobPercent'
        QtMocHelpers::SlotData<void(KJob *, unsigned long)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 31, 32 }, { QMetaType::ULong, 34 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PatchReviewToolView, qt_meta_tag_ZN19PatchReviewToolViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PatchReviewToolView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PatchReviewToolViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PatchReviewToolViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19PatchReviewToolViewE_t>.metaTypes,
    nullptr
} };

void PatchReviewToolView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PatchReviewToolView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dialogClosed((*reinterpret_cast<std::add_pointer_t<PatchReviewToolView*>>(_a[1]))); break;
        case 1: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<PatchReviewToolView*>>(_a[1]))); break;
        case 2: _t->startingNewReview(); break;
        case 3: _t->fileDoubleClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 4: _t->nextHunk(); break;
        case 5: _t->prevHunk(); break;
        case 6: _t->prevFile(); break;
        case 7: _t->nextFile(); break;
        case 8: _t->seekFile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->patchChanged(); break;
        case 10: _t->slotAppliedChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->finishReview(); break;
        case 12: _t->runTests(); break;
        case 13: _t->selectAll(); break;
        case 14: _t->deselectAll(); break;
        case 15: _t->fileItemChanged((*reinterpret_cast<std::add_pointer_t<QStandardItem*>>(_a[1]))); break;
        case 16: _t->documentActivated((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 17: _t->customContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 18: _t->testJobResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 19: _t->testJobPercent((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PatchReviewToolView* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PatchReviewToolView* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PatchReviewToolView::*)(PatchReviewToolView * )>(_a, &PatchReviewToolView::dialogClosed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PatchReviewToolView::*)(PatchReviewToolView * )>(_a, &PatchReviewToolView::stateChanged, 1))
            return;
    }
}

const QMetaObject *PatchReviewToolView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PatchReviewToolView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PatchReviewToolViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int PatchReviewToolView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}

// SIGNAL 0
void PatchReviewToolView::dialogClosed(PatchReviewToolView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PatchReviewToolView::stateChanged(PatchReviewToolView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
