/********************************************************************************
** Form generated from reading UI file 'mesonnewbuilddir.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MESONNEWBUILDDIR_H
#define UI_MESONNEWBUILDDIR_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "KUrlRequester"
#include "settings/mesonadvancedsettings.h"
#include "settings/mesonoptionsview.h"

QT_BEGIN_NAMESPACE

class Ui_MesonNewBuildDir
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *hl_buildDir;
    QLabel *l_buildDir;
    KUrlRequester *i_buildDir;
    MesonOptionsView *options;
    MesonAdvancedSettings *advanced;
    QHBoxLayout *hl_bottomBar;
    QLabel *l_statusMessage;
    QDialogButtonBox *b_buttonBox;

    void setupUi(QDialog *MesonNewBuildDir)
    {
        if (MesonNewBuildDir->objectName().isEmpty())
            MesonNewBuildDir->setObjectName("MesonNewBuildDir");
        MesonNewBuildDir->resize(670, 700);
        verticalLayout = new QVBoxLayout(MesonNewBuildDir);
        verticalLayout->setObjectName("verticalLayout");
        hl_buildDir = new QHBoxLayout();
        hl_buildDir->setObjectName("hl_buildDir");
        l_buildDir = new QLabel(MesonNewBuildDir);
        l_buildDir->setObjectName("l_buildDir");
        l_buildDir->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        hl_buildDir->addWidget(l_buildDir);

        i_buildDir = new KUrlRequester(MesonNewBuildDir);
        i_buildDir->setObjectName("i_buildDir");
        i_buildDir->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);

        hl_buildDir->addWidget(i_buildDir);


        verticalLayout->addLayout(hl_buildDir);

        options = new MesonOptionsView(MesonNewBuildDir);
        options->setObjectName("options");

        verticalLayout->addWidget(options);

        advanced = new MesonAdvancedSettings(MesonNewBuildDir);
        advanced->setObjectName("advanced");

        verticalLayout->addWidget(advanced);

        hl_bottomBar = new QHBoxLayout();
        hl_bottomBar->setObjectName("hl_bottomBar");
        l_statusMessage = new QLabel(MesonNewBuildDir);
        l_statusMessage->setObjectName("l_statusMessage");

        hl_bottomBar->addWidget(l_statusMessage);

        b_buttonBox = new QDialogButtonBox(MesonNewBuildDir);
        b_buttonBox->setObjectName("b_buttonBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(b_buttonBox->sizePolicy().hasHeightForWidth());
        b_buttonBox->setSizePolicy(sizePolicy);
        b_buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok|QDialogButtonBox::Reset);

        hl_bottomBar->addWidget(b_buttonBox);


        verticalLayout->addLayout(hl_bottomBar);


        retranslateUi(MesonNewBuildDir);
        QObject::connect(b_buttonBox, &QDialogButtonBox::accepted, MesonNewBuildDir, qOverload<>(&QDialog::accept));
        QObject::connect(b_buttonBox, &QDialogButtonBox::rejected, MesonNewBuildDir, qOverload<>(&QDialog::reject));
        QObject::connect(advanced, SIGNAL(configChanged()), MesonNewBuildDir, SLOT(updated()));
        QObject::connect(options, SIGNAL(configChanged()), MesonNewBuildDir, SLOT(updated()));
        QObject::connect(i_buildDir, SIGNAL(textChanged(QString)), MesonNewBuildDir, SLOT(updated()));

        QMetaObject::connectSlotsByName(MesonNewBuildDir);
    } // setupUi

    void retranslateUi(QDialog *MesonNewBuildDir)
    {
        l_buildDir->setText(tr2i18n("Build directory:", nullptr));
        i_buildDir->setPlaceholderText(tr2i18n("Full Path to the new build directory", nullptr));
        l_statusMessage->setText(tr2i18n("Status message...", nullptr));
        (void)MesonNewBuildDir;
    } // retranslateUi

};

namespace Ui {
    class MesonNewBuildDir: public Ui_MesonNewBuildDir {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MESONNEWBUILDDIR_H

