/********************************************************************************
** Form generated from reading UI file 'mesonlisteditor.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MESONLISTEDITOR_H
#define UI_MESONLISTEDITOR_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MesonListEditor
{
public:
    QHBoxLayout *horizontalLayout;
    QListWidget *array;
    QVBoxLayout *verticalLayout;
    QPushButton *b_new;
    QPushButton *b_del;
    QFrame *line;
    QPushButton *b_first;
    QPushButton *b_up;
    QPushButton *b_down;
    QPushButton *b_last;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *MesonListEditor)
    {
        if (MesonListEditor->objectName().isEmpty())
            MesonListEditor->setObjectName("MesonListEditor");
        MesonListEditor->resize(400, 450);
        horizontalLayout = new QHBoxLayout(MesonListEditor);
        horizontalLayout->setObjectName("horizontalLayout");
        array = new QListWidget(MesonListEditor);
        array->setObjectName("array");
        array->setFrameShadow(QFrame::Sunken);
        array->setAlternatingRowColors(true);
        array->setUniformItemSizes(true);
        array->setSelectionRectVisible(true);

        horizontalLayout->addWidget(array);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        b_new = new QPushButton(MesonListEditor);
        b_new->setObjectName("b_new");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        b_new->setIcon(icon);

        verticalLayout->addWidget(b_new);

        b_del = new QPushButton(MesonListEditor);
        b_del->setObjectName("b_del");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        b_del->setIcon(icon1);

        verticalLayout->addWidget(b_del);

        line = new QFrame(MesonListEditor);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        b_first = new QPushButton(MesonListEditor);
        b_first->setObjectName("b_first");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("arrow-up-double")));
        b_first->setIcon(icon2);

        verticalLayout->addWidget(b_first);

        b_up = new QPushButton(MesonListEditor);
        b_up->setObjectName("b_up");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("arrow-up")));
        b_up->setIcon(icon3);

        verticalLayout->addWidget(b_up);

        b_down = new QPushButton(MesonListEditor);
        b_down->setObjectName("b_down");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("arrow-down")));
        b_down->setIcon(icon4);

        verticalLayout->addWidget(b_down);

        b_last = new QPushButton(MesonListEditor);
        b_last->setObjectName("b_last");
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("arrow-down-double")));
        b_last->setIcon(icon5);

        verticalLayout->addWidget(b_last);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(MesonListEditor);
        buttonBox->setObjectName("buttonBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(buttonBox->sizePolicy().hasHeightForWidth());
        buttonBox->setSizePolicy(sizePolicy);
        buttonBox->setOrientation(Qt::Vertical);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);
        buttonBox->setCenterButtons(false);

        verticalLayout->addWidget(buttonBox);


        horizontalLayout->addLayout(verticalLayout);


        retranslateUi(MesonListEditor);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, MesonListEditor, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, MesonListEditor, qOverload<>(&QDialog::reject));
        QObject::connect(b_new, SIGNAL(clicked()), MesonListEditor, SLOT(add()));
        QObject::connect(b_del, SIGNAL(clicked()), MesonListEditor, SLOT(remove()));
        QObject::connect(b_up, SIGNAL(clicked()), MesonListEditor, SLOT(up()));
        QObject::connect(b_down, SIGNAL(clicked()), MesonListEditor, SLOT(down()));
        QObject::connect(array, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)), MesonListEditor, SLOT(currentItemChanged()));
        QObject::connect(b_first, SIGNAL(clicked()), MesonListEditor, SLOT(first()));
        QObject::connect(b_last, SIGNAL(clicked()), MesonListEditor, SLOT(last()));

        QMetaObject::connectSlotsByName(MesonListEditor);
    } // setupUi

    void retranslateUi(QDialog *MesonListEditor)
    {
        MesonListEditor->setWindowTitle(tr2i18n("Dialog", nullptr));
        b_new->setText(tr2i18n("New", nullptr));
        b_del->setText(tr2i18n("Delete", nullptr));
        b_first->setText(tr2i18n("First", nullptr));
        b_up->setText(tr2i18n("Up", nullptr));
        b_down->setText(tr2i18n("Down", nullptr));
        b_last->setText(tr2i18n("Last", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MesonListEditor: public Ui_MesonListEditor {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MESONLISTEDITOR_H

