/********************************************************************************
** Form generated from reading UI file 'cmakebuilddirchooser.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CMAKEBUILDDIRCHOOSER_H
#define UI_CMAKEBUILDDIRCHOOSER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"
#include "KMessageWidget"
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_CMakeBuildDirChooser
{
public:
    QFormLayout *formLayout;
    QLabel *availableLabel;
    QComboBox *availableBuildDirs;
    QLabel *label_3;
    KUrlRequester *buildFolder;
    KMessageWidget *status;
    QLabel *label;
    KUrlRequester *installPrefix;
    QLabel *label_2;
    QComboBox *buildType;
    QLabel *label_4;
    KComboBox *extraArguments;
    QLabel *label_5;
    KUrlRequester *cmakeExecutable;
    QCheckBox *autoConfigureOnCMakeListsChanges;

    void setupUi(QWidget *CMakeBuildDirChooser)
    {
        if (CMakeBuildDirChooser->objectName().isEmpty())
            CMakeBuildDirChooser->setObjectName("CMakeBuildDirChooser");
        CMakeBuildDirChooser->resize(611, 280);
        formLayout = new QFormLayout(CMakeBuildDirChooser);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        formLayout->setContentsMargins(0, 0, 0, 0);
        availableLabel = new QLabel(CMakeBuildDirChooser);
        availableLabel->setObjectName("availableLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, availableLabel);

        availableBuildDirs = new QComboBox(CMakeBuildDirChooser);
        availableBuildDirs->addItem(QString());
        availableBuildDirs->setObjectName("availableBuildDirs");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, availableBuildDirs);

        label_3 = new QLabel(CMakeBuildDirChooser);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        buildFolder = new KUrlRequester(CMakeBuildDirChooser);
        buildFolder->setObjectName("buildFolder");
        buildFolder->setMinimumSize(QSize(500, 0));

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, buildFolder);

        status = new KMessageWidget(CMakeBuildDirChooser);
        status->setObjectName("status");
        status->setCloseButtonVisible(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(status->sizePolicy().hasHeightForWidth());
        status->setSizePolicy(sizePolicy);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, status);

        label = new QLabel(CMakeBuildDirChooser);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label);

        installPrefix = new KUrlRequester(CMakeBuildDirChooser);
        installPrefix->setObjectName("installPrefix");
        sizePolicy.setHeightForWidth(installPrefix->sizePolicy().hasHeightForWidth());
        installPrefix->setSizePolicy(sizePolicy);
        installPrefix->setMinimumSize(QSize(500, 0));

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, installPrefix);

        label_2 = new QLabel(CMakeBuildDirChooser);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_2);

        buildType = new QComboBox(CMakeBuildDirChooser);
        buildType->addItem(QString::fromUtf8("Debug"));
        buildType->addItem(QString::fromUtf8("Release"));
        buildType->addItem(QString::fromUtf8("RelWithDebInfo"));
        buildType->addItem(QString::fromUtf8("MinSizeRel"));
        buildType->setObjectName("buildType");
        buildType->setEditable(true);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, buildType);

        label_4 = new QLabel(CMakeBuildDirChooser);
        label_4->setObjectName("label_4");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_4);

        extraArguments = new KComboBox(CMakeBuildDirChooser);
        extraArguments->setObjectName("extraArguments");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(extraArguments->sizePolicy().hasHeightForWidth());
        extraArguments->setSizePolicy(sizePolicy1);
        extraArguments->setEditable(true);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, extraArguments);

        label_5 = new QLabel(CMakeBuildDirChooser);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_5);

        cmakeExecutable = new KUrlRequester(CMakeBuildDirChooser);
        cmakeExecutable->setObjectName("cmakeExecutable");
        sizePolicy.setHeightForWidth(cmakeExecutable->sizePolicy().hasHeightForWidth());
        cmakeExecutable->setSizePolicy(sizePolicy);

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, cmakeExecutable);

        autoConfigureOnCMakeListsChanges = new QCheckBox(CMakeBuildDirChooser);
        autoConfigureOnCMakeListsChanges->setObjectName("autoConfigureOnCMakeListsChanges");
        autoConfigureOnCMakeListsChanges->setChecked(true);

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, autoConfigureOnCMakeListsChanges);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(buildFolder);
        label->setBuddy(installPrefix);
        label_2->setBuddy(buildType);
        label_5->setBuddy(cmakeExecutable);
#endif // QT_CONFIG(shortcut)

        retranslateUi(CMakeBuildDirChooser);

        buildType->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(CMakeBuildDirChooser);
    } // setupUi

    void retranslateUi(QWidget *CMakeBuildDirChooser)
    {
        availableLabel->setText(tr2i18n("Available build directories:", "@label:listbox"));
        availableBuildDirs->setItemText(0, tr2i18n("New build directory", "@item:inlistbox"));

        label_3->setText(tr2i18n("Build &directory:", "@label:chooser"));
        label->setText(tr2i18n("&Installation prefix:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        installPrefix->setToolTip(tr2i18n("The prefix under which the project will be installed. Leaving this empty will let CMake use its default install prefix.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        installPrefix->setPlaceholderText(tr2i18n("CMake's default install prefix", "@info:placeholder"));
        label_2->setText(tr2i18n("Build &type:", "@label:listbox"));

        label_4->setText(tr2i18n("Extra arguments:", "@label:listbox"));
        label_5->setText(tr2i18n("CMake &executable:", "@label:chooser"));
        autoConfigureOnCMakeListsChanges->setText(tr2i18n("Automatically reconfigure when CMake project files change", "@option:check"));
        (void)CMakeBuildDirChooser;
    } // retranslateUi

};

namespace Ui {
    class CMakeBuildDirChooser: public Ui_CMakeBuildDirChooser {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CMAKEBUILDDIRCHOOSER_H

