// This file is generated by kconfig_compiler_kf6 from uiconfig.kcfg.
// All changes you do to this file will be lost.
#ifndef UICONFIG_H
#define UICONFIG_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class UiConfig : public KConfigSkeleton
{
  public:

    static UiConfig *self();
    ~UiConfig() override;

    /**
      Get BottomLeftCornerOwner
    */
    static
    int bottomLeftCornerOwner()
    {
      return self()->mBottomLeftCornerOwner;
    }

    /**
      Is BottomLeftCornerOwner Immutable
    */
    static
    bool isBottomLeftCornerOwnerImmutable()
    {
      return self()->isImmutable( QStringLiteral( "BottomLeftCornerOwner" ) );
    }

    /**
      Get Item object corresponding to BottomLeftCornerOwner()
    */
    ItemInt *bottomLeftCornerOwnerItem()
    {
      return mBottomLeftCornerOwnerItem;
    }

    /**
      Get BottomRightCornerOwner
    */
    static
    int bottomRightCornerOwner()
    {
      return self()->mBottomRightCornerOwner;
    }

    /**
      Is BottomRightCornerOwner Immutable
    */
    static
    bool isBottomRightCornerOwnerImmutable()
    {
      return self()->isImmutable( QStringLiteral( "BottomRightCornerOwner" ) );
    }

    /**
      Get Item object corresponding to BottomRightCornerOwner()
    */
    ItemInt *bottomRightCornerOwnerItem()
    {
      return mBottomRightCornerOwnerItem;
    }

    /**
      Get TabBarVisibility
    */
    static
    int tabBarVisibility()
    {
      return self()->mTabBarVisibility;
    }

    /**
      Is TabBarVisibility Immutable
    */
    static
    bool isTabBarVisibilityImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TabBarVisibility" ) );
    }

    /**
      Get Item object corresponding to TabBarVisibility()
    */
    ItemInt *tabBarVisibilityItem()
    {
      return mTabBarVisibilityItem;
    }

    /**
      Get CloseButtonsOnTabs
    */
    static
    int closeButtonsOnTabs()
    {
      return self()->mCloseButtonsOnTabs;
    }

    /**
      Is CloseButtonsOnTabs Immutable
    */
    static
    bool isCloseButtonsOnTabsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "CloseButtonsOnTabs" ) );
    }

    /**
      Get Item object corresponding to CloseButtonsOnTabs()
    */
    ItemInt *closeButtonsOnTabsItem()
    {
      return mCloseButtonsOnTabsItem;
    }

    /**
      Get TabBarOpenAfterCurrent
    */
    static
    int tabBarOpenAfterCurrent()
    {
      return self()->mTabBarOpenAfterCurrent;
    }

    /**
      Is TabBarOpenAfterCurrent Immutable
    */
    static
    bool isTabBarOpenAfterCurrentImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TabBarOpenAfterCurrent" ) );
    }

    /**
      Get Item object corresponding to TabBarOpenAfterCurrent()
    */
    ItemInt *tabBarOpenAfterCurrentItem()
    {
      return mTabBarOpenAfterCurrentItem;
    }

    /**
      Get TabBarArrangeBuddies
    */
    static
    int tabBarArrangeBuddies()
    {
      return self()->mTabBarArrangeBuddies;
    }

    /**
      Is TabBarArrangeBuddies Immutable
    */
    static
    bool isTabBarArrangeBuddiesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "TabBarArrangeBuddies" ) );
    }

    /**
      Get Item object corresponding to TabBarArrangeBuddies()
    */
    ItemInt *tabBarArrangeBuddiesItem()
    {
      return mTabBarArrangeBuddiesItem;
    }

    /**
      Get ColorizeByProject
    */
    static
    bool colorizeByProject()
    {
      return self()->mColorizeByProject;
    }

    /**
      Is ColorizeByProject Immutable
    */
    static
    bool isColorizeByProjectImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ColorizeByProject" ) );
    }

    /**
      Get Item object corresponding to ColorizeByProject()
    */
    ItemBool *colorizeByProjectItem()
    {
      return mColorizeByProjectItem;
    }

  protected:
    UiConfig();
    friend class UiConfigHelper;


    // UiSettings
    int mBottomLeftCornerOwner;
    int mBottomRightCornerOwner;
    int mTabBarVisibility;
    int mCloseButtonsOnTabs;
    int mTabBarOpenAfterCurrent;
    int mTabBarArrangeBuddies;
    bool mColorizeByProject;

  private:
    ItemInt *mBottomLeftCornerOwnerItem;
    ItemInt *mBottomRightCornerOwnerItem;
    ItemInt *mTabBarVisibilityItem;
    ItemInt *mCloseButtonsOnTabsItem;
    ItemInt *mTabBarOpenAfterCurrentItem;
    ItemInt *mTabBarArrangeBuddiesItem;
    ItemBool *mColorizeByProjectItem;
};

#endif

