/********************************************************************************
** Form generated from reading UI file 'uiconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_UICONFIG_H
#define UI_UICONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_UiConfig
{
public:
    QVBoxLayout *vboxLayout;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *label_4;
    QLabel *label_5;
    QComboBox *kcfg_BottomLeftCornerOwner;
    QComboBox *kcfg_BottomRightCornerOwner;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_1;
    QCheckBox *kcfg_TabBarOpenAfterCurrent;
    QCheckBox *kcfg_TabBarArrangeBuddies;
    QCheckBox *kcfg_TabBarVisibility;
    QCheckBox *kcfg_CloseButtonsOnTabs;
    QGroupBox *groupBox_3;
    QFormLayout *formLayout_2;
    QCheckBox *kcfg_ColorizeByProject;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *UiConfig)
    {
        if (UiConfig->objectName().isEmpty())
            UiConfig->setObjectName("UiConfig");
        UiConfig->resize(521, 399);
        vboxLayout = new QVBoxLayout(UiConfig);
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        vboxLayout->setObjectName("vboxLayout");
        groupBox = new QGroupBox(UiConfig);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_5);

        kcfg_BottomLeftCornerOwner = new QComboBox(groupBox);
        kcfg_BottomLeftCornerOwner->addItem(QString());
        kcfg_BottomLeftCornerOwner->addItem(QString());
        kcfg_BottomLeftCornerOwner->setObjectName("kcfg_BottomLeftCornerOwner");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_BottomLeftCornerOwner);

        kcfg_BottomRightCornerOwner = new QComboBox(groupBox);
        kcfg_BottomRightCornerOwner->addItem(QString());
        kcfg_BottomRightCornerOwner->addItem(QString());
        kcfg_BottomRightCornerOwner->setObjectName("kcfg_BottomRightCornerOwner");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_BottomRightCornerOwner);


        vboxLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(UiConfig);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_1 = new QGridLayout(groupBox_2);
        gridLayout_1->setObjectName("gridLayout_1");
        kcfg_TabBarOpenAfterCurrent = new QCheckBox(groupBox_2);
        kcfg_TabBarOpenAfterCurrent->setObjectName("kcfg_TabBarOpenAfterCurrent");
        kcfg_TabBarOpenAfterCurrent->setChecked(true);

        gridLayout_1->addWidget(kcfg_TabBarOpenAfterCurrent, 2, 0, 1, 1);

        kcfg_TabBarArrangeBuddies = new QCheckBox(groupBox_2);
        kcfg_TabBarArrangeBuddies->setObjectName("kcfg_TabBarArrangeBuddies");

        gridLayout_1->addWidget(kcfg_TabBarArrangeBuddies, 3, 0, 1, 1);

        kcfg_TabBarVisibility = new QCheckBox(groupBox_2);
        kcfg_TabBarVisibility->setObjectName("kcfg_TabBarVisibility");
        kcfg_TabBarVisibility->setChecked(true);

        gridLayout_1->addWidget(kcfg_TabBarVisibility, 0, 0, 1, 1);

        kcfg_CloseButtonsOnTabs = new QCheckBox(groupBox_2);
        kcfg_CloseButtonsOnTabs->setObjectName("kcfg_CloseButtonsOnTabs");
        kcfg_CloseButtonsOnTabs->setChecked(true);

        gridLayout_1->addWidget(kcfg_CloseButtonsOnTabs, 1, 0, 1, 1);


        vboxLayout->addWidget(groupBox_2);

        groupBox_3 = new QGroupBox(UiConfig);
        groupBox_3->setObjectName("groupBox_3");
        formLayout_2 = new QFormLayout(groupBox_3);
        formLayout_2->setObjectName("formLayout_2");
        kcfg_ColorizeByProject = new QCheckBox(groupBox_3);
        kcfg_ColorizeByProject->setObjectName("kcfg_ColorizeByProject");
        kcfg_ColorizeByProject->setChecked(true);

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, kcfg_ColorizeByProject);


        vboxLayout->addWidget(groupBox_3);

        spacerItem = new QSpacerItem(0, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(UiConfig);
        QObject::connect(kcfg_TabBarVisibility, &QCheckBox::toggled, kcfg_TabBarOpenAfterCurrent, &QCheckBox::setEnabled);
        QObject::connect(kcfg_TabBarVisibility, &QCheckBox::toggled, kcfg_TabBarArrangeBuddies, &QCheckBox::setEnabled);
        QObject::connect(kcfg_TabBarVisibility, &QCheckBox::toggled, kcfg_CloseButtonsOnTabs, &QCheckBox::setEnabled);

        QMetaObject::connectSlotsByName(UiConfig);
    } // setupUi

    void retranslateUi(QWidget *UiConfig)
    {
        UiConfig->setWindowTitle(tr2i18n("User Interface", nullptr));
        groupBox->setTitle(tr2i18n("Dock Window Behavior", "@title:group"));
#if QT_CONFIG(tooltip)
        label_4->setToolTip(tr2i18n("<p>Controls whether the bottom left corner is occupied by the dock at the left, or by the dock at the bottom.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("Bottom left corner occupied by:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        label_5->setToolTip(tr2i18n("<p>Controls whether the bottom right corner is occupied by the dock at the right, or by the dock at the bottom.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        label_5->setText(tr2i18n("Bottom right corner occupied by:", "@label:listbox"));
        kcfg_BottomLeftCornerOwner->setItemText(0, tr2i18n("Left Dock", "@item:inlistbox"));
        kcfg_BottomLeftCornerOwner->setItemText(1, tr2i18n("Bottom Dock", "@item:inlistbox"));

#if QT_CONFIG(tooltip)
        kcfg_BottomLeftCornerOwner->setToolTip(tr2i18n("<p>Controls whether the bottom left corner is occupied by the dock at the left, or by the dock at the bottom.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_BottomRightCornerOwner->setItemText(0, tr2i18n("Right Dock", "@item:inlistbox"));
        kcfg_BottomRightCornerOwner->setItemText(1, tr2i18n("Bottom Dock", "@item:inlistbox"));

#if QT_CONFIG(tooltip)
        kcfg_BottomRightCornerOwner->setToolTip(tr2i18n("<p>Controls whether the bottom right corner is occupied by the dock at the right, or by the dock at the bottom.</p>", nullptr));
#endif // QT_CONFIG(tooltip)
        groupBox_2->setTitle(tr2i18n("Tabbed Browsing", "@title:group"));
#if QT_CONFIG(tooltip)
        kcfg_TabBarOpenAfterCurrent->setToolTip(tr2i18n("Controls whether to open new tabs next to the active one.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_TabBarOpenAfterCurrent->setText(tr2i18n("Open new tab after current", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_TabBarArrangeBuddies->setToolTip(tr2i18n("When enabled, plugins can group related files side by side.\n"
"For example, a header file will be opened next to the implementation file.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_TabBarArrangeBuddies->setText(tr2i18n("Arrange related documents side by side", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_TabBarVisibility->setToolTip(tr2i18n("Enables or disables the display of the tab bar at the top of the editor window.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_TabBarVisibility->setText(tr2i18n("Show tabs", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_CloseButtonsOnTabs->setToolTip(tr2i18n("Enables or disables the display of a close button in each tab in the tab bar at the top of the editor window.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_CloseButtonsOnTabs->setText(tr2i18n("Show close buttons on tabs", "@option:check"));
        groupBox_3->setTitle(tr2i18n("Coloring", "@title:group"));
#if QT_CONFIG(tooltip)
        kcfg_ColorizeByProject->setToolTip(tr2i18n("When enabled, tabs and other widgets are colored based on the project affiliation", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_ColorizeByProject->setText(tr2i18n("Color widgets based on the project affiliation", "@option:check"));
    } // retranslateUi

};

namespace Ui {
    class UiConfig: public Ui_UiConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UICONFIG_H

