/********************************************************************************
** Form generated from reading UI file 'projectpreferences.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTPREFERENCES_H
#define UI_PROJECTPREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_ProjectPreferences
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_3;
    KUrlRequester *kcfg_projectsBaseDirectory;
    QCheckBox *kcfg_parseAllProjectSources;
    QCheckBox *kcfg_saveDocuments;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ProjectSettings)
    {
        if (ProjectSettings->objectName().isEmpty())
            ProjectSettings->setObjectName("ProjectSettings");
        ProjectSettings->resize(597, 247);
        verticalLayout = new QVBoxLayout(ProjectSettings);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_3 = new QLabel(ProjectSettings);
        label_3->setObjectName("label_3");

        horizontalLayout_3->addWidget(label_3);

        kcfg_projectsBaseDirectory = new KUrlRequester(ProjectSettings);
        kcfg_projectsBaseDirectory->setObjectName("kcfg_projectsBaseDirectory");
        kcfg_projectsBaseDirectory->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);

        horizontalLayout_3->addWidget(kcfg_projectsBaseDirectory);


        verticalLayout->addLayout(horizontalLayout_3);

        kcfg_parseAllProjectSources = new QCheckBox(ProjectSettings);
        kcfg_parseAllProjectSources->setObjectName("kcfg_parseAllProjectSources");

        verticalLayout->addWidget(kcfg_parseAllProjectSources);

        kcfg_saveDocuments = new QCheckBox(ProjectSettings);
        kcfg_saveDocuments->setObjectName("kcfg_saveDocuments");

        verticalLayout->addWidget(kcfg_saveDocuments);

        verticalSpacer = new QSpacerItem(403, 147, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(kcfg_projectsBaseDirectory);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ProjectSettings);

        QMetaObject::connectSlotsByName(ProjectSettings);
    } // setupUi

    void retranslateUi(QWidget *ProjectSettings)
    {
#if QT_CONFIG(tooltip)
        label_3->setToolTip(tr2i18n("Select the base directory where new projects are to be created", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Projects base directory:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_projectsBaseDirectory->setToolTip(tr2i18n("Select the base directory where new projects are to be created", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_parseAllProjectSources->setToolTip(tr2i18n("Parse all files in a project after the project has been opened", "@info:tolltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_parseAllProjectSources->setText(tr2i18n("Schedule all project files for parsing", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_saveDocuments->setToolTip(tr2i18n("Save all modified documents when the \"build\" action is triggered", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_saveDocuments->setText(tr2i18n("Save all documents before building", "@option:check"));
        (void)ProjectSettings;
    } // retranslateUi

};

namespace Ui {
    class ProjectPreferences: public Ui_ProjectPreferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROJECTPREFERENCES_H

