/****************************************************************************
** Meta object code from reading C++ file 'projecttreeview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/projectmanagerview/projecttreeview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'projecttreeview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ProjectTreeViewE_t {};
} // unnamed namespace

template <> constexpr inline auto ProjectTreeView::qt_create_metaobjectdata<qt_meta_tag_ZN15ProjectTreeViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProjectTreeView",
        "activate",
        "",
        "KDevelop::Path",
        "url",
        "slotActivated",
        "QModelIndex",
        "index",
        "popupContextMenu",
        "QPoint",
        "pos",
        "openProjectConfig",
        "saveState",
        "KDevelop::IProject*",
        "project",
        "restoreState",
        "aboutToShutdown",
        "projectClosed",
        "rowsInserted",
        "parent",
        "start",
        "end",
        "rowsAboutToBeRemoved"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activate'
        QtMocHelpers::SignalData<void(const KDevelop::Path &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotActivated'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(5, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'popupContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(8, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'openProjectConfig'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'saveState'
        QtMocHelpers::SlotData<void(KDevelop::IProject *)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'saveState'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'restoreState'
        QtMocHelpers::SlotData<void(KDevelop::IProject *)>(15, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'restoreState'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessProtected | QMC::MethodCloned, QMetaType::Void),
        // Slot 'aboutToShutdown'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'projectClosed'
        QtMocHelpers::SlotData<void(KDevelop::IProject *)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'rowsInserted'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'rowsAboutToBeRemoved'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProjectTreeView, qt_meta_tag_ZN15ProjectTreeViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProjectTreeView::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ProjectTreeViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ProjectTreeViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ProjectTreeViewE_t>.metaTypes,
    nullptr
} };

void ProjectTreeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProjectTreeView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activate((*reinterpret_cast<std::add_pointer_t<KDevelop::Path>>(_a[1]))); break;
        case 1: _t->slotActivated((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 2: _t->popupContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 3: _t->openProjectConfig(); break;
        case 4: _t->saveState((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 5: _t->saveState(); break;
        case 6: _t->restoreState((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 7: _t->restoreState(); break;
        case 8: _t->aboutToShutdown(); break;
        case 9: _t->projectClosed((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 10: _t->rowsInserted((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: _t->rowsAboutToBeRemoved((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProjectTreeView::*)(const KDevelop::Path & )>(_a, &ProjectTreeView::activate, 0))
            return;
    }
}

const QMetaObject *ProjectTreeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProjectTreeView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ProjectTreeViewE_t>.strings))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int ProjectTreeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void ProjectTreeView::activate(const KDevelop::Path & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
