/********************************************************************************
** Form generated from reading UI file 'qmakeconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QMAKECONFIG_H
#define UI_QMAKECONFIG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"

QT_BEGIN_NAMESPACE

class Ui_QMakeConfig
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    KComboBox *buildDirCombo;
    QPushButton *addButton;
    QPushButton *removeButton;
    QGroupBox *groupBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *QMakeConfig)
    {
        if (QMakeConfig->objectName().isEmpty())
            QMakeConfig->setObjectName("QMakeConfig");
        QMakeConfig->resize(520, 552);
        verticalLayout = new QVBoxLayout(QMakeConfig);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setSizeConstraint(QLayout::SetMinimumSize);
        buildDirCombo = new KComboBox(QMakeConfig);
        buildDirCombo->setObjectName("buildDirCombo");

        horizontalLayout->addWidget(buildDirCombo);

        addButton = new QPushButton(QMakeConfig);
        addButton->setObjectName("addButton");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(addButton->sizePolicy().hasHeightForWidth());
        addButton->setSizePolicy(sizePolicy);
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addButton->setIcon(icon);

        horizontalLayout->addWidget(addButton);

        removeButton = new QPushButton(QMakeConfig);
        removeButton->setObjectName("removeButton");
        sizePolicy.setHeightForWidth(removeButton->sizePolicy().hasHeightForWidth());
        removeButton->setSizePolicy(sizePolicy);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        removeButton->setIcon(icon1);

        horizontalLayout->addWidget(removeButton);


        verticalLayout->addLayout(horizontalLayout);

        groupBox = new QGroupBox(QMakeConfig);
        groupBox->setObjectName("groupBox");
        groupBox->setMaximumSize(QSize(16777215, 273));

        verticalLayout->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 492, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(QMakeConfig);

        QMetaObject::connectSlotsByName(QMakeConfig);
    } // setupUi

    void retranslateUi(QWidget *QMakeConfig)
    {
        addButton->setText(QString());
        removeButton->setText(QString());
        groupBox->setTitle(tr2i18n("Build Settings", "@title:group"));
        (void)QMakeConfig;
    } // retranslateUi

};

namespace Ui {
    class QMakeConfig: public Ui_QMakeConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QMAKECONFIG_H

