/****************************************************************************
** Meta object code from reading C++ file 'variablecollection.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/kdevplatform/debugger/variable/variablecollection.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'variablecollection.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop8VariableE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::Variable::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop8VariableE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::Variable",
        "die",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'die'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Variable, qt_meta_tag_ZN8KDevelop8VariableE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::Variable::staticMetaObject = { {
    QMetaObject::SuperData::link<TreeItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop8VariableE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop8VariableE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop8VariableE_t>.metaTypes,
    nullptr
} };

void KDevelop::Variable::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Variable *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->die(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *KDevelop::Variable::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::Variable::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop8VariableE_t>.strings))
        return static_cast<void*>(this);
    return TreeItem::qt_metacast(_clname);
}

int KDevelop::Variable::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TreeItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KDevelop11TooltipRootE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::TooltipRoot::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop11TooltipRootE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::TooltipRoot"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TooltipRoot, qt_meta_tag_ZN8KDevelop11TooltipRootE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::TooltipRoot::staticMetaObject = { {
    QMetaObject::SuperData::link<TreeItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop11TooltipRootE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop11TooltipRootE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop11TooltipRootE_t>.metaTypes,
    nullptr
} };

void KDevelop::TooltipRoot::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TooltipRoot *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KDevelop::TooltipRoot::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::TooltipRoot::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop11TooltipRootE_t>.strings))
        return static_cast<void*>(this);
    return TreeItem::qt_metacast(_clname);
}

int KDevelop::TooltipRoot::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TreeItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KDevelop7WatchesE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::Watches::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop7WatchesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::Watches"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Watches, qt_meta_tag_ZN8KDevelop7WatchesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::Watches::staticMetaObject = { {
    QMetaObject::SuperData::link<TreeItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop7WatchesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop7WatchesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop7WatchesE_t>.metaTypes,
    nullptr
} };

void KDevelop::Watches::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Watches *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KDevelop::Watches::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::Watches::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop7WatchesE_t>.strings))
        return static_cast<void*>(this);
    return TreeItem::qt_metacast(_clname);
}

int KDevelop::Watches::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TreeItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KDevelop6LocalsE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::Locals::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop6LocalsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::Locals"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Locals, qt_meta_tag_ZN8KDevelop6LocalsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::Locals::staticMetaObject = { {
    QMetaObject::SuperData::link<TreeItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop6LocalsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop6LocalsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop6LocalsE_t>.metaTypes,
    nullptr
} };

void KDevelop::Locals::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Locals *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KDevelop::Locals::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::Locals::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop6LocalsE_t>.strings))
        return static_cast<void*>(this);
    return TreeItem::qt_metacast(_clname);
}

int KDevelop::Locals::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TreeItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KDevelop13VariablesRootE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::VariablesRoot::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop13VariablesRootE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::VariablesRoot"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VariablesRoot, qt_meta_tag_ZN8KDevelop13VariablesRootE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::VariablesRoot::staticMetaObject = { {
    QMetaObject::SuperData::link<TreeItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop13VariablesRootE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop13VariablesRootE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop13VariablesRootE_t>.metaTypes,
    nullptr
} };

void KDevelop::VariablesRoot::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VariablesRoot *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KDevelop::VariablesRoot::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::VariablesRoot::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop13VariablesRootE_t>.strings))
        return static_cast<void*>(this);
    return TreeItem::qt_metacast(_clname);
}

int KDevelop::VariablesRoot::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TreeItem::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KDevelop18VariableCollectionE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::VariableCollection::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop18VariableCollectionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::VariableCollection",
        "variableWidgetShown",
        "",
        "variableWidgetHidden",
        "updateAutoUpdate",
        "KDevelop::IDebugSession*",
        "session",
        "textDocumentCreated",
        "KDevelop::IDocument*",
        "viewCreated",
        "KTextEditor::Document*",
        "KTextEditor::View*"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'variableWidgetShown'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'variableWidgetHidden'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateAutoUpdate'
        QtMocHelpers::SlotData<void(KDevelop::IDebugSession *)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'updateAutoUpdate'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'textDocumentCreated'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'viewCreated'
        QtMocHelpers::SlotData<void(KTextEditor::Document *, KTextEditor::View *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 }, { 0x80000000 | 11, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VariableCollection, qt_meta_tag_ZN8KDevelop18VariableCollectionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::VariableCollection::staticMetaObject = { {
    QMetaObject::SuperData::link<TreeModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18VariableCollectionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18VariableCollectionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop18VariableCollectionE_t>.metaTypes,
    nullptr
} };

void KDevelop::VariableCollection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VariableCollection *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->variableWidgetShown(); break;
        case 1: _t->variableWidgetHidden(); break;
        case 2: _t->updateAutoUpdate((*reinterpret_cast<std::add_pointer_t<KDevelop::IDebugSession*>>(_a[1]))); break;
        case 3: _t->updateAutoUpdate(); break;
        case 4: _t->textDocumentCreated((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 5: _t->viewCreated((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *KDevelop::VariableCollection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::VariableCollection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18VariableCollectionE_t>.strings))
        return static_cast<void*>(this);
    return TreeModel::qt_metacast(_clname);
}

int KDevelop::VariableCollection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TreeModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
