/****************************************************************************
** Meta object code from reading C++ file 'cmakebuilder.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/cmakebuilder/cmakebuilder.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'cmakebuilder.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12CMakeBuilderE_t {};
} // unnamed namespace

template <> constexpr inline auto CMakeBuilder::qt_create_metaobjectdata<qt_meta_tag_ZN12CMakeBuilderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CMakeBuilder",
        "built",
        "",
        "KDevelop::ProjectBaseItem*",
        "failed",
        "installed",
        "cleaned",
        "configured",
        "KDevelop::IProject*",
        "KDevelop::IProjectBuilder::ConfigureRequest",
        "request",
        "pruned"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'built'
        QtMocHelpers::SignalData<void(KDevelop::ProjectBaseItem *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'failed'
        QtMocHelpers::SignalData<void(KDevelop::ProjectBaseItem *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'installed'
        QtMocHelpers::SignalData<void(KDevelop::ProjectBaseItem *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'cleaned'
        QtMocHelpers::SignalData<void(KDevelop::ProjectBaseItem *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'configured'
        QtMocHelpers::SignalData<void(KDevelop::IProject *, KDevelop::IProjectBuilder::ConfigureRequest)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 }, { 0x80000000 | 9, 10 },
        }}),
        // Signal 'pruned'
        QtMocHelpers::SignalData<void(KDevelop::IProject *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CMakeBuilder, qt_meta_tag_ZN12CMakeBuilderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CMakeBuilder::staticMetaObject = { {
    QMetaObject::SuperData::link<KDevelop::IPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CMakeBuilderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CMakeBuilderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12CMakeBuilderE_t>.metaTypes,
    nullptr
} };

void CMakeBuilder::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CMakeBuilder *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->built((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectBaseItem*>>(_a[1]))); break;
        case 1: _t->failed((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectBaseItem*>>(_a[1]))); break;
        case 2: _t->installed((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectBaseItem*>>(_a[1]))); break;
        case 3: _t->cleaned((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectBaseItem*>>(_a[1]))); break;
        case 4: _t->configured((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KDevelop::IProjectBuilder::ConfigureRequest>>(_a[2]))); break;
        case 5: _t->pruned((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CMakeBuilder::*)(KDevelop::ProjectBaseItem * )>(_a, &CMakeBuilder::built, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CMakeBuilder::*)(KDevelop::ProjectBaseItem * )>(_a, &CMakeBuilder::failed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CMakeBuilder::*)(KDevelop::ProjectBaseItem * )>(_a, &CMakeBuilder::installed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CMakeBuilder::*)(KDevelop::ProjectBaseItem * )>(_a, &CMakeBuilder::cleaned, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CMakeBuilder::*)(KDevelop::IProject * , KDevelop::IProjectBuilder::ConfigureRequest )>(_a, &CMakeBuilder::configured, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CMakeBuilder::*)(KDevelop::IProject * )>(_a, &CMakeBuilder::pruned, 5))
            return;
    }
}

const QMetaObject *CMakeBuilder::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CMakeBuilder::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12CMakeBuilderE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KDevelop::IProjectBuilder"))
        return static_cast< KDevelop::IProjectBuilder*>(this);
    if (!strcmp(_clname, "org.kdevelop.IProjectBuilder"))
        return static_cast< KDevelop::IProjectBuilder*>(this);
    return KDevelop::IPlugin::qt_metacast(_clname);
}

int CMakeBuilder::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDevelop::IPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void CMakeBuilder::built(KDevelop::ProjectBaseItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void CMakeBuilder::failed(KDevelop::ProjectBaseItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void CMakeBuilder::installed(KDevelop::ProjectBaseItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void CMakeBuilder::cleaned(KDevelop::ProjectBaseItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void CMakeBuilder::configured(KDevelop::IProject * _t1, KDevelop::IProjectBuilder::ConfigureRequest _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void CMakeBuilder::pruned(KDevelop::IProject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
