/********************************************************************************
** Form generated from reading UI file 'lldbconfigpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LLDBCONFIGPAGE_H
#define UI_LLDBCONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"
#include "shell/environmentconfigurebutton.h"
#include "util/environmentselectionwidget.h"

QT_BEGIN_NAMESPACE

class Ui_LldbConfigPage
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupDebugger;
    QFormLayout *formLayout;
    QLabel *label;
    KUrlRequester *lineDebuggerExec;
    QLabel *label_2;
    QLineEdit *lineDebuggerArgs;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout;
    KDevelop::EnvironmentSelectionWidget *comboEnv;
    KDevelop::EnvironmentConfigureButton *btnEditEnv;
    QCheckBox *checkInheritSystem;
    QGroupBox *groupOptions;
    QFormLayout *formLayout_2;
    QLabel *label_4;
    KUrlRequester *lineConfigScript;
    QLabel *label_5;
    QComboBox *comboStartWith;
    QLabel *label_7;
    QCheckBox *checkBreakOnStart;
    QGroupBox *groupRemote;
    QFormLayout *formLayout_3;
    QLabel *label_6;
    QLineEdit *lineRemoteServer;
    QLabel *label_8;
    QLineEdit *lineOnDevPath;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *LldbConfigPage)
    {
        if (LldbConfigPage->objectName().isEmpty())
            LldbConfigPage->setObjectName("LldbConfigPage");
        LldbConfigPage->resize(530, 535);
        verticalLayout = new QVBoxLayout(LldbConfigPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupDebugger = new QGroupBox(LldbConfigPage);
        groupDebugger->setObjectName("groupDebugger");
        formLayout = new QFormLayout(groupDebugger);
        formLayout->setObjectName("formLayout");
        label = new QLabel(groupDebugger);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        lineDebuggerExec = new KUrlRequester(groupDebugger);
        lineDebuggerExec->setObjectName("lineDebuggerExec");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, lineDebuggerExec);

        label_2 = new QLabel(groupDebugger);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        lineDebuggerArgs = new QLineEdit(groupDebugger);
        lineDebuggerArgs->setObjectName("lineDebuggerArgs");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, lineDebuggerArgs);

        label_3 = new QLabel(groupDebugger);
        label_3->setObjectName("label_3");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        comboEnv = new KDevelop::EnvironmentSelectionWidget(groupDebugger);
        comboEnv->setObjectName("comboEnv");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(comboEnv->sizePolicy().hasHeightForWidth());
        comboEnv->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(comboEnv);

        btnEditEnv = new KDevelop::EnvironmentConfigureButton(groupDebugger);
        btnEditEnv->setObjectName("btnEditEnv");

        horizontalLayout->addWidget(btnEditEnv);


        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        checkInheritSystem = new QCheckBox(groupDebugger);
        checkInheritSystem->setObjectName("checkInheritSystem");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, checkInheritSystem);


        verticalLayout->addWidget(groupDebugger);

        groupOptions = new QGroupBox(LldbConfigPage);
        groupOptions->setObjectName("groupOptions");
        formLayout_2 = new QFormLayout(groupOptions);
        formLayout_2->setObjectName("formLayout_2");
        label_4 = new QLabel(groupOptions);
        label_4->setObjectName("label_4");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        lineConfigScript = new KUrlRequester(groupOptions);
        lineConfigScript->setObjectName("lineConfigScript");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, lineConfigScript);

        label_5 = new QLabel(groupOptions);
        label_5->setObjectName("label_5");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_5);

        comboStartWith = new QComboBox(groupOptions);
        comboStartWith->addItem(QString());
        comboStartWith->addItem(QString());
        comboStartWith->addItem(QString());
        comboStartWith->setObjectName("comboStartWith");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, comboStartWith);

        label_7 = new QLabel(groupOptions);
        label_7->setObjectName("label_7");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_7);

        checkBreakOnStart = new QCheckBox(groupOptions);
        checkBreakOnStart->setObjectName("checkBreakOnStart");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, checkBreakOnStart);


        verticalLayout->addWidget(groupOptions);

        groupRemote = new QGroupBox(LldbConfigPage);
        groupRemote->setObjectName("groupRemote");
        groupRemote->setCheckable(true);
        formLayout_3 = new QFormLayout(groupRemote);
        formLayout_3->setObjectName("formLayout_3");
        label_6 = new QLabel(groupRemote);
        label_6->setObjectName("label_6");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_6);

        lineRemoteServer = new QLineEdit(groupRemote);
        lineRemoteServer->setObjectName("lineRemoteServer");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, lineRemoteServer);

        label_8 = new QLabel(groupRemote);
        label_8->setObjectName("label_8");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, label_8);

        lineOnDevPath = new QLineEdit(groupRemote);
        lineOnDevPath->setObjectName("lineOnDevPath");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, lineOnDevPath);


        verticalLayout->addWidget(groupRemote);

        verticalSpacer = new QSpacerItem(20, 149, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(LldbConfigPage);

        QMetaObject::connectSlotsByName(LldbConfigPage);
    } // setupUi

    void retranslateUi(QWidget *LldbConfigPage)
    {
        groupDebugger->setTitle(tr2i18n("Debugger", "@title:group"));
        label->setText(tr2i18n("Debugger executable:", "@label:chooser"));
        lineDebuggerExec->setProperty("placeholderText", QVariant(tr2i18n("Override path to lldb-mi executable...", "@info:placeholder")));
        label_2->setText(tr2i18n("Additional arguments:", "@label:textbox"));
        label_3->setText(tr2i18n("Environment:", "@label:chooser"));
        checkInheritSystem->setText(tr2i18n("Inherit system environment", "@option:check"));
        groupOptions->setTitle(tr2i18n("Options", "@title:group"));
        label_4->setText(tr2i18n("Config script:", "@label:chooser"));
        lineConfigScript->setProperty("placeholderText", QVariant(tr2i18n("/path/to/lldb/config/script", "@info:placeholder")));
        label_5->setText(tr2i18n("Start debugger with:", "@label:listbox"));
        comboStartWith->setItemText(0, tr2i18n("Application Output", "@item:inlistbox start debugger with"));
        comboStartWith->setItemText(1, tr2i18n("LLDB Console", "@item:inlistbox start debugger with"));
        comboStartWith->setItemText(2, tr2i18n("Frame Stack", "@item:inlistbox start debugger with"));

        label_7->setText(tr2i18n("Break on start:", "@option:check"));
        checkBreakOnStart->setText(QString());
        groupRemote->setTitle(tr2i18n("Remo&te Debugging", "@title:group"));
        label_6->setText(tr2i18n("Remote server:", "@label:textbox"));
        lineRemoteServer->setPlaceholderText(tr2i18n("host:port", "@info:placeholder"));
        label_8->setText(tr2i18n("Remote work path:", "@label:textbox"));
        lineOnDevPath->setPlaceholderText(tr2i18n("/path/to/a/on-device/writable/directory", "@info:placeholder"));
        (void)LldbConfigPage;
    } // retranslateUi

};

namespace Ui {
    class LldbConfigPage: public Ui_LldbConfigPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LLDBCONFIGPAGE_H

