/********************************************************************************
** Form generated from reading UI file 'makeconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAKECONFIG_H
#define UI_MAKECONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include <util/environmentselectionwidget.h>
#include "KComboBox"
#include "KUrlRequester"
#include "shell/environmentconfigurebutton.h"

QT_BEGIN_NAMESPACE

class Ui_MakeConfig
{
public:
    QFormLayout *formLayout;
    QLabel *label_8;
    QCheckBox *kcfg_abortOnFirstError;
    QLabel *label_7;
    QCheckBox *kcfg_displayOnly;
    QLabel *label_31;
    QCheckBox *kcfg_installAsRoot;
    QLabel *rootinstallationcommandLabel;
    KComboBox *kcfg_suCommand;
    QLabel *label;
    QSpinBox *kcfg_numberOfJobs;
    QLabel *label_4;
    KUrlRequester *makeExecutable;
    QLabel *label_6;
    QLineEdit *kcfg_defaultTarget;
    QLabel *label_5;
    QLineEdit *kcfg_additionalOptions;
    QLabel *label_2;
    QWidget *widget;
    QHBoxLayout *horizontalLayout;
    KDevelop::EnvironmentSelectionWidget *kcfg_environmentProfile;
    KDevelop::EnvironmentConfigureButton *configureEnvironment;
    QLabel *label_3;
    QCheckBox *kcfg_overrideNumberOfJobs;

    void setupUi(QWidget *MakeConfig)
    {
        if (MakeConfig->objectName().isEmpty())
            MakeConfig->setObjectName("MakeConfig");
        MakeConfig->resize(521, 362);
        formLayout = new QFormLayout(MakeConfig);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::AllNonFixedFieldsGrow);
        formLayout->setContentsMargins(0, 0, 0, 0);
        label_8 = new QLabel(MakeConfig);
        label_8->setObjectName("label_8");
        label_8->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_8);

        kcfg_abortOnFirstError = new QCheckBox(MakeConfig);
        kcfg_abortOnFirstError->setObjectName("kcfg_abortOnFirstError");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_abortOnFirstError);

        label_7 = new QLabel(MakeConfig);
        label_7->setObjectName("label_7");
        label_7->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_7);

        kcfg_displayOnly = new QCheckBox(MakeConfig);
        kcfg_displayOnly->setObjectName("kcfg_displayOnly");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_displayOnly);

        label_31 = new QLabel(MakeConfig);
        label_31->setObjectName("label_31");
        label_31->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_31);

        kcfg_installAsRoot = new QCheckBox(MakeConfig);
        kcfg_installAsRoot->setObjectName("kcfg_installAsRoot");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_installAsRoot);

        rootinstallationcommandLabel = new QLabel(MakeConfig);
        rootinstallationcommandLabel->setObjectName("rootinstallationcommandLabel");
        rootinstallationcommandLabel->setEnabled(false);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, rootinstallationcommandLabel);

        kcfg_suCommand = new KComboBox(MakeConfig);
        kcfg_suCommand->addItem(QString::fromUtf8("kdesu"));
        kcfg_suCommand->addItem(QString::fromUtf8("kdesudo"));
        kcfg_suCommand->addItem(QString::fromUtf8("gksu"));
        kcfg_suCommand->setObjectName("kcfg_suCommand");
        kcfg_suCommand->setEnabled(false);
        kcfg_suCommand->setEditable(true);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_suCommand);

        label = new QLabel(MakeConfig);
        label->setObjectName("label");
        label->setEnabled(false);
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label);

        kcfg_numberOfJobs = new QSpinBox(MakeConfig);
        kcfg_numberOfJobs->setObjectName("kcfg_numberOfJobs");
        kcfg_numberOfJobs->setEnabled(false);
        kcfg_numberOfJobs->setMinimum(1);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_numberOfJobs);

        label_4 = new QLabel(MakeConfig);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_4);

        makeExecutable = new KUrlRequester(MakeConfig);
        makeExecutable->setObjectName("makeExecutable");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(makeExecutable->sizePolicy().hasHeightForWidth());
        makeExecutable->setSizePolicy(sizePolicy);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, makeExecutable);

        label_6 = new QLabel(MakeConfig);
        label_6->setObjectName("label_6");
        label_6->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_6);

        kcfg_defaultTarget = new QLineEdit(MakeConfig);
        kcfg_defaultTarget->setObjectName("kcfg_defaultTarget");
        kcfg_defaultTarget->setClearButtonEnabled(true);

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, kcfg_defaultTarget);

        label_5 = new QLabel(MakeConfig);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_5);

        kcfg_additionalOptions = new QLineEdit(MakeConfig);
        kcfg_additionalOptions->setObjectName("kcfg_additionalOptions");
        kcfg_additionalOptions->setClearButtonEnabled(true);

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, kcfg_additionalOptions);

        label_2 = new QLabel(MakeConfig);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        formLayout->setWidget(10, QFormLayout::ItemRole::LabelRole, label_2);

        widget = new QWidget(MakeConfig);
        widget->setObjectName("widget");
        horizontalLayout = new QHBoxLayout(widget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        kcfg_environmentProfile = new KDevelop::EnvironmentSelectionWidget(widget);
        kcfg_environmentProfile->setObjectName("kcfg_environmentProfile");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_environmentProfile->sizePolicy().hasHeightForWidth());
        kcfg_environmentProfile->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(kcfg_environmentProfile);

        configureEnvironment = new KDevelop::EnvironmentConfigureButton(widget);
        configureEnvironment->setObjectName("configureEnvironment");

        horizontalLayout->addWidget(configureEnvironment);


        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, widget);

        label_3 = new QLabel(MakeConfig);
        label_3->setObjectName("label_3");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_overrideNumberOfJobs = new QCheckBox(MakeConfig);
        kcfg_overrideNumberOfJobs->setObjectName("kcfg_overrideNumberOfJobs");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_overrideNumberOfJobs);

#if QT_CONFIG(shortcut)
        label_8->setBuddy(kcfg_abortOnFirstError);
        label_7->setBuddy(kcfg_displayOnly);
        label_31->setBuddy(kcfg_installAsRoot);
        rootinstallationcommandLabel->setBuddy(kcfg_suCommand);
        label->setBuddy(kcfg_numberOfJobs);
        label_4->setBuddy(makeExecutable);
        label_6->setBuddy(kcfg_defaultTarget);
        label_5->setBuddy(kcfg_additionalOptions);
        label_2->setBuddy(kcfg_environmentProfile);
        label_3->setBuddy(kcfg_overrideNumberOfJobs);
#endif // QT_CONFIG(shortcut)

        retranslateUi(MakeConfig);
        QObject::connect(kcfg_installAsRoot, SIGNAL(clicked(bool)), kcfg_suCommand, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_installAsRoot, &QCheckBox::toggled, rootinstallationcommandLabel, &QLabel::setEnabled);
        QObject::connect(kcfg_installAsRoot, SIGNAL(toggled(bool)), kcfg_suCommand, SLOT(setEnabled(bool)));
        QObject::connect(kcfg_overrideNumberOfJobs, &QCheckBox::toggled, kcfg_numberOfJobs, &QSpinBox::setEnabled);
        QObject::connect(kcfg_overrideNumberOfJobs, &QCheckBox::toggled, label, &QLabel::setEnabled);

        QMetaObject::connectSlotsByName(MakeConfig);
    } // setupUi

    void retranslateUi(QWidget *MakeConfig)
    {
        label_8->setText(tr2i18n("&Abort on first error:", "@option:check"));
        kcfg_abortOnFirstError->setText(QString());
        label_7->setText(tr2i18n("&Display commands but do not execute them:", "@option:check"));
        kcfg_displayOnly->setText(QString());
        label_31->setText(tr2i18n("Insta&ll as root:", "@option:check"));
        kcfg_installAsRoot->setText(QString());
        rootinstallationcommandLabel->setText(tr2i18n("Root installation &command:", "@label:listbox"));

        label->setText(tr2i18n("&Number of simultaneous jobs:", "@label:spinbox"));
        label_4->setText(tr2i18n("&Make executable:", "@label:chooser"));
        label_6->setText(tr2i18n("Default make &target:", "@label:textbox"));
        label_5->setText(tr2i18n("Additional ma&ke options:", "@label:textbox"));
        label_2->setText(tr2i18n("Active environment &profile:", "@label:chooser"));
        label_3->setText(tr2i18n("Override number of &jobs:", "@option:check"));
        kcfg_overrideNumberOfJobs->setText(QString());
        (void)MakeConfig;
    } // retranslateUi

};

namespace Ui {
    class MakeConfig: public Ui_MakeConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MAKECONFIG_H

