/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.12.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // kdevelop-semantic-colors.xml
  0x0,0x0,0x2,0x86,
  0x28,
  0xb5,0x2f,0xfd,0x60,0xbc,0x8,0xe5,0x13,0x0,0xe6,0x22,0x66,0x1f,0x10,0x79,0x1b,
  0xa7,0x52,0x92,0xe9,0x95,0x67,0x16,0xcd,0xb2,0xa5,0x8c,0x48,0x13,0x19,0x52,0x15,
  0x64,0xb6,0xab,0xec,0xf,0x20,0xcf,0x4,0x0,0x5,0x80,0xb,0x60,0x0,0x5d,0x0,
  0x59,0x0,0x97,0xad,0xdb,0x77,0x7d,0xa9,0xbf,0xca,0xdf,0xe5,0xdc,0xea,0x7d,0xc6,
  0x89,0x30,0x2c,0xfc,0xfb,0xc4,0x55,0xe9,0x28,0xaf,0x68,0x1e,0xfa,0x7d,0xd7,0x56,
  0x59,0x29,0xc,0xe3,0xd3,0x9e,0xe,0x7a,0x97,0xcf,0xa6,0xcc,0xcc,0x80,0x97,0x7d,
  0x66,0x78,0xcc,0xb1,0x84,0x40,0x24,0x10,0xbb,0xd6,0x9d,0x46,0x5b,0xb2,0xe5,0x43,
  0xa,0x51,0x3c,0x95,0xc0,0x3,0x0,0x89,0x3c,0x86,0x75,0x9,0x89,0xde,0xa5,0xd1,
  0x98,0x55,0x48,0x9d,0x1f,0xc2,0x90,0x78,0x17,0xad,0xf1,0x5a,0x47,0xb1,0x9c,0xaa,
  0xc8,0x23,0xbd,0xf1,0xec,0x3a,0x2e,0x57,0xf,0x2a,0x79,0xc6,0xbe,0x3d,0x37,0x2c,
  0x21,0x4f,0x87,0x2d,0x2b,0xd0,0xdf,0x95,0xe9,0x1f,0xef,0xe1,0xc9,0x9e,0xb6,0x76,
  0xde,0xaa,0xff,0xa,0xde,0x45,0xc9,0xa8,0xc5,0x69,0x94,0xfc,0xee,0x6d,0x49,0x79,
  0x97,0x7f,0x87,0x45,0xfb,0xdf,0x7c,0x9f,0x56,0xa8,0xd1,0xf8,0x72,0xd3,0xe2,0xf6,
  0x60,0x6,0x40,0xbc,0xb3,0xff,0x2e,0xea,0x59,0x16,0x37,0xc2,0xac,0xd0,0x20,0x63,
  0x4f,0x4d,0x72,0xd,0x73,0xc0,0xd6,0x37,0x7,0x31,0x8d,0x6f,0x9b,0xf3,0x2,0xf1,
  0x1b,0xb3,0x3e,0xb2,0x55,0xa3,0xd1,0x3e,0xad,0xf1,0xdb,0xfa,0xec,0xa8,0xe5,0x0,
  0xa3,0xec,0x8f,0xfc,0x10,0xef,0xca,0x64,0xc5,0xf8,0xf9,0x95,0x5d,0x3a,0x41,0x97,
  0xce,0x5d,0x7e,0xb6,0x37,0x8a,0xec,0x8,0x9d,0x3,0xdd,0xec,0x5d,0xef,0x76,0x94,
  0x13,0x76,0x6e,0x15,0xb2,0x2c,0x7e,0xd9,0xf5,0xa,0x63,0xc8,0x4f,0xdd,0x7a,0xa9,
  0x14,0x33,0x7e,0xd7,0xb8,0x3e,0x4f,0xbf,0x1d,0xff,0xed,0x4c,0xec,0x29,0x2e,0x68,
  0x34,0xd2,0xf6,0x79,0xb9,0x52,0x76,0x54,0x0,0x88,0x65,0x61,0xfd,0xec,0x50,0xf0,
  0xf6,0x59,0x4c,0x59,0x4f,0x3d,0xa3,0x91,0x1b,0x87,0xc7,0xe1,0x61,0xb1,0xf5,0x5e,
  0x87,0xd5,0x72,0x6e,0x3f,0xd5,0xc2,0xe6,0xf8,0x9c,0x95,0xd2,0x12,0x7a,0x85,0x33,
  0xdb,0x29,0x5b,0x2f,0xfd,0x95,0xd2,0xc9,0xd3,0xfe,0x4b,0x2b,0x25,0xf3,0x8f,0xd6,
  0x37,0x9a,0xe1,0x3c,0xb2,0x47,0xd0,0xad,0x63,0xd3,0x39,0xd7,0xfa,0xf6,0x1e,0x48,
  0xbb,0xb,0xac,0x1b,0xd9,0x58,0x95,0x18,0x89,0x75,0xb4,0x3d,0x62,0x87,0xcd,0x5d,
  0x9f,0xdd,0x99,0x1,0x58,0x20,0x20,0x86,0x10,0x67,0x92,0xb6,0xd,0x21,0x96,0xef,
  0x91,0x6,0xd7,0x13,0xb,0xce,0x0,0xdc,0x44,0x8,0xc4,0x82,0x24,0x24,0x18,0xf8,
  0x9d,0x18,0x1,0xdf,0x89,0x32,0xe4,0x7b,0x48,0xd8,0xe1,0xd4,0xd1,0x54,0x6e,0xd6,
  0xc4,0x56,0x54,0xa3,0x6c,0xeb,0x6f,0xa5,0xc,0xad,0xf8,0x23,0x58,0x5d,0x28,0x5f,
  0xc7,0xf1,0x4,0x10,0x30,0xdf,0x18,0xd6,0xb2,0x84,0xa7,0x47,0xd5,0xde,0x31,0xa8,
  0x51,0xd2,0x22,0xe4,0x68,0x99,0x3b,0x81,0x7,0x4,0x90,0xf4,0x10,0xf0,0x17,0x4,
  0x6a,0x1f,0x9,0x8,0xd8,0x17,0xbc,0x33,0x23,0xf0,0x22,0xe8,0xe8,0x5,0xc7,0xa,
  0xdc,0xb2,0x8b,0x7e,0xe2,0x40,0x9b,0x2,0xdc,0x7c,0x30,0xe,0xe5,0x69,0x33,0x56,
  0x35,0x54,0xbf,0x79,0xee,0x16,0x60,0x9c,0x88,0x2d,0xf6,0x72,0xcd,0xc0,0x1d,0x8c,
  0x8f,0x31,0xf2,0x22,0x36,0xd6,0x76,0x4c,0x25,0x31,0xa0,0xe2,0x31,0x99,0x2c,0x5b,
  0xdf,0xe4,0xed,0xde,0x3c,0x66,0x96,0xcd,0x88,0x10,0x4b,0xf9,0x2a,0x59,0x8c,0xc6,
  0x67,0x3e,0xe9,0x18,0xd2,0x4c,0xbe,0x18,0xd,0x90,0x6,0x8,0x64,0x2,0x72,0x1,
  0xea,0x21,0x59,0x3a,0x9e,0xc0,0xc3,0xdb,0x35,0x74,0x4f,0x7,0xfd,0x3,0x65,0x63,
  0x9c,0x85,0x66,0x6,0x38,0x36,0xa0,0x1e,0xbf,0x6f,0x64,0x9f,0x98,0x9,0xc2,0x36,
  0x2,0x15,0x88,0x8,0x67,
  
};

static const unsigned char qt_resource_name[] = {
  // org.kde.syntax-highlighting
  0x0,0x1b,
  0x1,0x9c,0xda,0xa7,
  0x0,0x6f,
  0x0,0x72,0x0,0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,0x65,0x0,0x2e,0x0,0x73,0x0,0x79,0x0,0x6e,0x0,0x74,0x0,0x61,0x0,0x78,0x0,0x2d,0x0,0x68,0x0,0x69,
  0x0,0x67,0x0,0x68,0x0,0x6c,0x0,0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,0x69,0x0,0x6e,0x0,0x67,
    // syntax-addons
  0x0,0xd,
  0x5,0x71,0xe6,0xd3,
  0x0,0x73,
  0x0,0x79,0x0,0x6e,0x0,0x74,0x0,0x61,0x0,0x78,0x0,0x2d,0x0,0x61,0x0,0x64,0x0,0x64,0x0,0x6f,0x0,0x6e,0x0,0x73,
    // kdevelop-semantic-colors.xml
  0x0,0x1c,
  0x6,0xb6,0xb3,0x1c,
  0x0,0x6b,
  0x0,0x64,0x0,0x65,0x0,0x76,0x0,0x65,0x0,0x6c,0x0,0x6f,0x0,0x70,0x0,0x2d,0x0,0x73,0x0,0x65,0x0,0x6d,0x0,0x61,0x0,0x6e,0x0,0x74,0x0,0x69,0x0,0x63,
  0x0,0x2d,0x0,0x63,0x0,0x6f,0x0,0x6c,0x0,0x6f,0x0,0x72,0x0,0x73,0x0,0x2e,0x0,0x78,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9f,0xb7,0x73,0x79,0x10,
  // :/org.kde.syntax-highlighting
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9f,0xb7,0x73,0x79,0x10,
  // :/org.kde.syntax-highlighting/syntax-addons
  0x0,0x0,0x0,0x3c,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9f,0xb7,0x73,0x79,0x10,
  // :/org.kde.syntax-highlighting/syntax-addons/kdevelop-semantic-colors.xml
  0x0,0x0,0x0,0x5c,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9f,0xb7,0x73,0x79,0x10,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_syntax)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_syntax)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_syntax)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_syntax)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_syntax)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_syntax)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
