/********************************************************************************
** Form generated from reading UI file 'configwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGWIDGET_H
#define UI_CONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"
#include "KUrlRequester"
#include "util/environmentselectionwidget.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label_5;
    KUrlRequester *buildDir;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *label_6;
    KComboBox *buildAction;
    QLabel *label_10;
    QCheckBox *enableAction;
    QLabel *execLabel;
    KUrlRequester *actionExecutable;
    QLabel *argLabel;
    QLineEdit *actionArguments;
    QLabel *envLabel;
    KDevelop::EnvironmentSelectionWidget *actionEnvironment;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ConfigWidget)
    {
        if (ConfigWidget->objectName().isEmpty())
            ConfigWidget->setObjectName("ConfigWidget");
        ConfigWidget->resize(363, 244);
        verticalLayout = new QVBoxLayout(ConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_5 = new QLabel(ConfigWidget);
        label_5->setObjectName("label_5");

        horizontalLayout->addWidget(label_5);

        buildDir = new KUrlRequester(ConfigWidget);
        buildDir->setObjectName("buildDir");

        horizontalLayout->addWidget(buildDir);


        verticalLayout->addLayout(horizontalLayout);

        groupBox = new QGroupBox(ConfigWidget);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_6);

        buildAction = new KComboBox(groupBox);
        buildAction->setObjectName("buildAction");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, buildAction);

        label_10 = new QLabel(groupBox);
        label_10->setObjectName("label_10");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_10);

        enableAction = new QCheckBox(groupBox);
        enableAction->setObjectName("enableAction");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, enableAction);

        execLabel = new QLabel(groupBox);
        execLabel->setObjectName("execLabel");
        execLabel->setEnabled(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, execLabel);

        actionExecutable = new KUrlRequester(groupBox);
        actionExecutable->setObjectName("actionExecutable");
        actionExecutable->setEnabled(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, actionExecutable);

        argLabel = new QLabel(groupBox);
        argLabel->setObjectName("argLabel");
        argLabel->setEnabled(false);

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, argLabel);

        actionArguments = new QLineEdit(groupBox);
        actionArguments->setObjectName("actionArguments");
        actionArguments->setEnabled(false);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, actionArguments);

        envLabel = new QLabel(groupBox);
        envLabel->setObjectName("envLabel");
        envLabel->setEnabled(false);

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, envLabel);

        actionEnvironment = new KDevelop::EnvironmentSelectionWidget(groupBox);
        actionEnvironment->setObjectName("actionEnvironment");
        actionEnvironment->setEnabled(false);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, actionEnvironment);


        verticalLayout->addWidget(groupBox);

        verticalSpacer = new QSpacerItem(20, 76, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(ConfigWidget);
        QObject::connect(enableAction, SIGNAL(toggled(bool)), actionExecutable, SLOT(setEnabled(bool)));
        QObject::connect(enableAction, &QCheckBox::toggled, actionArguments, &QLineEdit::setEnabled);
        QObject::connect(enableAction, SIGNAL(toggled(bool)), actionEnvironment, SLOT(setEnabled(bool)));
        QObject::connect(enableAction, &QCheckBox::toggled, execLabel, &QLabel::setEnabled);
        QObject::connect(enableAction, &QCheckBox::toggled, argLabel, &QLabel::setEnabled);
        QObject::connect(enableAction, &QCheckBox::toggled, envLabel, &QLabel::setEnabled);

        QMetaObject::connectSlotsByName(ConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *ConfigWidget)
    {
        label_5->setText(tr2i18n("Build directory:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        buildDir->setToolTip(tr2i18n("Select the directory where the tools are being executed in.\n"
"If this is the same as the source directory you can leave it empty.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        buildDir->setProperty("placeholderText", QVariant(tr2i18n("The directory where the tools are executed in", "@info:placeholder")));
        buildDir->setProperty("text", QVariant(QString()));
        groupBox->setTitle(tr2i18n("Build Tools", "@title:group"));
        label_6->setText(tr2i18n("Action:", "@label:listbox"));
        label_10->setText(tr2i18n("Enable:", "@option:check"));
        enableAction->setText(QString());
        execLabel->setText(tr2i18n("Executable:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        actionExecutable->setToolTip(tr2i18n("This is the executable that should be executed when selecting the action from the Project menu", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        argLabel->setText(tr2i18n("Arguments:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        actionArguments->setToolTip(tr2i18n("The arguments that the tool needs to execute properly.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        envLabel->setText(tr2i18n("Environment:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        actionEnvironment->setToolTip(tr2i18n("Choose a pre-configured environment for your tool", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        (void)ConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class ConfigWidget: public Ui_ConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGWIDGET_H

