/********************************************************************************
** Form generated from reading UI file 'noprojectcustomincludepaths.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NOPROJECTCUSTOMINCLUDEPATHS_H
#define UI_NOPROJECTCUSTOMINCLUDEPATHS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_CustomIncludePaths
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox_2;
    QHBoxLayout *horizontalLayout_3;
    QHBoxLayout *horizontalLayout;
    KUrlRequester *storageDirectory;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QPlainTextEdit *customIncludePaths;
    QVBoxLayout *verticalLayout;
    QPushButton *directorySelector;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CustomIncludePaths)
    {
        if (CustomIncludePaths->objectName().isEmpty())
            CustomIncludePaths->setObjectName("CustomIncludePaths");
        CustomIncludePaths->resize(526, 536);
        verticalLayout_2 = new QVBoxLayout(CustomIncludePaths);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox_2 = new QGroupBox(CustomIncludePaths);
        groupBox_2->setObjectName("groupBox_2");
        horizontalLayout_3 = new QHBoxLayout(groupBox_2);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        storageDirectory = new KUrlRequester(groupBox_2);
        storageDirectory->setObjectName("storageDirectory");

        horizontalLayout->addWidget(storageDirectory);


        horizontalLayout_3->addLayout(horizontalLayout);


        verticalLayout_2->addWidget(groupBox_2);

        groupBox = new QGroupBox(CustomIncludePaths);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        customIncludePaths = new QPlainTextEdit(groupBox);
        customIncludePaths->setObjectName("customIncludePaths");

        horizontalLayout_2->addWidget(customIncludePaths);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        directorySelector = new QPushButton(groupBox);
        directorySelector->setObjectName("directorySelector");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(directorySelector->sizePolicy().hasHeightForWidth());
        directorySelector->setSizePolicy(sizePolicy);
        directorySelector->setMaximumSize(QSize(30, 30));

        verticalLayout->addWidget(directorySelector);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout_2->addLayout(verticalLayout);


        gridLayout->addLayout(horizontalLayout_2, 0, 0, 1, 1);


        verticalLayout_2->addWidget(groupBox);

        buttonBox = new QDialogButtonBox(CustomIncludePaths);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(CustomIncludePaths);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CustomIncludePaths, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CustomIncludePaths, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CustomIncludePaths);
    } // setupUi

    void retranslateUi(QDialog *CustomIncludePaths)
    {
        groupBox_2->setTitle(tr2i18n("Storage Directory:", "@title:group"));
#if QT_CONFIG(tooltip)
        storageDirectory->setToolTip(tr2i18n("The custom include-path will be stored in a special file called \".kdev_include_paths\" stored within a source directory.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        groupBox->setTitle(tr2i18n("Custom include paths or #define's", "@title:group"));
#if QT_CONFIG(tooltip)
        customIncludePaths->setToolTip(tr2i18n("The plain list of include paths. You may also define custom macros here by adding \"#define UI_NAME VALUE\" lines.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        directorySelector->setToolTip(tr2i18n("Select a directory to include.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        directorySelector->setText(tr2i18n("...", "@action:button"));
        (void)CustomIncludePaths;
    } // retranslateUi

};

namespace Ui {
    class CustomIncludePaths: public Ui_CustomIncludePaths {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NOPROJECTCUSTOMINCLUDEPATHS_H

