// This file is generated by kconfig_compiler_kf6 from projectsettings.kcfg.
// All changes you do to this file will be lost.

#include "projectsettings.h"

using namespace cppcheck;

ProjectSettings::ProjectSettings( )
  : KConfigSkeleton()
{
  setCurrentGroup( QStringLiteral( "Cppcheck" ) );

  KConfigSkeleton::ItemBool  *itemCheckStyle;
  itemCheckStyle = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "checkStyle" ), mCheckStyle, defaults::checkStyle );
  addItem( itemCheckStyle, QStringLiteral( "checkStyle" ) );
  KConfigSkeleton::ItemBool  *itemCheckPerformance;
  itemCheckPerformance = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "checkPerformance" ), mCheckPerformance, defaults::checkPerformance );
  addItem( itemCheckPerformance, QStringLiteral( "checkPerformance" ) );
  KConfigSkeleton::ItemBool  *itemCheckPortability;
  itemCheckPortability = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "checkPortability" ), mCheckPortability, defaults::checkPortability );
  addItem( itemCheckPortability, QStringLiteral( "checkPortability" ) );
  KConfigSkeleton::ItemBool  *itemCheckInformation;
  itemCheckInformation = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "checkInformation" ), mCheckInformation, defaults::checkInformation );
  addItem( itemCheckInformation, QStringLiteral( "checkInformation" ) );
  KConfigSkeleton::ItemBool  *itemCheckUnusedFunction;
  itemCheckUnusedFunction = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "checkUnusedFunction" ), mCheckUnusedFunction, defaults::checkUnusedFunction );
  addItem( itemCheckUnusedFunction, QStringLiteral( "checkUnusedFunction" ) );
  KConfigSkeleton::ItemBool  *itemCheckMissingInclude;
  itemCheckMissingInclude = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "checkMissingInclude" ), mCheckMissingInclude, defaults::checkMissingInclude );
  addItem( itemCheckMissingInclude, QStringLiteral( "checkMissingInclude" ) );
  KConfigSkeleton::ItemBool  *itemInconclusiveAnalysis;
  itemInconclusiveAnalysis = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "inconclusiveAnalysis" ), mInconclusiveAnalysis, defaults::inconclusiveAnalysis );
  addItem( itemInconclusiveAnalysis, QStringLiteral( "inconclusiveAnalysis" ) );
  KConfigSkeleton::ItemBool  *itemForceCheck;
  itemForceCheck = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "forceCheck" ), mForceCheck, defaults::forceCheck );
  addItem( itemForceCheck, QStringLiteral( "forceCheck" ) );
  KConfigSkeleton::ItemBool  *itemCheckConfig;
  itemCheckConfig = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "checkConfig" ), mCheckConfig, defaults::checkConfig );
  addItem( itemCheckConfig, QStringLiteral( "checkConfig" ) );
  KConfigSkeleton::ItemBool  *itemUseProjectIncludes;
  itemUseProjectIncludes = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "useProjectIncludes" ), mUseProjectIncludes, defaults::useProjectIncludes );
  addItem( itemUseProjectIncludes, QStringLiteral( "useProjectIncludes" ) );
  KConfigSkeleton::ItemBool  *itemUseSystemIncludes;
  itemUseSystemIncludes = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "useSystemIncludes" ), mUseSystemIncludes, defaults::useSystemIncludes );
  addItem( itemUseSystemIncludes, QStringLiteral( "useSystemIncludes" ) );
  KConfigSkeleton::ItemString  *itemIgnoredIncludes;
  itemIgnoredIncludes = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "ignoredIncludes" ), mIgnoredIncludes );
  addItem( itemIgnoredIncludes, QStringLiteral( "ignoredIncludes" ) );
  KConfigSkeleton::ItemString  *itemExtraParameters;
  itemExtraParameters = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "extraParameters" ), mExtraParameters );
  addItem( itemExtraParameters, QStringLiteral( "extraParameters" ) );
}

ProjectSettings::~ProjectSettings()
{
}

