// This file is generated by kconfig_compiler_kf6 from globalsettings.kcfg.
// All changes you do to this file will be lost.
#ifndef HEAPTRACK_GLOBALSETTINGS_H
#define HEAPTRACK_GLOBALSETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

#include "utils.h"

namespace Heaptrack {

class GlobalSettings : public KConfigSkeleton
{
  public:

    static GlobalSettings *self();
    ~GlobalSettings() override;

    /**
      Get heaptrackExecutable
    */
    static
    QString heaptrackExecutable()
    {
      return self()->mHeaptrackExecutable;
    }

    /**
      Is heaptrackExecutable Immutable
    */
    static
    bool isHeaptrackExecutableImmutable()
    {
      return self()->isImmutable( QStringLiteral( "heaptrackExecutable" ) );
    }

    /**
      Get heaptrackGuiExecutable
    */
    static
    QString heaptrackGuiExecutable()
    {
      return self()->mHeaptrackGuiExecutable;
    }

    /**
      Is heaptrackGuiExecutable Immutable
    */
    static
    bool isHeaptrackGuiExecutableImmutable()
    {
      return self()->isImmutable( QStringLiteral( "heaptrackGuiExecutable" ) );
    }

  protected:
    GlobalSettings();
    friend class GlobalSettingsHelper;


    // Heaptrack
    QString mHeaptrackExecutable;
    QString mHeaptrackGuiExecutable;
};

}

#endif

