/********************************************************************************
** Form generated from reading UI file 'grepoutputview.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GREPOUTPUTVIEW_H
#define UI_GREPOUTPUTVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"

QT_BEGIN_NAMESPACE

class Ui_GrepOutputView
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QWidget *statusbar;
    QHBoxLayout *horizontalLayout;
    KComboBox *modelSelector;
    QLabel *replacementLabel;
    KComboBox *replacementCombo;
    QPushButton *applyButton;
    QTreeView *resultsTreeView;

    void setupUi(QWidget *GrepOutputView)
    {
        if (GrepOutputView->objectName().isEmpty())
            GrepOutputView->setObjectName("GrepOutputView");
        GrepOutputView->resize(746, 300);
        gridLayout = new QGridLayout(GrepOutputView);
        gridLayout->setObjectName("gridLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        statusbar = new QWidget(GrepOutputView);
        statusbar->setObjectName("statusbar");
        horizontalLayout = new QHBoxLayout(statusbar);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName("horizontalLayout");
        modelSelector = new KComboBox(statusbar);
        modelSelector->setObjectName("modelSelector");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(5);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(modelSelector->sizePolicy().hasHeightForWidth());
        modelSelector->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(modelSelector);

        replacementLabel = new QLabel(statusbar);
        replacementLabel->setObjectName("replacementLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(replacementLabel->sizePolicy().hasHeightForWidth());
        replacementLabel->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(replacementLabel);

        replacementCombo = new KComboBox(statusbar);
        replacementCombo->setObjectName("replacementCombo");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(2);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(replacementCombo->sizePolicy().hasHeightForWidth());
        replacementCombo->setSizePolicy(sizePolicy2);
        replacementCombo->setEditable(true);

        horizontalLayout->addWidget(replacementCombo);

        applyButton = new QPushButton(statusbar);
        applyButton->setObjectName("applyButton");
        applyButton->setEnabled(false);
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(1);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(applyButton->sizePolicy().hasHeightForWidth());
        applyButton->setSizePolicy(sizePolicy3);

        horizontalLayout->addWidget(applyButton);


        verticalLayout->addWidget(statusbar);

        resultsTreeView = new QTreeView(GrepOutputView);
        resultsTreeView->setObjectName("resultsTreeView");

        verticalLayout->addWidget(resultsTreeView);


        gridLayout->addLayout(verticalLayout, 1, 0, 1, 1);

#if QT_CONFIG(shortcut)
        replacementLabel->setBuddy(replacementCombo);
#endif // QT_CONFIG(shortcut)

        retranslateUi(GrepOutputView);

        QMetaObject::connectSlotsByName(GrepOutputView);
    } // setupUi

    void retranslateUi(QWidget *GrepOutputView)
    {
        replacementLabel->setText(tr2i18n("Replacement &text:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        replacementCombo->setToolTip(tr2i18n("Enter the replacement pattern", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        applyButton->setToolTip(tr2i18n("Apply replacement on selected items", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        applyButton->setText(tr2i18n("&Replace", "@action:button"));
        (void)GrepOutputView;
    } // retranslateUi

};

namespace Ui {
    class GrepOutputView: public Ui_GrepOutputView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GREPOUTPUTVIEW_H

