/********************************************************************************
** Form generated from reading UI file 'projectvcspage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTVCSPAGE_H
#define UI_PROJECTVCSPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"

QT_BEGIN_NAMESPACE

class Ui_ProjectVcsPage
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    KComboBox *vcsTypes;
    QStackedWidget *vcsImportOptions;

    void setupUi(QWidget *ProjectVcsPage)
    {
        if (ProjectVcsPage->objectName().isEmpty())
            ProjectVcsPage->setObjectName("ProjectVcsPage");
        ProjectVcsPage->resize(559, 325);
        verticalLayout = new QVBoxLayout(ProjectVcsPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(ProjectVcsPage);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        vcsTypes = new KComboBox(ProjectVcsPage);
        vcsTypes->setObjectName("vcsTypes");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(vcsTypes->sizePolicy().hasHeightForWidth());
        vcsTypes->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(vcsTypes);


        verticalLayout->addLayout(horizontalLayout);

        vcsImportOptions = new QStackedWidget(ProjectVcsPage);
        vcsImportOptions->setObjectName("vcsImportOptions");

        verticalLayout->addWidget(vcsImportOptions);


        retranslateUi(ProjectVcsPage);

        QMetaObject::connectSlotsByName(ProjectVcsPage);
    } // setupUi

    void retranslateUi(QWidget *ProjectVcsPage)
    {
        label->setText(tr2i18n("Version control system:", "@label:listbox"));
        (void)ProjectVcsPage;
    } // retranslateUi

};

namespace Ui {
    class ProjectVcsPage: public Ui_ProjectVcsPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROJECTVCSPAGE_H

