/****************************************************************************
** Meta object code from reading C++ file 'mesonoptionbaseview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/meson/settings/mesonoptionbaseview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mesonoptionbaseview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19MesonOptionBaseViewE_t {};
} // unnamed namespace

template <> constexpr inline auto MesonOptionBaseView::qt_create_metaobjectdata<qt_meta_tag_ZN19MesonOptionBaseViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MesonOptionBaseView",
        "configChanged",
        "",
        "reset"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'configChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reset'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MesonOptionBaseView, qt_meta_tag_ZN19MesonOptionBaseViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MesonOptionBaseView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MesonOptionBaseViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MesonOptionBaseViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19MesonOptionBaseViewE_t>.metaTypes,
    nullptr
} };

void MesonOptionBaseView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MesonOptionBaseView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->configChanged(); break;
        case 1: _t->reset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MesonOptionBaseView::*)()>(_a, &MesonOptionBaseView::configChanged, 0))
            return;
    }
}

const QMetaObject *MesonOptionBaseView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MesonOptionBaseView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MesonOptionBaseViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int MesonOptionBaseView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void MesonOptionBaseView::configChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN20MesonOptionArrayViewE_t {};
} // unnamed namespace

template <> constexpr inline auto MesonOptionArrayView::qt_create_metaobjectdata<qt_meta_tag_ZN20MesonOptionArrayViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MesonOptionArrayView"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MesonOptionArrayView, qt_meta_tag_ZN20MesonOptionArrayViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MesonOptionArrayView::staticMetaObject = { {
    QMetaObject::SuperData::link<MesonOptionBaseView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20MesonOptionArrayViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20MesonOptionArrayViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20MesonOptionArrayViewE_t>.metaTypes,
    nullptr
} };

void MesonOptionArrayView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MesonOptionArrayView *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *MesonOptionArrayView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MesonOptionArrayView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20MesonOptionArrayViewE_t>.strings))
        return static_cast<void*>(this);
    return MesonOptionBaseView::qt_metacast(_clname);
}

int MesonOptionArrayView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MesonOptionBaseView::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN19MesonOptionBoolViewE_t {};
} // unnamed namespace

template <> constexpr inline auto MesonOptionBoolView::qt_create_metaobjectdata<qt_meta_tag_ZN19MesonOptionBoolViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MesonOptionBoolView",
        "updated",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'updated'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MesonOptionBoolView, qt_meta_tag_ZN19MesonOptionBoolViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MesonOptionBoolView::staticMetaObject = { {
    QMetaObject::SuperData::link<MesonOptionBaseView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MesonOptionBoolViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MesonOptionBoolViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19MesonOptionBoolViewE_t>.metaTypes,
    nullptr
} };

void MesonOptionBoolView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MesonOptionBoolView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updated(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *MesonOptionBoolView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MesonOptionBoolView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19MesonOptionBoolViewE_t>.strings))
        return static_cast<void*>(this);
    return MesonOptionBaseView::qt_metacast(_clname);
}

int MesonOptionBoolView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MesonOptionBaseView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN20MesonOptionComboViewE_t {};
} // unnamed namespace

template <> constexpr inline auto MesonOptionComboView::qt_create_metaobjectdata<qt_meta_tag_ZN20MesonOptionComboViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MesonOptionComboView",
        "updated",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'updated'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MesonOptionComboView, qt_meta_tag_ZN20MesonOptionComboViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MesonOptionComboView::staticMetaObject = { {
    QMetaObject::SuperData::link<MesonOptionBaseView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20MesonOptionComboViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20MesonOptionComboViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20MesonOptionComboViewE_t>.metaTypes,
    nullptr
} };

void MesonOptionComboView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MesonOptionComboView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updated(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *MesonOptionComboView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MesonOptionComboView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20MesonOptionComboViewE_t>.strings))
        return static_cast<void*>(this);
    return MesonOptionBaseView::qt_metacast(_clname);
}

int MesonOptionComboView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MesonOptionBaseView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN22MesonOptionIntegerViewE_t {};
} // unnamed namespace

template <> constexpr inline auto MesonOptionIntegerView::qt_create_metaobjectdata<qt_meta_tag_ZN22MesonOptionIntegerViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MesonOptionIntegerView",
        "updated",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'updated'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MesonOptionIntegerView, qt_meta_tag_ZN22MesonOptionIntegerViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MesonOptionIntegerView::staticMetaObject = { {
    QMetaObject::SuperData::link<MesonOptionBaseView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22MesonOptionIntegerViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22MesonOptionIntegerViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22MesonOptionIntegerViewE_t>.metaTypes,
    nullptr
} };

void MesonOptionIntegerView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MesonOptionIntegerView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updated(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *MesonOptionIntegerView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MesonOptionIntegerView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22MesonOptionIntegerViewE_t>.strings))
        return static_cast<void*>(this);
    return MesonOptionBaseView::qt_metacast(_clname);
}

int MesonOptionIntegerView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MesonOptionBaseView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN21MesonOptionStringViewE_t {};
} // unnamed namespace

template <> constexpr inline auto MesonOptionStringView::qt_create_metaobjectdata<qt_meta_tag_ZN21MesonOptionStringViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MesonOptionStringView",
        "updated",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'updated'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MesonOptionStringView, qt_meta_tag_ZN21MesonOptionStringViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MesonOptionStringView::staticMetaObject = { {
    QMetaObject::SuperData::link<MesonOptionBaseView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21MesonOptionStringViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21MesonOptionStringViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21MesonOptionStringViewE_t>.metaTypes,
    nullptr
} };

void MesonOptionStringView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MesonOptionStringView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updated(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *MesonOptionStringView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MesonOptionStringView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21MesonOptionStringViewE_t>.strings))
        return static_cast<void*>(this);
    return MesonOptionBaseView::qt_metacast(_clname);
}

int MesonOptionStringView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = MesonOptionBaseView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
