/********************************************************************************
** Form generated from reading UI file 'templatepage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEMPLATEPAGE_H
#define UI_TEMPLATEPAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_TemplatePage
{
public:
    QHBoxLayout *horizontalLayout;
    QTreeView *treeView;
    QVBoxLayout *buttonLayout;
    QPushButton *loadButton;
    QPushButton *extractButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *TemplatePage)
    {
        if (TemplatePage->objectName().isEmpty())
            TemplatePage->setObjectName("TemplatePage");
        TemplatePage->resize(548, 300);
        horizontalLayout = new QHBoxLayout(TemplatePage);
        horizontalLayout->setObjectName("horizontalLayout");
        treeView = new QTreeView(TemplatePage);
        treeView->setObjectName("treeView");
        treeView->header()->setVisible(false);

        horizontalLayout->addWidget(treeView);

        buttonLayout = new QVBoxLayout();
        buttonLayout->setObjectName("buttonLayout");
        loadButton = new QPushButton(TemplatePage);
        loadButton->setObjectName("loadButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("application-x-archive")));
        loadButton->setIcon(icon);

        buttonLayout->addWidget(loadButton);

        extractButton = new QPushButton(TemplatePage);
        extractButton->setObjectName("extractButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("archive-extract")));
        extractButton->setIcon(icon1);

        buttonLayout->addWidget(extractButton);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        buttonLayout->addItem(verticalSpacer);


        horizontalLayout->addLayout(buttonLayout);


        retranslateUi(TemplatePage);

        QMetaObject::connectSlotsByName(TemplatePage);
    } // setupUi

    void retranslateUi(QWidget *TemplatePage)
    {
        loadButton->setText(tr2i18n("Load Template From File", "@action:button"));
        extractButton->setText(tr2i18n("Clone Template", "@action:button"));
        (void)TemplatePage;
    } // retranslateUi

};

namespace Ui {
    class TemplatePage: public Ui_TemplatePage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TEMPLATEPAGE_H

