/****************************************************************************
** Meta object code from reading C++ file 'watcheddocumentset.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/kdevplatform/shell/watcheddocumentset.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'watcheddocumentset.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop18WatchedDocumentSetE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::WatchedDocumentSet::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop18WatchedDocumentSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::WatchedDocumentSet",
        "changed",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WatchedDocumentSet, qt_meta_tag_ZN8KDevelop18WatchedDocumentSetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::WatchedDocumentSet::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18WatchedDocumentSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18WatchedDocumentSetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop18WatchedDocumentSetE_t>.metaTypes,
    nullptr
} };

void KDevelop::WatchedDocumentSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WatchedDocumentSet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WatchedDocumentSet::*)()>(_a, &WatchedDocumentSet::changed, 0))
            return;
    }
}

const QMetaObject *KDevelop::WatchedDocumentSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::WatchedDocumentSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18WatchedDocumentSetE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDevelop::WatchedDocumentSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::WatchedDocumentSet::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN8KDevelop18CurrentDocumentSetE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::CurrentDocumentSet::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop18CurrentDocumentSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::CurrentDocumentSet"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CurrentDocumentSet, qt_meta_tag_ZN8KDevelop18CurrentDocumentSetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::CurrentDocumentSet::staticMetaObject = { {
    QMetaObject::SuperData::link<WatchedDocumentSet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18CurrentDocumentSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18CurrentDocumentSetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop18CurrentDocumentSetE_t>.metaTypes,
    nullptr
} };

void KDevelop::CurrentDocumentSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CurrentDocumentSet *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KDevelop::CurrentDocumentSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::CurrentDocumentSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18CurrentDocumentSetE_t>.strings))
        return static_cast<void*>(this);
    return WatchedDocumentSet::qt_metacast(_clname);
}

int KDevelop::CurrentDocumentSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WatchedDocumentSet::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KDevelop15OpenDocumentSetE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::OpenDocumentSet::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop15OpenDocumentSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::OpenDocumentSet",
        "documentClosed",
        "",
        "IDocument*",
        "doc",
        "documentCreated",
        "documentUrlChanged",
        "QUrl",
        "previousUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'documentClosed'
        QtMocHelpers::SlotData<void(IDocument *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'documentCreated'
        QtMocHelpers::SlotData<void(IDocument *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'documentUrlChanged'
        QtMocHelpers::SlotData<void(IDocument *, const QUrl &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OpenDocumentSet, qt_meta_tag_ZN8KDevelop15OpenDocumentSetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::OpenDocumentSet::staticMetaObject = { {
    QMetaObject::SuperData::link<WatchedDocumentSet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop15OpenDocumentSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop15OpenDocumentSetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop15OpenDocumentSetE_t>.metaTypes,
    nullptr
} };

void KDevelop::OpenDocumentSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OpenDocumentSet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->documentClosed((*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[1]))); break;
        case 1: _t->documentCreated((*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[1]))); break;
        case 2: _t->documentUrlChanged((*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *KDevelop::OpenDocumentSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::OpenDocumentSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop15OpenDocumentSetE_t>.strings))
        return static_cast<void*>(this);
    return WatchedDocumentSet::qt_metacast(_clname);
}

int KDevelop::OpenDocumentSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WatchedDocumentSet::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KDevelop10ProjectSetE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::ProjectSet::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop10ProjectSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::ProjectSet",
        "fileAdded",
        "",
        "KDevelop::ProjectFileItem*",
        "fileRemoved",
        "file",
        "fileRenamed",
        "KDevelop::Path",
        "oldFile",
        "newFile"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'fileAdded'
        QtMocHelpers::SlotData<void(KDevelop::ProjectFileItem *)>(1, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'fileRemoved'
        QtMocHelpers::SlotData<void(KDevelop::ProjectFileItem *)>(4, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 3, 5 },
        }}),
        // Slot 'fileRenamed'
        QtMocHelpers::SlotData<void(const KDevelop::Path &, KDevelop::ProjectFileItem *)>(6, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 3, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProjectSet, qt_meta_tag_ZN8KDevelop10ProjectSetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::ProjectSet::staticMetaObject = { {
    QMetaObject::SuperData::link<WatchedDocumentSet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop10ProjectSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop10ProjectSetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop10ProjectSetE_t>.metaTypes,
    nullptr
} };

void KDevelop::ProjectSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProjectSet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fileAdded((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectFileItem*>>(_a[1]))); break;
        case 1: _t->fileRemoved((*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectFileItem*>>(_a[1]))); break;
        case 2: _t->fileRenamed((*reinterpret_cast<std::add_pointer_t<KDevelop::Path>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KDevelop::ProjectFileItem*>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *KDevelop::ProjectSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::ProjectSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop10ProjectSetE_t>.strings))
        return static_cast<void*>(this);
    return WatchedDocumentSet::qt_metacast(_clname);
}

int KDevelop::ProjectSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WatchedDocumentSet::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KDevelop17CurrentProjectSetE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::CurrentProjectSet::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop17CurrentProjectSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::CurrentProjectSet"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CurrentProjectSet, qt_meta_tag_ZN8KDevelop17CurrentProjectSetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::CurrentProjectSet::staticMetaObject = { {
    QMetaObject::SuperData::link<ProjectSet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop17CurrentProjectSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop17CurrentProjectSetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop17CurrentProjectSetE_t>.metaTypes,
    nullptr
} };

void KDevelop::CurrentProjectSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CurrentProjectSet *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KDevelop::CurrentProjectSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::CurrentProjectSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop17CurrentProjectSetE_t>.strings))
        return static_cast<void*>(this);
    return ProjectSet::qt_metacast(_clname);
}

int KDevelop::CurrentProjectSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ProjectSet::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KDevelop13AllProjectSetE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::AllProjectSet::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop13AllProjectSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::AllProjectSet"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AllProjectSet, qt_meta_tag_ZN8KDevelop13AllProjectSetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::AllProjectSet::staticMetaObject = { {
    QMetaObject::SuperData::link<ProjectSet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop13AllProjectSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop13AllProjectSetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop13AllProjectSetE_t>.metaTypes,
    nullptr
} };

void KDevelop::AllProjectSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AllProjectSet *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KDevelop::AllProjectSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::AllProjectSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop13AllProjectSetE_t>.strings))
        return static_cast<void*>(this);
    return ProjectSet::qt_metacast(_clname);
}

int KDevelop::AllProjectSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ProjectSet::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KDevelop18DocumentsInPathSetE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::DocumentsInPathSet::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop18DocumentsInPathSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::DocumentsInPathSet"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DocumentsInPathSet, qt_meta_tag_ZN8KDevelop18DocumentsInPathSetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::DocumentsInPathSet::staticMetaObject = { {
    QMetaObject::SuperData::link<AllProjectSet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18DocumentsInPathSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18DocumentsInPathSetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop18DocumentsInPathSetE_t>.metaTypes,
    nullptr
} };

void KDevelop::DocumentsInPathSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DocumentsInPathSet *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KDevelop::DocumentsInPathSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::DocumentsInPathSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop18DocumentsInPathSetE_t>.strings))
        return static_cast<void*>(this);
    return AllProjectSet::qt_metacast(_clname);
}

int KDevelop::DocumentsInPathSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AllProjectSet::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KDevelop25DocumentsInCurrentPathSetE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::DocumentsInCurrentPathSet::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop25DocumentsInCurrentPathSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::DocumentsInCurrentPathSet"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DocumentsInCurrentPathSet, qt_meta_tag_ZN8KDevelop25DocumentsInCurrentPathSetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::DocumentsInCurrentPathSet::staticMetaObject = { {
    QMetaObject::SuperData::link<DocumentsInPathSet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop25DocumentsInCurrentPathSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop25DocumentsInCurrentPathSetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop25DocumentsInCurrentPathSetE_t>.metaTypes,
    nullptr
} };

void KDevelop::DocumentsInCurrentPathSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DocumentsInCurrentPathSet *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KDevelop::DocumentsInCurrentPathSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::DocumentsInCurrentPathSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop25DocumentsInCurrentPathSetE_t>.strings))
        return static_cast<void*>(this);
    return DocumentsInPathSet::qt_metacast(_clname);
}

int KDevelop::DocumentsInCurrentPathSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DocumentsInPathSet::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN8KDevelop9BypassSetE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::BypassSet::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop9BypassSetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::BypassSet"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<BypassSet, qt_meta_tag_ZN8KDevelop9BypassSetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::BypassSet::staticMetaObject = { {
    QMetaObject::SuperData::link<WatchedDocumentSet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop9BypassSetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop9BypassSetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop9BypassSetE_t>.metaTypes,
    nullptr
} };

void KDevelop::BypassSet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BypassSet *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KDevelop::BypassSet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::BypassSet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop9BypassSetE_t>.strings))
        return static_cast<void*>(this);
    return WatchedDocumentSet::qt_metacast(_clname);
}

int KDevelop::BypassSet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = WatchedDocumentSet::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
