/****************************************************************************
** Meta object code from reading C++ file 'quickopenplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/quickopen/quickopenplugin.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'quickopenplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15QuickOpenPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto QuickOpenPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN15QuickOpenPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QuickOpenPlugin",
        "quickOpen",
        "",
        "quickOpenFile",
        "quickOpenFunction",
        "quickOpenClass",
        "quickOpenDeclaration",
        "quickOpenOpenFile",
        "quickOpenDefinition",
        "quickOpenNavigateFunctions",
        "quickOpenDocumentation",
        "quickOpenActions",
        "previousFunction",
        "nextFunction",
        "storeScopes",
        "storeItems"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'quickOpen'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quickOpenFile'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quickOpenFunction'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quickOpenClass'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quickOpenDeclaration'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quickOpenOpenFile'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quickOpenDefinition'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quickOpenNavigateFunctions'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quickOpenDocumentation'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'quickOpenActions'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'previousFunction'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'nextFunction'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'storeScopes'
        QtMocHelpers::SlotData<void(const QStringList &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 2 },
        }}),
        // Slot 'storeItems'
        QtMocHelpers::SlotData<void(const QStringList &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QuickOpenPlugin, qt_meta_tag_ZN15QuickOpenPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QuickOpenPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<KDevelop::IPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QuickOpenPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QuickOpenPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15QuickOpenPluginE_t>.metaTypes,
    nullptr
} };

void QuickOpenPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QuickOpenPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->quickOpen(); break;
        case 1: _t->quickOpenFile(); break;
        case 2: _t->quickOpenFunction(); break;
        case 3: _t->quickOpenClass(); break;
        case 4: _t->quickOpenDeclaration(); break;
        case 5: _t->quickOpenOpenFile(); break;
        case 6: _t->quickOpenDefinition(); break;
        case 7: _t->quickOpenNavigateFunctions(); break;
        case 8: _t->quickOpenDocumentation(); break;
        case 9: _t->quickOpenActions(); break;
        case 10: _t->previousFunction(); break;
        case 11: _t->nextFunction(); break;
        case 12: _t->storeScopes((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 13: _t->storeItems((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *QuickOpenPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QuickOpenPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15QuickOpenPluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KDevelop::IQuickOpen"))
        return static_cast< KDevelop::IQuickOpen*>(this);
    if (!strcmp(_clname, "org.kdevelop.IQuickOpen"))
        return static_cast< KDevelop::IQuickOpen*>(this);
    return KDevelop::IPlugin::qt_metacast(_clname);
}

int QuickOpenPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDevelop::IPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN17QuickOpenLineEditE_t {};
} // unnamed namespace

template <> constexpr inline auto QuickOpenLineEdit::qt_create_metaobjectdata<qt_meta_tag_ZN17QuickOpenLineEditE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "QuickOpenLineEdit",
        "activate",
        "",
        "deactivate",
        "checkFocus",
        "widgetDestroyed"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'activate'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deactivate'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkFocus'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'widgetDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<QuickOpenLineEdit, qt_meta_tag_ZN17QuickOpenLineEditE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject QuickOpenLineEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QLineEdit::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QuickOpenLineEditE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QuickOpenLineEditE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17QuickOpenLineEditE_t>.metaTypes,
    nullptr
} };

void QuickOpenLineEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QuickOpenLineEdit *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activate(); break;
        case 1: _t->deactivate(); break;
        case 2: _t->checkFocus(); break;
        case 3: _t->widgetDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *QuickOpenLineEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QuickOpenLineEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17QuickOpenLineEditE_t>.strings))
        return static_cast<void*>(this);
    return QLineEdit::qt_metacast(_clname);
}

int QuickOpenLineEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLineEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
