// This file is generated by kconfig_compiler_kf6 from dockerpreferencessettings.kcfg.
// All changes you do to this file will be lost.
#ifndef DOCKERPREFERENCESSETTINGS_H
#define DOCKERPREFERENCESSETTINGS_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class DockerPreferencesSettings : public KConfigSkeleton
{
  public:

    DockerPreferencesSettings( );
    ~DockerPreferencesSettings() override;

    /**
      Get extraArguments
    */
    QString extraArguments() const
    {
      return mExtraArguments;
    }

    /**
      Is extraArguments Immutable
    */
    bool isExtraArgumentsImmutable() const
    {
      return isImmutable( QStringLiteral( "extraArguments" ) );
    }

    /**
      Get projectsVolume
    */
    QString projectsVolume() const
    {
      return mProjectsVolume;
    }

    /**
      Is projectsVolume Immutable
    */
    bool isProjectsVolumeImmutable() const
    {
      return isImmutable( QStringLiteral( "projectsVolume" ) );
    }

    /**
      Get buildDirsVolume
    */
    QString buildDirsVolume() const
    {
      return mBuildDirsVolume;
    }

    /**
      Is buildDirsVolume Immutable
    */
    bool isBuildDirsVolumeImmutable() const
    {
      return isImmutable( QStringLiteral( "buildDirsVolume" ) );
    }

  protected:

    // Docker
    QString mExtraArguments;
    QString mProjectsVolume;
    QString mBuildDirsVolume;
};

#endif

