/********************************************************************************
** Form generated from reading UI file 'ssltrustdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SSLTRUSTDIALOG_H
#define UI_SSLTRUSTDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SvnSSLTrustDialog
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *msgLabel;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout1;
    QTextBrowser *reasons;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *hostname;
    QLabel *label_2;
    QLabel *issuer;
    QLabel *label_3;
    QLabel *validFrom;
    QLabel *label_4;
    QLabel *validUntil;
    QLabel *label_5;
    QLabel *fingerprint;

    void setupUi(QWidget *SvnSSLTrustDialog)
    {
        if (SvnSSLTrustDialog->objectName().isEmpty())
            SvnSSLTrustDialog->setObjectName("SvnSSLTrustDialog");
        SvnSSLTrustDialog->resize(578, 500);
        vboxLayout = new QVBoxLayout(SvnSSLTrustDialog);
        vboxLayout->setObjectName("vboxLayout");
        msgLabel = new QLabel(SvnSSLTrustDialog);
        msgLabel->setObjectName("msgLabel");

        vboxLayout->addWidget(msgLabel);

        groupBox = new QGroupBox(SvnSSLTrustDialog);
        groupBox->setObjectName("groupBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox->sizePolicy().hasHeightForWidth());
        groupBox->setSizePolicy(sizePolicy);
        vboxLayout1 = new QVBoxLayout(groupBox);
        vboxLayout1->setObjectName("vboxLayout1");
        reasons = new QTextBrowser(groupBox);
        reasons->setObjectName("reasons");
        reasons->setOverwriteMode(false);
        reasons->setTextInteractionFlags(Qt::NoTextInteraction);
        reasons->setOpenLinks(false);

        vboxLayout1->addWidget(reasons);


        vboxLayout->addWidget(groupBox);

        groupBox_2 = new QGroupBox(SvnSSLTrustDialog);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setHorizontalSpacing(12);
        gridLayout->setVerticalSpacing(9);
        label = new QLabel(groupBox_2);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        hostname = new QLabel(groupBox_2);
        hostname->setObjectName("hostname");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(hostname->sizePolicy().hasHeightForWidth());
        hostname->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(hostname, 0, 1, 1, 1);

        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 0, 1, 1);

        issuer = new QLabel(groupBox_2);
        issuer->setObjectName("issuer");
        sizePolicy1.setHeightForWidth(issuer->sizePolicy().hasHeightForWidth());
        issuer->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(issuer, 1, 1, 1, 1);

        label_3 = new QLabel(groupBox_2);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        validFrom = new QLabel(groupBox_2);
        validFrom->setObjectName("validFrom");
        sizePolicy1.setHeightForWidth(validFrom->sizePolicy().hasHeightForWidth());
        validFrom->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(validFrom, 2, 1, 1, 1);

        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 3, 0, 1, 1);

        validUntil = new QLabel(groupBox_2);
        validUntil->setObjectName("validUntil");
        sizePolicy1.setHeightForWidth(validUntil->sizePolicy().hasHeightForWidth());
        validUntil->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(validUntil, 3, 1, 1, 1);

        label_5 = new QLabel(groupBox_2);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 4, 0, 1, 1);

        fingerprint = new QLabel(groupBox_2);
        fingerprint->setObjectName("fingerprint");
        sizePolicy1.setHeightForWidth(fingerprint->sizePolicy().hasHeightForWidth());
        fingerprint->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(fingerprint, 4, 1, 1, 1);


        vboxLayout->addWidget(groupBox_2);


        retranslateUi(SvnSSLTrustDialog);

        QMetaObject::connectSlotsByName(SvnSSLTrustDialog);
    } // setupUi

    void retranslateUi(QWidget *SvnSSLTrustDialog)
    {
        msgLabel->setText(tr2i18n("There were errors validating the server certificate.\n"
"Do you want to trust this certificate?", nullptr));
        groupBox->setTitle(tr2i18n("Reasons why the validation failed", nullptr));
        groupBox_2->setTitle(tr2i18n("Certificate Information", "@title:group"));
        label->setText(tr2i18n("Hostname:", "@label:textbox"));
        hostname->setText(tr2i18n("someserver", nullptr));
        label_2->setText(tr2i18n("Issuer:", "@label:textbox"));
        issuer->setText(tr2i18n("someissuer", nullptr));
        label_3->setText(tr2i18n("Valid from:", "@label:textbox"));
        validFrom->setText(tr2i18n("validfrom", nullptr));
        label_4->setText(tr2i18n("Valid until:", "@label:textbox"));
        validUntil->setText(tr2i18n("validuntil", nullptr));
        label_5->setText(tr2i18n("Fingerprint:", "@label:textbox"));
        fingerprint->setText(tr2i18n("fingerprint", nullptr));
        (void)SvnSSLTrustDialog;
    } // retranslateUi

};

namespace Ui {
    class SvnSSLTrustDialog: public Ui_SvnSSLTrustDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SSLTRUSTDIALOG_H

