/********************************************************************************
** Form generated from reading UI file 'launchconfigurationdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LAUNCHCONFIGURATIONDIALOG_H
#define UI_LAUNCHCONFIGURATIONDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KMessageWidget"

QT_BEGIN_NAMESPACE

class Ui_LaunchConfigurationDialog
{
public:
    QVBoxLayout *verticalLayout;
    QSplitter *splitter;
    QWidget *layoutWidget;
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    QPushButton *addConfig;
    QPushButton *deleteConfig;
    QSpacerItem *horizontalSpacer;
    QTreeView *tree;
    QWidget *layoutWidget_2;
    QGridLayout *gridLayout_2;
    QLabel *debugLabel;
    QComboBox *debugger;
    QLabel *configName;
    QStackedWidget *stack;
    KMessageWidget *messageWidget;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *LaunchConfigurationDialog)
    {
        if (LaunchConfigurationDialog->objectName().isEmpty())
            LaunchConfigurationDialog->setObjectName("LaunchConfigurationDialog");
        LaunchConfigurationDialog->resize(643, 530);
        verticalLayout = new QVBoxLayout(LaunchConfigurationDialog);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        splitter = new QSplitter(LaunchConfigurationDialog);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        layoutWidget = new QWidget(splitter);
        layoutWidget->setObjectName("layoutWidget");
        vboxLayout = new QVBoxLayout(layoutWidget);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        addConfig = new QPushButton(layoutWidget);
        addConfig->setObjectName("addConfig");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addConfig->setIcon(icon);

        hboxLayout->addWidget(addConfig);

        deleteConfig = new QPushButton(layoutWidget);
        deleteConfig->setObjectName("deleteConfig");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        deleteConfig->setIcon(icon1);

        hboxLayout->addWidget(deleteConfig);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        hboxLayout->addItem(horizontalSpacer);


        vboxLayout->addLayout(hboxLayout);

        tree = new QTreeView(layoutWidget);
        tree->setObjectName("tree");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tree->sizePolicy().hasHeightForWidth());
        tree->setSizePolicy(sizePolicy);
        tree->setRootIsDecorated(false);
        tree->header()->setVisible(false);

        vboxLayout->addWidget(tree);

        splitter->addWidget(layoutWidget);
        layoutWidget_2 = new QWidget(splitter);
        layoutWidget_2->setObjectName("layoutWidget_2");
        gridLayout_2 = new QGridLayout(layoutWidget_2);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        debugLabel = new QLabel(layoutWidget_2);
        debugLabel->setObjectName("debugLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(debugLabel->sizePolicy().hasHeightForWidth());
        debugLabel->setSizePolicy(sizePolicy1);

        gridLayout_2->addWidget(debugLabel, 0, 1, 1, 1);

        debugger = new QComboBox(layoutWidget_2);
        debugger->setObjectName("debugger");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(debugger->sizePolicy().hasHeightForWidth());
        debugger->setSizePolicy(sizePolicy2);

        gridLayout_2->addWidget(debugger, 0, 2, 1, 1);

        configName = new QLabel(layoutWidget_2);
        configName->setObjectName("configName");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(configName->sizePolicy().hasHeightForWidth());
        configName->setSizePolicy(sizePolicy3);
        configName->setLineWidth(1);

        gridLayout_2->addWidget(configName, 0, 0, 1, 1);

        stack = new QStackedWidget(layoutWidget_2);
        stack->setObjectName("stack");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy4.setHorizontalStretch(2);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(stack->sizePolicy().hasHeightForWidth());
        stack->setSizePolicy(sizePolicy4);

        gridLayout_2->addWidget(stack, 1, 0, 1, 3);

        splitter->addWidget(layoutWidget_2);

        verticalLayout->addWidget(splitter);

        messageWidget = new KMessageWidget(LaunchConfigurationDialog);
        messageWidget->setObjectName("messageWidget");

        verticalLayout->addWidget(messageWidget);

        buttonBox = new QDialogButtonBox(LaunchConfigurationDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(LaunchConfigurationDialog);

        QMetaObject::connectSlotsByName(LaunchConfigurationDialog);
    } // setupUi

    void retranslateUi(QWidget *LaunchConfigurationDialog)
    {
        addConfig->setText(tr2i18n("Add", "@action:button"));
        deleteConfig->setText(tr2i18n("Remove", "@action:button"));
        debugLabel->setText(tr2i18n("Debugger:", "@label:listbox"));
        configName->setText(tr2i18n("Name", nullptr));
        (void)LaunchConfigurationDialog;
    } // retranslateUi

};

namespace Ui {
    class LaunchConfigurationDialog: public Ui_LaunchConfigurationDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LAUNCHCONFIGURATIONDIALOG_H

