/****************************************************************************
** Meta object code from reading C++ file 'midebugsession.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/debuggercommon/midebugsession.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'midebugsession.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6KDevMI14MIDebugSessionE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevMI::MIDebugSession::qt_create_metaobjectdata<qt_meta_tag_ZN6KDevMI14MIDebugSessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevMI::MIDebugSession",
        "inferiorStdoutLines",
        "",
        "lines",
        "inferiorStderrLines",
        "inferiorStopped",
        "MI::AsyncRecord",
        "r",
        "inferiorRunning",
        "debuggerUserCommandOutput",
        "output",
        "debuggerInternalCommandOutput",
        "debuggerInternalOutput",
        "debuggerStateChanged",
        "DBGStateFlags",
        "oldState",
        "newState",
        "showMessage",
        "message",
        "timeout",
        "raiseDebuggerConsoleViews",
        "restartDebugger",
        "stopDebugger",
        "killDebuggerNow",
        "interruptDebugger",
        "run",
        "runToCursor",
        "jumpToCursor",
        "stepOver",
        "stepIntoInstruction",
        "stepInto",
        "stepOverInstruction",
        "stepOut",
        "runUntil",
        "QUrl",
        "url",
        "line",
        "address",
        "jumpTo",
        "jumpToMemoryAddress",
        "startDebugging",
        "KDevelop::ILaunchConfiguration*",
        "cfg",
        "IExecutePlugin*",
        "iexec",
        "examineCoreFile",
        "debugee",
        "coreFile",
        "attachToProcess",
        "pid",
        "slotDebuggerReady",
        "slotDebuggerExited",
        "abnormal",
        "msg",
        "slotInferiorStopped",
        "slotInferiorRunning",
        "processNotification",
        "n",
        "defaultErrorHandler",
        "MI::ResultRecord",
        "result",
        "handleDebuggerStateChange",
        "handleTargetAttach",
        "explainDebuggerStatus"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'inferiorStdoutLines'
        QtMocHelpers::SignalData<void(const QStringList &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'inferiorStderrLines'
        QtMocHelpers::SignalData<void(const QStringList &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 3 },
        }}),
        // Signal 'inferiorStopped'
        QtMocHelpers::SignalData<void(const MI::AsyncRecord &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'inferiorRunning'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'debuggerUserCommandOutput'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'debuggerInternalCommandOutput'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'debuggerInternalOutput'
        QtMocHelpers::SignalData<void(const QString &) const>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Signal 'debuggerStateChanged'
        QtMocHelpers::SignalData<void(DBGStateFlags, DBGStateFlags)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 14, 16 },
        }}),
        // Signal 'showMessage'
        QtMocHelpers::SignalData<void(const QString &, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 }, { QMetaType::Int, 19 },
        }}),
        // Signal 'raiseDebuggerConsoleViews'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'restartDebugger'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stopDebugger'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'killDebuggerNow'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'interruptDebugger'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'run'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'runToCursor'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'jumpToCursor'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stepOver'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stepIntoInstruction'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stepInto'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stepOverInstruction'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stepOut'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'runUntil'
        QtMocHelpers::SlotData<void(const QUrl &, int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 }, { QMetaType::Int, 36 },
        }}),
        // Slot 'runUntil'
        QtMocHelpers::SlotData<void(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'jumpTo'
        QtMocHelpers::SlotData<void(const QUrl &, int)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 35 }, { QMetaType::Int, 36 },
        }}),
        // Slot 'jumpToMemoryAddress'
        QtMocHelpers::SlotData<void(const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 37 },
        }}),
        // Slot 'startDebugging'
        QtMocHelpers::SlotData<bool(KDevelop::ILaunchConfiguration *, IExecutePlugin *)>(40, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 41, 42 }, { 0x80000000 | 43, 44 },
        }}),
        // Slot 'examineCoreFile'
        QtMocHelpers::SlotData<bool(const QUrl &, const QUrl &)>(45, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 34, 46 }, { 0x80000000 | 34, 47 },
        }}),
        // Slot 'attachToProcess'
        QtMocHelpers::SlotData<bool(int)>(48, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 49 },
        }}),
        // Slot 'slotDebuggerReady'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotDebuggerExited'
        QtMocHelpers::SlotData<void(bool, const QString &)>(51, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 52 }, { QMetaType::QString, 53 },
        }}),
        // Slot 'slotInferiorStopped'
        QtMocHelpers::SlotData<void(const MI::AsyncRecord &)>(54, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'slotInferiorRunning'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'processNotification'
        QtMocHelpers::SlotData<void(const MI::AsyncRecord &)>(56, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 6, 57 },
        }}),
        // Slot 'defaultErrorHandler'
        QtMocHelpers::SlotData<void(const MI::ResultRecord &)>(58, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'handleDebuggerStateChange'
        QtMocHelpers::SlotData<void(DBGStateFlags, DBGStateFlags)>(61, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 14, 16 },
        }}),
        // Slot 'handleTargetAttach'
        QtMocHelpers::SlotData<void(const MI::ResultRecord &)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 59, 7 },
        }}),
        // Slot 'explainDebuggerStatus'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MIDebugSession, qt_meta_tag_ZN6KDevMI14MIDebugSessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevMI::MIDebugSession::staticMetaObject = { {
    QMetaObject::SuperData::link<KDevelop::IDebugSession::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KDevMI14MIDebugSessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KDevMI14MIDebugSessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6KDevMI14MIDebugSessionE_t>.metaTypes,
    nullptr
} };

void KDevMI::MIDebugSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MIDebugSession *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->inferiorStdoutLines((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 1: _t->inferiorStderrLines((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->inferiorStopped((*reinterpret_cast<std::add_pointer_t<MI::AsyncRecord>>(_a[1]))); break;
        case 3: _t->inferiorRunning(); break;
        case 4: _t->debuggerUserCommandOutput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->debuggerInternalCommandOutput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->debuggerInternalOutput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->debuggerStateChanged((*reinterpret_cast<std::add_pointer_t<DBGStateFlags>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DBGStateFlags>>(_a[2]))); break;
        case 8: _t->showMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->raiseDebuggerConsoleViews(); break;
        case 10: _t->restartDebugger(); break;
        case 11: _t->stopDebugger(); break;
        case 12: _t->killDebuggerNow(); break;
        case 13: _t->interruptDebugger(); break;
        case 14: _t->run(); break;
        case 15: _t->runToCursor(); break;
        case 16: _t->jumpToCursor(); break;
        case 17: _t->stepOver(); break;
        case 18: _t->stepIntoInstruction(); break;
        case 19: _t->stepInto(); break;
        case 20: _t->stepOverInstruction(); break;
        case 21: _t->stepOut(); break;
        case 22: _t->runUntil((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 23: _t->runUntil((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->jumpTo((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 25: _t->jumpToMemoryAddress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: { bool _r = _t->startDebugging((*reinterpret_cast<std::add_pointer_t<KDevelop::ILaunchConfiguration*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<IExecutePlugin*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->examineCoreFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->attachToProcess((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: _t->slotDebuggerReady(); break;
        case 30: _t->slotDebuggerExited((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 31: _t->slotInferiorStopped((*reinterpret_cast<std::add_pointer_t<MI::AsyncRecord>>(_a[1]))); break;
        case 32: _t->slotInferiorRunning(); break;
        case 33: _t->processNotification((*reinterpret_cast<std::add_pointer_t<MI::AsyncRecord>>(_a[1]))); break;
        case 34: _t->defaultErrorHandler((*reinterpret_cast<std::add_pointer_t<MI::ResultRecord>>(_a[1]))); break;
        case 35: _t->handleDebuggerStateChange((*reinterpret_cast<std::add_pointer_t<DBGStateFlags>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<DBGStateFlags>>(_a[2]))); break;
        case 36: _t->handleTargetAttach((*reinterpret_cast<std::add_pointer_t<MI::ResultRecord>>(_a[1]))); break;
        case 37: _t->explainDebuggerStatus(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MIDebugSession::*)(const QStringList & )>(_a, &MIDebugSession::inferiorStdoutLines, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugSession::*)(const QStringList & )>(_a, &MIDebugSession::inferiorStderrLines, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugSession::*)(const MI::AsyncRecord & )>(_a, &MIDebugSession::inferiorStopped, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugSession::*)()>(_a, &MIDebugSession::inferiorRunning, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugSession::*)(const QString & )>(_a, &MIDebugSession::debuggerUserCommandOutput, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugSession::*)(const QString & )>(_a, &MIDebugSession::debuggerInternalCommandOutput, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugSession::*)(const QString & ) const>(_a, &MIDebugSession::debuggerInternalOutput, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugSession::*)(DBGStateFlags , DBGStateFlags )>(_a, &MIDebugSession::debuggerStateChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugSession::*)(const QString & , int )>(_a, &MIDebugSession::showMessage, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugSession::*)()>(_a, &MIDebugSession::raiseDebuggerConsoleViews, 9))
            return;
    }
}

const QMetaObject *KDevMI::MIDebugSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevMI::MIDebugSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KDevMI14MIDebugSessionE_t>.strings))
        return static_cast<void*>(this);
    return KDevelop::IDebugSession::qt_metacast(_clname);
}

int KDevMI::MIDebugSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDevelop::IDebugSession::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 38)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 38;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 38)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 38;
    }
    return _id;
}

// SIGNAL 0
void KDevMI::MIDebugSession::inferiorStdoutLines(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDevMI::MIDebugSession::inferiorStderrLines(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KDevMI::MIDebugSession::inferiorStopped(const MI::AsyncRecord & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KDevMI::MIDebugSession::inferiorRunning()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KDevMI::MIDebugSession::debuggerUserCommandOutput(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KDevMI::MIDebugSession::debuggerInternalCommandOutput(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KDevMI::MIDebugSession::debuggerInternalOutput(const QString & _t1)const
{
    QMetaObject::activate<void>(const_cast< KDevMI::MIDebugSession *>(this), &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KDevMI::MIDebugSession::debuggerStateChanged(DBGStateFlags _t1, DBGStateFlags _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void KDevMI::MIDebugSession::showMessage(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void KDevMI::MIDebugSession::raiseDebuggerConsoleViews()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
