/********************************************************************************
** Form generated from reading UI file 'environmentwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ENVIRONMENTWIDGET_H
#define UI_ENVIRONMENTWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"

QT_BEGIN_NAMESPACE

class Ui_EnvironmentWidget
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    KComboBox *profileSelect;
    QPushButton *addProfileButton;
    QPushButton *cloneProfileButton;
    QPushButton *removeProfileButton;
    QPushButton *setAsDefaultProfileButton;
    QTableView *variableTable;
    QVBoxLayout *verticalLayout;
    QPushButton *removeVariableButton;
    QPushButton *batchModeEditButton;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *EnvironmentWidget)
    {
        if (EnvironmentWidget->objectName().isEmpty())
            EnvironmentWidget->setObjectName("EnvironmentWidget");
        EnvironmentWidget->resize(704, 480);
        gridLayout = new QGridLayout(EnvironmentWidget);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(EnvironmentWidget);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        profileSelect = new KComboBox(EnvironmentWidget);
        profileSelect->setObjectName("profileSelect");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(profileSelect->sizePolicy().hasHeightForWidth());
        profileSelect->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(profileSelect);

        addProfileButton = new QPushButton(EnvironmentWidget);
        addProfileButton->setObjectName("addProfileButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addProfileButton->setIcon(icon);

        horizontalLayout->addWidget(addProfileButton);

        cloneProfileButton = new QPushButton(EnvironmentWidget);
        cloneProfileButton->setObjectName("cloneProfileButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-clone")));
        cloneProfileButton->setIcon(icon1);

        horizontalLayout->addWidget(cloneProfileButton);

        removeProfileButton = new QPushButton(EnvironmentWidget);
        removeProfileButton->setObjectName("removeProfileButton");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        removeProfileButton->setIcon(icon2);

        horizontalLayout->addWidget(removeProfileButton);

        setAsDefaultProfileButton = new QPushButton(EnvironmentWidget);
        setAsDefaultProfileButton->setObjectName("setAsDefaultProfileButton");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("starred-symbolic")));
        setAsDefaultProfileButton->setIcon(icon3);

        horizontalLayout->addWidget(setAsDefaultProfileButton);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        variableTable = new QTableView(EnvironmentWidget);
        variableTable->setObjectName("variableTable");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(2);
        sizePolicy1.setHeightForWidth(variableTable->sizePolicy().hasHeightForWidth());
        variableTable->setSizePolicy(sizePolicy1);
        variableTable->setSelectionMode(QAbstractItemView::ExtendedSelection);
        variableTable->setSelectionBehavior(QAbstractItemView::SelectRows);
        variableTable->setSortingEnabled(true);
        variableTable->setCornerButtonEnabled(false);
        variableTable->verticalHeader()->setVisible(false);

        gridLayout->addWidget(variableTable, 1, 0, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        removeVariableButton = new QPushButton(EnvironmentWidget);
        removeVariableButton->setObjectName("removeVariableButton");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(removeVariableButton->sizePolicy().hasHeightForWidth());
        removeVariableButton->setSizePolicy(sizePolicy2);
        removeVariableButton->setIcon(icon2);

        verticalLayout->addWidget(removeVariableButton);

        batchModeEditButton = new QPushButton(EnvironmentWidget);
        batchModeEditButton->setObjectName("batchModeEditButton");
        sizePolicy2.setHeightForWidth(batchModeEditButton->sizePolicy().hasHeightForWidth());
        batchModeEditButton->setSizePolicy(sizePolicy2);
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("format-list-unordered")));
        batchModeEditButton->setIcon(icon4);

        verticalLayout->addWidget(batchModeEditButton);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);


        gridLayout->addLayout(verticalLayout, 1, 1, 1, 1);


        retranslateUi(EnvironmentWidget);

        QMetaObject::connectSlotsByName(EnvironmentWidget);
    } // setupUi

    void retranslateUi(QWidget *EnvironmentWidget)
    {
        label->setText(tr2i18n("Environment profile:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        addProfileButton->setToolTip(tr2i18n("Add profile...", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        cloneProfileButton->setToolTip(tr2i18n("Clone profile...", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        removeProfileButton->setToolTip(tr2i18n("Remove profile", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        setAsDefaultProfileButton->setToolTip(tr2i18n("Set as default", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        removeVariableButton->setToolTip(tr2i18n("Remove variable", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        batchModeEditButton->setToolTip(tr2i18n("Batch edit mode", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        (void)EnvironmentWidget;
    } // retranslateUi

};

namespace Ui {
    class EnvironmentWidget: public Ui_EnvironmentWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ENVIRONMENTWIDGET_H

