/********************************************************************************
** Form generated from reading UI file 'vcscommitdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VCSCOMMITDIALOG_H
#define UI_VCSCOMMITDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_VcsCommitDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    QTreeView *files;
    QDialogButtonBox *buttonBox;

    void setupUi(QWidget *VcsCommitDialog)
    {
        if (VcsCommitDialog->objectName().isEmpty())
            VcsCommitDialog->setObjectName("VcsCommitDialog");
        VcsCommitDialog->setProperty("modal", QVariant(false));
        VcsCommitDialog->resize(497, 432);
        verticalLayout = new QVBoxLayout(VcsCommitDialog);
        verticalLayout->setObjectName("verticalLayout");
        label_2 = new QLabel(VcsCommitDialog);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        verticalLayout->addWidget(label_2);

        files = new QTreeView(VcsCommitDialog);
        files->setObjectName("files");
        files->setEditTriggers(QAbstractItemView::NoEditTriggers);
        files->setRootIsDecorated(false);
        files->setUniformRowHeights(true);

        verticalLayout->addWidget(files);

        buttonBox = new QDialogButtonBox(VcsCommitDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(VcsCommitDialog);

        QMetaObject::connectSlotsByName(VcsCommitDialog);
    } // setupUi

    void retranslateUi(QWidget *VcsCommitDialog)
    {
        VcsCommitDialog->setWindowTitle(tr2i18n("Select Files to Commit", "@title:window"));
        label_2->setText(tr2i18n("Commit files:", "@label:listbox"));
    } // retranslateUi

};

namespace Ui {
    class VcsCommitDialog: public Ui_VcsCommitDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VCSCOMMITDIALOG_H

