/********************************************************************************
** Form generated from reading UI file 'selectcoredialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SELECTCOREDIALOG_H
#define UI_SELECTCOREDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "KMessageWidget"
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_SelectCoreDialog
{
public:
    QVBoxLayout *vboxLayout;
    QFormLayout *formLayout;
    QLabel *label;
    KUrlRequester *executableFile;
    QLabel *label_2;
    KUrlRequester *coreFile;
    KMessageWidget *selectionValidWidget;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SelectCoreDialog)
    {
        if (SelectCoreDialog->objectName().isEmpty())
            SelectCoreDialog->setObjectName("SelectCoreDialog");
        SelectCoreDialog->resize(442, 173);
        vboxLayout = new QVBoxLayout(SelectCoreDialog);
        vboxLayout->setObjectName("vboxLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        label = new QLabel(SelectCoreDialog);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        executableFile = new KUrlRequester(SelectCoreDialog);
        executableFile->setObjectName("executableFile");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, executableFile);

        label_2 = new QLabel(SelectCoreDialog);
        label_2->setObjectName("label_2");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_2);

        coreFile = new KUrlRequester(SelectCoreDialog);
        coreFile->setObjectName("coreFile");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, coreFile);


        vboxLayout->addLayout(formLayout);

        selectionValidWidget = new KMessageWidget(SelectCoreDialog);
        selectionValidWidget->setObjectName("selectionValidWidget");
        selectionValidWidget->setCloseButtonVisible(false);
        selectionValidWidget->setMessageType(KMessageWidget::MessageType::Error);

        vboxLayout->addWidget(selectionValidWidget);

        buttonBox = new QDialogButtonBox(SelectCoreDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        vboxLayout->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        label->setBuddy(executableFile);
        label_2->setBuddy(coreFile);
#endif // QT_CONFIG(shortcut)

        retranslateUi(SelectCoreDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SelectCoreDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SelectCoreDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SelectCoreDialog);
    } // setupUi

    void retranslateUi(QDialog *SelectCoreDialog)
    {
        label->setText(tr2i18n("Executable:", "@label:chooser"));
        label_2->setText(tr2i18n("Core file:", "@label:chooser"));
        (void)SelectCoreDialog;
    } // retranslateUi

};

namespace Ui {
    class SelectCoreDialog: public Ui_SelectCoreDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SELECTCOREDIALOG_H

