/****************************************************************************
** Meta object code from reading C++ file 'problemmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/kdevplatform/shell/problemmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'problemmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop12ProblemModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::ProblemModel::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop12ProblemModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::ProblemModel",
        "problemsChanged",
        "",
        "fullUpdateTooltipChanged",
        "setShowImports",
        "showImports",
        "setScope",
        "ProblemScope",
        "scope",
        "setPathForDocumentsInPathScope",
        "path",
        "setSeverity",
        "severity",
        "setSeverities",
        "KDevelop::IProblem::Severities",
        "severities",
        "setGrouping",
        "grouping",
        "forceFullUpdate",
        "onProblemsChanged",
        "setCurrentDocument",
        "IDocument*",
        "doc",
        "closedDocument",
        "documentUrlChanged",
        "document",
        "QUrl",
        "previousUrl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'problemsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullUpdateTooltipChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setShowImports'
        QtMocHelpers::SlotData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 },
        }}),
        // Slot 'setScope'
        QtMocHelpers::SlotData<void(ProblemScope)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'setPathForDocumentsInPathScope'
        QtMocHelpers::SlotData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'setSeverity'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'setSeverities'
        QtMocHelpers::SlotData<void(KDevelop::IProblem::Severities)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setGrouping'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'forceFullUpdate'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onProblemsChanged'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'setCurrentDocument'
        QtMocHelpers::SlotData<void(IDocument *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'closedDocument'
        QtMocHelpers::SlotData<void(IDocument *)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'documentUrlChanged'
        QtMocHelpers::SlotData<void(IDocument *, const QUrl &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 25 }, { 0x80000000 | 26, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProblemModel, qt_meta_tag_ZN8KDevelop12ProblemModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::ProblemModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop12ProblemModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop12ProblemModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop12ProblemModelE_t>.metaTypes,
    nullptr
} };

void KDevelop::ProblemModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProblemModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->problemsChanged(); break;
        case 1: _t->fullUpdateTooltipChanged(); break;
        case 2: _t->setShowImports((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->setScope((*reinterpret_cast<std::add_pointer_t<ProblemScope>>(_a[1]))); break;
        case 4: _t->setPathForDocumentsInPathScope((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->setSeverity((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->setSeverities((*reinterpret_cast<std::add_pointer_t<KDevelop::IProblem::Severities>>(_a[1]))); break;
        case 7: _t->setGrouping((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->forceFullUpdate(); break;
        case 9: _t->onProblemsChanged(); break;
        case 10: _t->setCurrentDocument((*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[1]))); break;
        case 11: _t->closedDocument((*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[1]))); break;
        case 12: _t->documentUrlChanged((*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProblemModel::*)()>(_a, &ProblemModel::problemsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProblemModel::*)()>(_a, &ProblemModel::fullUpdateTooltipChanged, 1))
            return;
    }
}

const QMetaObject *KDevelop::ProblemModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::ProblemModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop12ProblemModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int KDevelop::ProblemModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::ProblemModel::problemsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KDevelop::ProblemModel::fullUpdateTooltipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
