/********************************************************************************
** Form generated from reading UI file 'projectmanagerview.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTMANAGERVIEW_H
#define UI_PROJECTMANAGERVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "projectbuildsetwidget.h"
#include "projecttreeview.h"

QT_BEGIN_NAMESPACE

class Ui_ProjectManagerView
{
public:
    QHBoxLayout *horizontalLayout;
    QSplitter *splitter;
    QWidget *verticalLayoutWidget;
    QVBoxLayout *verticalLayout_2;
    ProjectTreeView *projectTreeView;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout;
    ProjectBuildSetWidget *buildSetView;

    void setupUi(QWidget *ProjectManagerView)
    {
        if (ProjectManagerView->objectName().isEmpty())
            ProjectManagerView->setObjectName("ProjectManagerView");
        ProjectManagerView->resize(289, 632);
        horizontalLayout = new QHBoxLayout(ProjectManagerView);
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout->setObjectName("horizontalLayout");
        splitter = new QSplitter(ProjectManagerView);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Vertical);
        verticalLayoutWidget = new QWidget(splitter);
        verticalLayoutWidget->setObjectName("verticalLayoutWidget");
        verticalLayout_2 = new QVBoxLayout(verticalLayoutWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        projectTreeView = new ProjectTreeView(verticalLayoutWidget);
        projectTreeView->setObjectName("projectTreeView");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(6);
        sizePolicy.setHeightForWidth(projectTreeView->sizePolicy().hasHeightForWidth());
        projectTreeView->setSizePolicy(sizePolicy);
        projectTreeView->header()->setVisible(false);

        verticalLayout_2->addWidget(projectTreeView);

        splitter->addWidget(verticalLayoutWidget);
        layoutWidget = new QWidget(splitter);
        layoutWidget->setObjectName("layoutWidget");
        verticalLayout = new QVBoxLayout(layoutWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        buildSetView = new ProjectBuildSetWidget(layoutWidget);
        buildSetView->setObjectName("buildSetView");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(2);
        sizePolicy1.setHeightForWidth(buildSetView->sizePolicy().hasHeightForWidth());
        buildSetView->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(buildSetView);

        splitter->addWidget(layoutWidget);

        horizontalLayout->addWidget(splitter);


        retranslateUi(ProjectManagerView);

        QMetaObject::connectSlotsByName(ProjectManagerView);
    } // setupUi

    void retranslateUi(QWidget *ProjectManagerView)
    {
#if QT_CONFIG(whatsthis)
        projectTreeView->setWhatsThis(tr2i18n("Project Overview", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
#if QT_CONFIG(whatsthis)
        buildSetView->setWhatsThis(tr2i18n("Build Items:", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        (void)ProjectManagerView;
    } // retranslateUi

};

namespace Ui {
    class ProjectManagerView: public Ui_ProjectManagerView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROJECTMANAGERVIEW_H

