/********************************************************************************
** Form generated from reading UI file 'testcases.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TESTCASES_H
#define UI_TESTCASES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KEditListWidget"

QT_BEGIN_NAMESPACE

class Ui_TestCasesPage
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *identifierLabel;
    QLineEdit *identifierLineEdit;
    QLabel *testCasesLabel;
    KEditListWidget *keditlistwidget;

    void setupUi(QWidget *TestCasesPage)
    {
        if (TestCasesPage->objectName().isEmpty())
            TestCasesPage->setObjectName("TestCasesPage");
        TestCasesPage->resize(555, 488);
        verticalLayout = new QVBoxLayout(TestCasesPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(TestCasesPage);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        identifierLabel = new QLabel(groupBox);
        identifierLabel->setObjectName("identifierLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, identifierLabel);

        identifierLineEdit = new QLineEdit(groupBox);
        identifierLineEdit->setObjectName("identifierLineEdit");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, identifierLineEdit);

        testCasesLabel = new QLabel(groupBox);
        testCasesLabel->setObjectName("testCasesLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, testCasesLabel);

        keditlistwidget = new KEditListWidget(groupBox);
        keditlistwidget->setObjectName("keditlistwidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(keditlistwidget->sizePolicy().hasHeightForWidth());
        keditlistwidget->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, keditlistwidget);


        verticalLayout->addWidget(groupBox);

#if QT_CONFIG(shortcut)
        identifierLabel->setBuddy(identifierLineEdit);
#endif // QT_CONFIG(shortcut)

        retranslateUi(TestCasesPage);

        QMetaObject::connectSlotsByName(TestCasesPage);
    } // setupUi

    void retranslateUi(QWidget *TestCasesPage)
    {
        groupBox->setTitle(tr2i18n("Set the test name and its test cases.", nullptr));
        identifierLabel->setText(tr2i18n("&Identifier:", "@label:textbox"));
        testCasesLabel->setText(tr2i18n("&Test cases:", "@label:listbox"));
        (void)TestCasesPage;
    } // retranslateUi

};

namespace Ui {
    class TestCasesPage: public Ui_TestCasesPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TESTCASES_H

