// This file is generated by kconfig_compiler_kf6 from projectconfig.kcfg.
// All changes you do to this file will be lost.

#include "projectconfig.h"

using namespace SourceFormatter;

ProjectConfig::ProjectConfig( )
  : KConfigSkeleton()
{
  setCurrentGroup( QStringLiteral( "SourceFormatter" ) );

  KConfigSkeleton::ItemBool  *itemUseDefault;
  itemUseDefault = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseDefault" ), mUseDefault, true );
  addItem( itemUseDefault, QStringLiteral( "useDefault" ) );
  KConfigSkeleton::ItemBool  *itemModelinesEnabled;
  itemModelinesEnabled = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "ModelinesEnabled" ), mModelinesEnabled, false );
  addItem( itemModelinesEnabled, QStringLiteral( "modelinesEnabled" ) );
  KConfigSkeleton::ItemBool  *itemOverrideKateIndentation;
  itemOverrideKateIndentation = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "OverrideKateIndentation" ), mOverrideKateIndentation, false );
  addItem( itemOverrideKateIndentation, QStringLiteral( "overrideKateIndentation" ) );
}

ProjectConfig::~ProjectConfig()
{
}

