/********************************************************************************
** Form generated from reading UI file 'mesonadvancedsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MESONADVANCEDSETTINGS_H
#define UI_MESONADVANCEDSETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"
#include "KLineEdit"
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_MesonAdvancedSettings
{
public:
    QVBoxLayout *verticalLayout;
    QPushButton *b_showAdvanced;
    QGroupBox *container;
    QVBoxLayout *verticalLayout_4;
    QGridLayout *gridLayout;
    QLabel *l_mesonArgs;
    QLabel *l_backend;
    QLabel *l_mesonExe;
    KLineEdit *i_mesonArgs;
    KComboBox *i_backend;
    KUrlRequester *i_mesonExe;
    QPushButton *b_hideAdvanced;

    void setupUi(QWidget *MesonAdvancedSettings)
    {
        if (MesonAdvancedSettings->objectName().isEmpty())
            MesonAdvancedSettings->setObjectName("MesonAdvancedSettings");
        MesonAdvancedSettings->resize(500, 250);
        verticalLayout = new QVBoxLayout(MesonAdvancedSettings);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        b_showAdvanced = new QPushButton(MesonAdvancedSettings);
        b_showAdvanced->setObjectName("b_showAdvanced");

        verticalLayout->addWidget(b_showAdvanced);

        container = new QGroupBox(MesonAdvancedSettings);
        container->setObjectName("container");
        verticalLayout_4 = new QVBoxLayout(container);
        verticalLayout_4->setObjectName("verticalLayout_4");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        l_mesonArgs = new QLabel(container);
        l_mesonArgs->setObjectName("l_mesonArgs");
        l_mesonArgs->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(l_mesonArgs, 0, 0, 1, 1);

        l_backend = new QLabel(container);
        l_backend->setObjectName("l_backend");
        l_backend->setLayoutDirection(Qt::LeftToRight);
        l_backend->setScaledContents(false);
        l_backend->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(l_backend, 1, 0, 1, 1);

        l_mesonExe = new QLabel(container);
        l_mesonExe->setObjectName("l_mesonExe");
        l_mesonExe->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(l_mesonExe, 2, 0, 1, 1);

        i_mesonArgs = new KLineEdit(container);
        i_mesonArgs->setObjectName("i_mesonArgs");
        i_mesonArgs->setProperty("showClearButton", QVariant(true));

        gridLayout->addWidget(i_mesonArgs, 0, 1, 1, 1);

        i_backend = new KComboBox(container);
        i_backend->setObjectName("i_backend");

        gridLayout->addWidget(i_backend, 1, 1, 1, 1);

        i_mesonExe = new KUrlRequester(container);
        i_mesonExe->setObjectName("i_mesonExe");

        gridLayout->addWidget(i_mesonExe, 2, 1, 1, 1);


        verticalLayout_4->addLayout(gridLayout);

        b_hideAdvanced = new QPushButton(container);
        b_hideAdvanced->setObjectName("b_hideAdvanced");

        verticalLayout_4->addWidget(b_hideAdvanced);


        verticalLayout->addWidget(container);


        retranslateUi(MesonAdvancedSettings);
        QObject::connect(b_showAdvanced, &QPushButton::clicked, container, qOverload<>(&QGroupBox::show));
        QObject::connect(b_showAdvanced, &QPushButton::clicked, b_showAdvanced, qOverload<>(&QPushButton::hide));
        QObject::connect(b_hideAdvanced, &QPushButton::clicked, container, qOverload<>(&QGroupBox::hide));
        QObject::connect(b_hideAdvanced, &QPushButton::clicked, b_showAdvanced, qOverload<>(&QPushButton::show));
        QObject::connect(i_mesonArgs, SIGNAL(textChanged(QString)), MesonAdvancedSettings, SLOT(updated()));
        QObject::connect(i_backend, SIGNAL(currentIndexChanged(int)), MesonAdvancedSettings, SLOT(updated()));
        QObject::connect(i_mesonExe, SIGNAL(textChanged(QString)), MesonAdvancedSettings, SLOT(updated()));

        QMetaObject::connectSlotsByName(MesonAdvancedSettings);
    } // setupUi

    void retranslateUi(QWidget *MesonAdvancedSettings)
    {
        b_showAdvanced->setText(tr2i18n("Show Advanced Configuration", "@action:button"));
        container->setTitle(tr2i18n("Advanced Configuration", "@title:group"));
        l_mesonArgs->setText(tr2i18n("Extra Meson arguments:", "@label:textbox"));
        l_backend->setText(tr2i18n("Meson backend:", "@label:listbox"));
        l_mesonExe->setText(tr2i18n("Meson executable:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        i_mesonArgs->setToolTip(tr2i18n("Changing this will reset the build options.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        i_mesonExe->setPlaceholderText(tr2i18n("/path/to/mesonexecutable", "@info:placeholder"));
        b_hideAdvanced->setText(tr2i18n("Hide Advanced Configuration", "@action:button"));
        (void)MesonAdvancedSettings;
    } // retranslateUi

};

namespace Ui {
    class MesonAdvancedSettings: public Ui_MesonAdvancedSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MESONADVANCEDSETTINGS_H

