/********************************************************************************
** Form generated from reading UI file 'projectconfigpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTCONFIGPAGE_H
#define UI_PROJECTCONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "sourceformatterselectionedit.h"

namespace SourceFormatter {

class Ui_ProjectConfigPage
{
public:
    QVBoxLayout *vboxLayout;
    QCheckBox *kcfg_useDefault;
    QGroupBox *generalGroupBox;
    QVBoxLayout *vboxLayout1;
    QCheckBox *kcfg_overrideKateIndentation;
    QCheckBox *kcfg_modelinesEnabled;
    QGroupBox *formattinStylesGroupBox;
    QVBoxLayout *verticalLayout;
    KDevelop::SourceFormatterSelectionEdit *formatterSelectionEdit;

    void setupUi(QWidget *SourceFormatter__ProjectConfigPage)
    {
        if (SourceFormatter__ProjectConfigPage->objectName().isEmpty())
            SourceFormatter__ProjectConfigPage->setObjectName("SourceFormatter__ProjectConfigPage");
        SourceFormatter__ProjectConfigPage->resize(407, 315);
        vboxLayout = new QVBoxLayout(SourceFormatter__ProjectConfigPage);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        kcfg_useDefault = new QCheckBox(SourceFormatter__ProjectConfigPage);
        kcfg_useDefault->setObjectName("kcfg_useDefault");

        vboxLayout->addWidget(kcfg_useDefault);

        generalGroupBox = new QGroupBox(SourceFormatter__ProjectConfigPage);
        generalGroupBox->setObjectName("generalGroupBox");
        vboxLayout1 = new QVBoxLayout(generalGroupBox);
        vboxLayout1->setObjectName("vboxLayout1");
        kcfg_overrideKateIndentation = new QCheckBox(generalGroupBox);
        kcfg_overrideKateIndentation->setObjectName("kcfg_overrideKateIndentation");

        vboxLayout1->addWidget(kcfg_overrideKateIndentation);

        kcfg_modelinesEnabled = new QCheckBox(generalGroupBox);
        kcfg_modelinesEnabled->setObjectName("kcfg_modelinesEnabled");

        vboxLayout1->addWidget(kcfg_modelinesEnabled);


        vboxLayout->addWidget(generalGroupBox);

        formattinStylesGroupBox = new QGroupBox(SourceFormatter__ProjectConfigPage);
        formattinStylesGroupBox->setObjectName("formattinStylesGroupBox");
        verticalLayout = new QVBoxLayout(formattinStylesGroupBox);
        verticalLayout->setObjectName("verticalLayout");
        formatterSelectionEdit = new KDevelop::SourceFormatterSelectionEdit(formattinStylesGroupBox);
        formatterSelectionEdit->setObjectName("formatterSelectionEdit");

        verticalLayout->addWidget(formatterSelectionEdit);


        vboxLayout->addWidget(formattinStylesGroupBox);

        vboxLayout->setStretch(2, 1);

        retranslateUi(SourceFormatter__ProjectConfigPage);

        QMetaObject::connectSlotsByName(SourceFormatter__ProjectConfigPage);
    } // setupUi

    void retranslateUi(QWidget *SourceFormatter__ProjectConfigPage)
    {
        kcfg_useDefault->setText(tr2i18n("&Use default", "@option:check"));
        generalGroupBox->setTitle(tr2i18n("General", "@title:group"));
#if QT_CONFIG(tooltip)
        kcfg_overrideKateIndentation->setToolTip(tr2i18n("Override the editor indentation mode according to the formatting style for documents without a Kate modeline.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_overrideKateIndentation->setText(tr2i18n("Override editor indentation mode", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_modelinesEnabled->setToolTip(tr2i18n("Add a Kate modeline according to the formatting style to formatted documents.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_modelinesEnabled->setText(tr2i18n("Add Kate modeline", "@option:check"));
        formattinStylesGroupBox->setTitle(tr2i18n("Formatting Styles", "@title:group"));
        (void)SourceFormatter__ProjectConfigPage;
    } // retranslateUi

};

} // namespace SourceFormatter

namespace SourceFormatter {
namespace Ui {
    class ProjectConfigPage: public Ui_ProjectConfigPage {};
} // namespace Ui
} // namespace SourceFormatter

#endif // PROJECTCONFIGPAGE_H

