/********************************************************************************
** Form generated from reading UI file 'mesonoptionbaseview.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MESONOPTIONBASEVIEW_H
#define UI_MESONOPTIONBASEVIEW_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MesonOptionBaseView
{
public:
    QHBoxLayout *layout;
    QLabel *l_name;
    QToolButton *b_reset;

    void setupUi(QWidget *MesonOptionBaseView)
    {
        if (MesonOptionBaseView->objectName().isEmpty())
            MesonOptionBaseView->setObjectName("MesonOptionBaseView");
        MesonOptionBaseView->resize(500, 32);
        layout = new QHBoxLayout(MesonOptionBaseView);
        layout->setObjectName("layout");
        layout->setContentsMargins(0, 0, 0, 0);
        l_name = new QLabel(MesonOptionBaseView);
        l_name->setObjectName("l_name");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(l_name->sizePolicy().hasHeightForWidth());
        l_name->setSizePolicy(sizePolicy);
        l_name->setMinimumSize(QSize(50, 0));

        layout->addWidget(l_name);

        b_reset = new QToolButton(MesonOptionBaseView);
        b_reset->setObjectName("b_reset");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-revert")));
        b_reset->setIcon(icon);

        layout->addWidget(b_reset);


        retranslateUi(MesonOptionBaseView);
        QObject::connect(b_reset, SIGNAL(clicked()), MesonOptionBaseView, SLOT(reset()));

        QMetaObject::connectSlotsByName(MesonOptionBaseView);
    } // setupUi

    void retranslateUi(QWidget *MesonOptionBaseView)
    {
        l_name->setText(tr2i18n("Name:", nullptr));
#if QT_CONFIG(tooltip)
        b_reset->setToolTip(tr2i18n("Reset to default value", nullptr));
#endif // QT_CONFIG(tooltip)
        b_reset->setText(QString());
        (void)MesonOptionBaseView;
    } // retranslateUi

};

namespace Ui {
    class MesonOptionBaseView: public Ui_MesonOptionBaseView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MESONOPTIONBASEVIEW_H

