/********************************************************************************
** Form generated from reading UI file 'clangtidypreferences.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLANGTIDYPREFERENCES_H
#define UI_CLANGTIDYPREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"
#include "config/checksetmanagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_ClangTidyPreferences
{
public:
    QVBoxLayout *settingsLayout;
    QGroupBox *pathsGroupBox;
    QHBoxLayout *pathsGroupBoxLayout;
    QVBoxLayout *pathsLabelsLayout;
    QLabel *clangtidyLabel;
    QVBoxLayout *pathsUrlsLayout;
    KUrlRequester *kcfg_clangtidyPath;
    QGroupBox *jobsBox;
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_parallelJobsEnabled;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_parallelJobsAutoCount;
    QSpacerItem *horizontalSpacer;
    QLabel *parallelJobsFixedCountLabel;
    QSpinBox *kcfg_parallelJobsFixedCount;
    ClangTidy::CheckSetManageWidget *checksets;

    void setupUi(QWidget *ClangTidyPreferences)
    {
        if (ClangTidyPreferences->objectName().isEmpty())
            ClangTidyPreferences->setObjectName("ClangTidyPreferences");
        ClangTidyPreferences->resize(400, 300);
        settingsLayout = new QVBoxLayout(ClangTidyPreferences);
        settingsLayout->setObjectName("settingsLayout");
        settingsLayout->setContentsMargins(0, 0, 0, 0);
        pathsGroupBox = new QGroupBox(ClangTidyPreferences);
        pathsGroupBox->setObjectName("pathsGroupBox");
        pathsGroupBoxLayout = new QHBoxLayout(pathsGroupBox);
        pathsGroupBoxLayout->setObjectName("pathsGroupBoxLayout");
        pathsLabelsLayout = new QVBoxLayout();
        pathsLabelsLayout->setObjectName("pathsLabelsLayout");
        clangtidyLabel = new QLabel(pathsGroupBox);
        clangtidyLabel->setObjectName("clangtidyLabel");
        clangtidyLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        pathsLabelsLayout->addWidget(clangtidyLabel);


        pathsGroupBoxLayout->addLayout(pathsLabelsLayout);

        pathsUrlsLayout = new QVBoxLayout();
        pathsUrlsLayout->setObjectName("pathsUrlsLayout");
        kcfg_clangtidyPath = new KUrlRequester(pathsGroupBox);
        kcfg_clangtidyPath->setObjectName("kcfg_clangtidyPath");

        pathsUrlsLayout->addWidget(kcfg_clangtidyPath);


        pathsGroupBoxLayout->addLayout(pathsUrlsLayout);


        settingsLayout->addWidget(pathsGroupBox);

        jobsBox = new QGroupBox(ClangTidyPreferences);
        jobsBox->setObjectName("jobsBox");
        jobsBox->setTitle(QString::fromUtf8(""));
        verticalLayout = new QVBoxLayout(jobsBox);
        verticalLayout->setObjectName("verticalLayout");
        kcfg_parallelJobsEnabled = new QCheckBox(jobsBox);
        kcfg_parallelJobsEnabled->setObjectName("kcfg_parallelJobsEnabled");

        verticalLayout->addWidget(kcfg_parallelJobsEnabled);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_parallelJobsAutoCount = new QCheckBox(jobsBox);
        kcfg_parallelJobsAutoCount->setObjectName("kcfg_parallelJobsAutoCount");

        horizontalLayout->addWidget(kcfg_parallelJobsAutoCount);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        parallelJobsFixedCountLabel = new QLabel(jobsBox);
        parallelJobsFixedCountLabel->setObjectName("parallelJobsFixedCountLabel");

        horizontalLayout->addWidget(parallelJobsFixedCountLabel);

        kcfg_parallelJobsFixedCount = new QSpinBox(jobsBox);
        kcfg_parallelJobsFixedCount->setObjectName("kcfg_parallelJobsFixedCount");
        kcfg_parallelJobsFixedCount->setMinimum(1);

        horizontalLayout->addWidget(kcfg_parallelJobsFixedCount);


        verticalLayout->addLayout(horizontalLayout);


        settingsLayout->addWidget(jobsBox);

        checksets = new ClangTidy::CheckSetManageWidget(ClangTidyPreferences);
        checksets->setObjectName("checksets");

        settingsLayout->addWidget(checksets);

        settingsLayout->setStretch(2, 1);
#if QT_CONFIG(shortcut)
        clangtidyLabel->setBuddy(kcfg_clangtidyPath);
#endif // QT_CONFIG(shortcut)

        retranslateUi(ClangTidyPreferences);

        QMetaObject::connectSlotsByName(ClangTidyPreferences);
    } // setupUi

    void retranslateUi(QWidget *ClangTidyPreferences)
    {
        pathsGroupBox->setTitle(tr2i18n("Paths", "@title:group"));
        clangtidyLabel->setText(tr2i18n("Clang-&Tidy executable:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        kcfg_clangtidyPath->setToolTip(tr2i18n("The full path to the Clang-Tidy executable", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_parallelJobsEnabled->setText(tr2i18n("Run analysis jobs in parallel", "@option:check"));
        kcfg_parallelJobsAutoCount->setText(tr2i18n("Use all CPU cores", "@option:check"));
        parallelJobsFixedCountLabel->setText(tr2i18n("Maximum number of threads:", "@label:spinbox"));
        (void)ClangTidyPreferences;
    } // retranslateUi

};

namespace Ui {
    class ClangTidyPreferences: public Ui_ClangTidyPreferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CLANGTIDYPREFERENCES_H

