/********************************************************************************
** Form generated from reading UI file 'projectpathswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTPATHSWIDGET_H
#define UI_PROJECTPATHSWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"
#include "kcm_widget/defineswidget.h"
#include "kcm_widget/includeswidget.h"
#include "kcm_widget/parserwidget.h"

QT_BEGIN_NAMESPACE

class Ui_ProjectPathsWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *configureLabel;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *kcfg_reparse;
    QSpacerItem *horizontalSpacer;
    QWidget *compilerBox;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    QComboBox *compiler;
    QPushButton *batchEdit;
    QHBoxLayout *horizontalLayout;
    QHBoxLayout *horizontalLayout_4;
    KComboBox *projectPaths;
    QPushButton *addPath;
    QPushButton *removePath;
    QTabWidget *languageParameters;
    QWidget *includePathsPage;
    QGridLayout *gridLayout_3;
    IncludesWidget *includesWidget;
    QWidget *definesPage;
    QVBoxLayout *gridLayout_2;
    DefinesWidget *definesWidget;
    QWidget *parserPage;
    QGridLayout *gridLayout_4;
    ParserWidget *parserWidget;

    void setupUi(QWidget *ProjectPathsWidget)
    {
        if (ProjectPathsWidget->objectName().isEmpty())
            ProjectPathsWidget->setObjectName("ProjectPathsWidget");
        ProjectPathsWidget->resize(667, 621);
        gridLayout = new QGridLayout(ProjectPathsWidget);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        configureLabel = new QLabel(ProjectPathsWidget);
        configureLabel->setObjectName("configureLabel");

        gridLayout->addWidget(configureLabel, 1, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        kcfg_reparse = new QCheckBox(ProjectPathsWidget);
        kcfg_reparse->setObjectName("kcfg_reparse");
        kcfg_reparse->setChecked(true);

        horizontalLayout_3->addWidget(kcfg_reparse);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        compilerBox = new QWidget(ProjectPathsWidget);
        compilerBox->setObjectName("compilerBox");
        horizontalLayout_2 = new QHBoxLayout(compilerBox);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(compilerBox);
        label->setObjectName("label");

        horizontalLayout_2->addWidget(label);

        compiler = new QComboBox(compilerBox);
        compiler->setObjectName("compiler");

        horizontalLayout_2->addWidget(compiler);


        horizontalLayout_3->addWidget(compilerBox);

        batchEdit = new QPushButton(ProjectPathsWidget);
        batchEdit->setObjectName("batchEdit");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("format-list-unordered")));
        batchEdit->setIcon(icon);

        horizontalLayout_3->addWidget(batchEdit);


        gridLayout->addLayout(horizontalLayout_3, 3, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        projectPaths = new KComboBox(ProjectPathsWidget);
        projectPaths->setObjectName("projectPaths");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(projectPaths->sizePolicy().hasHeightForWidth());
        projectPaths->setSizePolicy(sizePolicy);

        horizontalLayout_4->addWidget(projectPaths);

        addPath = new QPushButton(ProjectPathsWidget);
        addPath->setObjectName("addPath");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addPath->setIcon(icon1);

        horizontalLayout_4->addWidget(addPath);

        removePath = new QPushButton(ProjectPathsWidget);
        removePath->setObjectName("removePath");
        removePath->setEnabled(false);
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        removePath->setIcon(icon2);

        horizontalLayout_4->addWidget(removePath);


        horizontalLayout->addLayout(horizontalLayout_4);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        languageParameters = new QTabWidget(ProjectPathsWidget);
        languageParameters->setObjectName("languageParameters");
        languageParameters->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(8);
        sizePolicy1.setHeightForWidth(languageParameters->sizePolicy().hasHeightForWidth());
        languageParameters->setSizePolicy(sizePolicy1);
        includePathsPage = new QWidget();
        includePathsPage->setObjectName("includePathsPage");
        gridLayout_3 = new QGridLayout(includePathsPage);
        gridLayout_3->setObjectName("gridLayout_3");
        includesWidget = new IncludesWidget(includePathsPage);
        includesWidget->setObjectName("includesWidget");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(8);
        sizePolicy2.setHeightForWidth(includesWidget->sizePolicy().hasHeightForWidth());
        includesWidget->setSizePolicy(sizePolicy2);

        gridLayout_3->addWidget(includesWidget, 0, 0, 1, 1);

        languageParameters->addTab(includePathsPage, QString());
        definesPage = new QWidget();
        definesPage->setObjectName("definesPage");
        gridLayout_2 = new QVBoxLayout(definesPage);
        gridLayout_2->setObjectName("gridLayout_2");
        definesWidget = new DefinesWidget(definesPage);
        definesWidget->setObjectName("definesWidget");
        sizePolicy2.setHeightForWidth(definesWidget->sizePolicy().hasHeightForWidth());
        definesWidget->setSizePolicy(sizePolicy2);

        gridLayout_2->addWidget(definesWidget);

        languageParameters->addTab(definesPage, QString());
        parserPage = new QWidget();
        parserPage->setObjectName("parserPage");
        gridLayout_4 = new QGridLayout(parserPage);
        gridLayout_4->setObjectName("gridLayout_4");
        parserWidget = new ParserWidget(parserPage);
        parserWidget->setObjectName("parserWidget");

        gridLayout_4->addWidget(parserWidget, 0, 0, 1, 1);

        languageParameters->addTab(parserPage, QString());

        gridLayout->addWidget(languageParameters, 2, 0, 1, 1);


        retranslateUi(ProjectPathsWidget);

        languageParameters->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ProjectPathsWidget);
    } // setupUi

    void retranslateUi(QWidget *ProjectPathsWidget)
    {
        configureLabel->setText(tr2i18n("Configure which macros and include directories/files will be added to the parser during project parsing:", nullptr));
#if QT_CONFIG(tooltip)
        kcfg_reparse->setToolTip(tr2i18n("Check this if you want the project to be reparsed to apply the changes.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_reparse->setText(tr2i18n("Reparse the project", "@option:check"));
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("<html><head/><body><p>Select compiler that will be used to retrieve standard include directories and defined macros.</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Compiler for path:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        compiler->setToolTip(tr2i18n("<html><head/><body><p>Select compiler that will be used to retrieve standard include directories and defined macros.</p></body></html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        batchEdit->setToolTip(tr2i18n("Edit multiple includes/defines at the same time.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        batchEdit->setText(tr2i18n("&Batch Edit...", "@action:button"));
#if QT_CONFIG(tooltip)
        addPath->setToolTip(tr2i18n("Add a new sub-project path entry.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        addPath->setText(QString());
#if QT_CONFIG(tooltip)
        removePath->setToolTip(tr2i18n("Delete current sub-project path entry.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        removePath->setText(QString());
        languageParameters->setTabText(languageParameters->indexOf(includePathsPage), tr2i18n("Includes/Imports", "@title:tab"));
        languageParameters->setTabText(languageParameters->indexOf(definesPage), tr2i18n("Defines", "@title:tab"));
        languageParameters->setTabText(languageParameters->indexOf(parserPage), tr2i18n("C/C++ Parser", "@title:tab"));
        (void)ProjectPathsWidget;
    } // retranslateUi

};

namespace Ui {
    class ProjectPathsWidget: public Ui_ProjectPathsWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROJECTPATHSWIDGET_H

