/****************************************************************************
** Meta object code from reading C++ file 'testview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/testview/testview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'testview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8TestViewE_t {};
} // unnamed namespace

template <> constexpr inline auto TestView::qt_create_metaobjectdata<qt_meta_tag_ZN8TestViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TestView",
        "runSelectedTests",
        "",
        "showSource",
        "addTestSuite",
        "KDevelop::ITestSuite*",
        "suite",
        "removeTestSuite",
        "updateTestSuite",
        "KDevelop::TestResult",
        "result",
        "notifyTestCaseStarted",
        "test_cases",
        "addProject",
        "QStandardItem*",
        "KDevelop::IProject*",
        "project",
        "removeProject",
        "doubleClicked",
        "QModelIndex",
        "index",
        "contextMenuActions",
        "QList<QAction*>"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'runSelectedTests'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showSource'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addTestSuite'
        QtMocHelpers::SlotData<void(KDevelop::ITestSuite *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'removeTestSuite'
        QtMocHelpers::SlotData<void(KDevelop::ITestSuite *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'updateTestSuite'
        QtMocHelpers::SlotData<void(KDevelop::ITestSuite *, const KDevelop::TestResult &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'notifyTestCaseStarted'
        QtMocHelpers::SlotData<void(KDevelop::ITestSuite *, const QStringList &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { QMetaType::QStringList, 12 },
        }}),
        // Slot 'addProject'
        QtMocHelpers::SlotData<QStandardItem *(KDevelop::IProject *)>(13, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'removeProject'
        QtMocHelpers::SlotData<void(KDevelop::IProject *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'doubleClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Slot 'contextMenuActions'
        QtMocHelpers::SlotData<QList<QAction*>()>(21, 2, QMC::AccessPublic, 0x80000000 | 22),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TestView, qt_meta_tag_ZN8TestViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TestView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8TestViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8TestViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8TestViewE_t>.metaTypes,
    nullptr
} };

void TestView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TestView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->runSelectedTests(); break;
        case 1: _t->showSource(); break;
        case 2: _t->addTestSuite((*reinterpret_cast<std::add_pointer_t<KDevelop::ITestSuite*>>(_a[1]))); break;
        case 3: _t->removeTestSuite((*reinterpret_cast<std::add_pointer_t<KDevelop::ITestSuite*>>(_a[1]))); break;
        case 4: _t->updateTestSuite((*reinterpret_cast<std::add_pointer_t<KDevelop::ITestSuite*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KDevelop::TestResult>>(_a[2]))); break;
        case 5: _t->notifyTestCaseStarted((*reinterpret_cast<std::add_pointer_t<KDevelop::ITestSuite*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 6: { QStandardItem* _r = _t->addProject((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStandardItem**>(_a[0]) = std::move(_r); }  break;
        case 7: _t->removeProject((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 8: _t->doubleClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 9: { QList<QAction*> _r = _t->contextMenuActions();
            if (_a[0]) *reinterpret_cast<QList<QAction*>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *TestView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TestView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8TestViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int TestView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}
QT_WARNING_POP
