/****************************************************************************
** Meta object code from reading C++ file 'project.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/kdevplatform/shell/project.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'project.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop7ProjectE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::Project::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop7ProjectE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::Project",
        "aboutToOpen",
        "",
        "KDevelop::IProject*",
        "open",
        "Path",
        "projectFile",
        "close",
        "projectFileManager",
        "IProjectFileManager*",
        "buildSystemManager",
        "IBuildSystemManager*",
        "versionControlPlugin",
        "IPlugin*",
        "managerPlugin",
        "setManagerPlugin",
        "manager",
        "projectItem",
        "ProjectFolderItem*",
        "inProject",
        "IndexedString",
        "url",
        "setReloadJob",
        "KJob*",
        "job",
        "name"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'aboutToOpen'
        QtMocHelpers::SignalData<void(KDevelop::IProject *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Slot 'open'
        QtMocHelpers::SlotData<bool(const Path &)>(4, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'close'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'projectFileManager'
        QtMocHelpers::SlotData<IProjectFileManager *() const>(8, 2, QMC::AccessPublic, 0x80000000 | 9),
        // Slot 'buildSystemManager'
        QtMocHelpers::SlotData<IBuildSystemManager *() const>(10, 2, QMC::AccessPublic, 0x80000000 | 11),
        // Slot 'versionControlPlugin'
        QtMocHelpers::SlotData<IPlugin *() const>(12, 2, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'managerPlugin'
        QtMocHelpers::SlotData<IPlugin *() const>(14, 2, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'setManagerPlugin'
        QtMocHelpers::SlotData<void(IPlugin *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 16 },
        }}),
        // Slot 'projectItem'
        QtMocHelpers::SlotData<ProjectFolderItem *() const>(17, 2, QMC::AccessPublic, 0x80000000 | 18),
        // Slot 'inProject'
        QtMocHelpers::SlotData<bool(const IndexedString &) const>(19, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'setReloadJob'
        QtMocHelpers::SlotData<void(KJob *)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Method 'name'
        QtMocHelpers::MethodData<QString() const>(25, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::QString),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Project, qt_meta_tag_ZN8KDevelop7ProjectE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::Project::staticMetaObject = { {
    QMetaObject::SuperData::link<IProject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop7ProjectE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop7ProjectE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop7ProjectE_t>.metaTypes,
    nullptr
} };

void KDevelop::Project::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Project *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->aboutToOpen((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 1: { bool _r = _t->open((*reinterpret_cast<std::add_pointer_t<Path>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->close(); break;
        case 3: { IProjectFileManager* _r = _t->projectFileManager();
            if (_a[0]) *reinterpret_cast<IProjectFileManager**>(_a[0]) = std::move(_r); }  break;
        case 4: { IBuildSystemManager* _r = _t->buildSystemManager();
            if (_a[0]) *reinterpret_cast<IBuildSystemManager**>(_a[0]) = std::move(_r); }  break;
        case 5: { IPlugin* _r = _t->versionControlPlugin();
            if (_a[0]) *reinterpret_cast<IPlugin**>(_a[0]) = std::move(_r); }  break;
        case 6: { IPlugin* _r = _t->managerPlugin();
            if (_a[0]) *reinterpret_cast<IPlugin**>(_a[0]) = std::move(_r); }  break;
        case 7: _t->setManagerPlugin((*reinterpret_cast<std::add_pointer_t<IPlugin*>>(_a[1]))); break;
        case 8: { ProjectFolderItem* _r = _t->projectItem();
            if (_a[0]) *reinterpret_cast<ProjectFolderItem**>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->inProject((*reinterpret_cast<std::add_pointer_t<IndexedString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setReloadJob((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 11: { QString _r = _t->name();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IProject* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Project::*)(KDevelop::IProject * )>(_a, &Project::aboutToOpen, 0))
            return;
    }
}

const QMetaObject *KDevelop::Project::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::Project::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop7ProjectE_t>.strings))
        return static_cast<void*>(this);
    return IProject::qt_metacast(_clname);
}

int KDevelop::Project::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = IProject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::Project::aboutToOpen(KDevelop::IProject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
