/****************************************************************************
** Meta object code from reading C++ file 'area.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/kdevplatform/sublime/area.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'area.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7Sublime4AreaE_t {};
} // unnamed namespace

template <> constexpr inline auto Sublime::Area::qt_create_metaobjectdata<qt_meta_tag_ZN7Sublime4AreaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Sublime::Area",
        "viewAdded",
        "",
        "Sublime::AreaIndex*",
        "Sublime::View*",
        "aboutToRemoveView",
        "viewRemoved",
        "toolViewAdded",
        "Sublime::Position",
        "requestToolViewRaise",
        "aboutToRemoveToolView",
        "changingWorkingSet",
        "Sublime::Area*",
        "area",
        "oldArea",
        "from",
        "to",
        "changedWorkingSet",
        "clearWorkingSet",
        "positionChanged",
        "actionDestroyed",
        "action"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'viewAdded'
        QtMocHelpers::SignalData<void(Sublime::AreaIndex *, Sublime::View *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Signal 'aboutToRemoveView'
        QtMocHelpers::SignalData<void(Sublime::AreaIndex *, Sublime::View *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Signal 'viewRemoved'
        QtMocHelpers::SignalData<void(Sublime::AreaIndex *, Sublime::View *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 4, 2 },
        }}),
        // Signal 'toolViewAdded'
        QtMocHelpers::SignalData<void(Sublime::View *, Sublime::Position)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { 0x80000000 | 8, 2 },
        }}),
        // Signal 'requestToolViewRaise'
        QtMocHelpers::SignalData<void(Sublime::View *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 },
        }}),
        // Signal 'aboutToRemoveToolView'
        QtMocHelpers::SignalData<void(Sublime::View *, Sublime::Position)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { 0x80000000 | 8, 2 },
        }}),
        // Signal 'changingWorkingSet'
        QtMocHelpers::SignalData<void(Sublime::Area *, Sublime::Area *, const QString &, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 12, 14 }, { QMetaType::QString, 15 }, { QMetaType::QString, 16 },
        }}),
        // Signal 'changedWorkingSet'
        QtMocHelpers::SignalData<void(Sublime::Area *, Sublime::Area *, const QString &, const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 12, 14 }, { QMetaType::QString, 15 }, { QMetaType::QString, 16 },
        }}),
        // Signal 'clearWorkingSet'
        QtMocHelpers::SignalData<void(Sublime::Area *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Slot 'positionChanged'
        QtMocHelpers::SlotData<void(Sublime::View *, int)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'actionDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Area, qt_meta_tag_ZN7Sublime4AreaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Sublime::Area::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Sublime4AreaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Sublime4AreaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7Sublime4AreaE_t>.metaTypes,
    nullptr
} };

void Sublime::Area::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Area *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->viewAdded((*reinterpret_cast<std::add_pointer_t<Sublime::AreaIndex*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[2]))); break;
        case 1: _t->aboutToRemoveView((*reinterpret_cast<std::add_pointer_t<Sublime::AreaIndex*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[2]))); break;
        case 2: _t->viewRemoved((*reinterpret_cast<std::add_pointer_t<Sublime::AreaIndex*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[2]))); break;
        case 3: _t->toolViewAdded((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::Position>>(_a[2]))); break;
        case 4: _t->requestToolViewRaise((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1]))); break;
        case 5: _t->aboutToRemoveToolView((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::Position>>(_a[2]))); break;
        case 6: _t->changingWorkingSet((*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 7: _t->changedWorkingSet((*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 8: _t->clearWorkingSet((*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[1]))); break;
        case 9: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<Sublime::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->actionDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Sublime::Area* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Sublime::Area* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< Sublime::Area* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Area::*)(Sublime::AreaIndex * , Sublime::View * )>(_a, &Area::viewAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Area::*)(Sublime::AreaIndex * , Sublime::View * )>(_a, &Area::aboutToRemoveView, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Area::*)(Sublime::AreaIndex * , Sublime::View * )>(_a, &Area::viewRemoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Area::*)(Sublime::View * , Sublime::Position )>(_a, &Area::toolViewAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Area::*)(Sublime::View * )>(_a, &Area::requestToolViewRaise, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Area::*)(Sublime::View * , Sublime::Position )>(_a, &Area::aboutToRemoveToolView, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Area::*)(Sublime::Area * , Sublime::Area * , const QString & , const QString & )>(_a, &Area::changingWorkingSet, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Area::*)(Sublime::Area * , Sublime::Area * , const QString & , const QString & )>(_a, &Area::changedWorkingSet, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Area::*)(Sublime::Area * )>(_a, &Area::clearWorkingSet, 8))
            return;
    }
}

const QMetaObject *Sublime::Area::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Sublime::Area::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7Sublime4AreaE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Sublime::Area::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Sublime::Area::viewAdded(Sublime::AreaIndex * _t1, Sublime::View * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void Sublime::Area::aboutToRemoveView(Sublime::AreaIndex * _t1, Sublime::View * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void Sublime::Area::viewRemoved(Sublime::AreaIndex * _t1, Sublime::View * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Sublime::Area::toolViewAdded(Sublime::View * _t1, Sublime::Position _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Sublime::Area::requestToolViewRaise(Sublime::View * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Sublime::Area::aboutToRemoveToolView(Sublime::View * _t1, Sublime::Position _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void Sublime::Area::changingWorkingSet(Sublime::Area * _t1, Sublime::Area * _t2, const QString & _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 7
void Sublime::Area::changedWorkingSet(Sublime::Area * _t1, Sublime::Area * _t2, const QString & _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 8
void Sublime::Area::clearWorkingSet(Sublime::Area * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
