/****************************************************************************
** Meta object code from reading C++ file 'idocumentcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/kdevplatform/interfaces/idocumentcontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'idocumentcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop19IDocumentControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::IDocumentController::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop19IDocumentControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::IDocumentController",
        "documentActivated",
        "",
        "KDevelop::IDocument*",
        "document",
        "documentJumpPerformed",
        "newDocument",
        "KTextEditor::Cursor",
        "newCursor",
        "previousDocument",
        "previousCursor",
        "documentSaved",
        "documentOpened",
        "documentLoaded",
        "textDocumentCreated",
        "documentClosed",
        "documentStateChanged",
        "documentContentChanged",
        "documentLoadedPrepare",
        "documentUrlChanged",
        "QUrl",
        "previousUrl",
        "openDocument",
        "url",
        "cursor",
        "DocumentActivationParams",
        "activationParams",
        "encoding",
        "KTextEditor::Range",
        "range",
        "IDocument*",
        "buddy",
        "doc",
        "prefName",
        "closeAllDocuments"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'documentActivated'
        QtMocHelpers::SignalData<void(KDevelop::IDocument *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'documentJumpPerformed'
        QtMocHelpers::SignalData<void(KDevelop::IDocument *, KTextEditor::Cursor, KDevelop::IDocument *, KTextEditor::Cursor)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 3, 9 }, { 0x80000000 | 7, 10 },
        }}),
        // Signal 'documentSaved'
        QtMocHelpers::SignalData<void(KDevelop::IDocument *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'documentOpened'
        QtMocHelpers::SignalData<void(KDevelop::IDocument *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'documentLoaded'
        QtMocHelpers::SignalData<void(KDevelop::IDocument *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'textDocumentCreated'
        QtMocHelpers::SignalData<void(KDevelop::IDocument *)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'documentClosed'
        QtMocHelpers::SignalData<void(KDevelop::IDocument *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'documentStateChanged'
        QtMocHelpers::SignalData<void(KDevelop::IDocument *)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'documentContentChanged'
        QtMocHelpers::SignalData<void(KDevelop::IDocument *)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'documentLoadedPrepare'
        QtMocHelpers::SignalData<void(KDevelop::IDocument *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'documentUrlChanged'
        QtMocHelpers::SignalData<void(KDevelop::IDocument *, const QUrl &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<KDevelop::IDocument *(const QUrl &, const KTextEditor::Cursor &, DocumentActivationParams, const QString &)>(22, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 20, 23 }, { 0x80000000 | 7, 24 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<KDevelop::IDocument *(const QUrl &, const KTextEditor::Cursor &, DocumentActivationParams)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 20, 23 }, { 0x80000000 | 7, 24 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<KDevelop::IDocument *(const QUrl &, const KTextEditor::Cursor &)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 20, 23 }, { 0x80000000 | 7, 24 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<KDevelop::IDocument *(const QUrl &, const KTextEditor::Range &, DocumentActivationParams, const QString &, IDocument *)>(22, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 20, 23 }, { 0x80000000 | 28, 29 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<KDevelop::IDocument *(const QUrl &, const KTextEditor::Range &, DocumentActivationParams, const QString &)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 20, 23 }, { 0x80000000 | 28, 29 }, { 0x80000000 | 25, 26 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<KDevelop::IDocument *(const QUrl &, const KTextEditor::Range &, DocumentActivationParams)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 20, 23 }, { 0x80000000 | 28, 29 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<KDevelop::IDocument *(const QUrl &, const KTextEditor::Range &)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 20, 23 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<KDevelop::IDocument *(const QUrl &)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 3, {{
            { 0x80000000 | 20, 23 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<bool(IDocument *, const KTextEditor::Range &, DocumentActivationParams, IDocument *)>(22, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 30, 32 }, { 0x80000000 | 28, 29 }, { 0x80000000 | 25, 26 }, { 0x80000000 | 30, 31 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<bool(IDocument *, const KTextEditor::Range &, DocumentActivationParams)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 30, 32 }, { 0x80000000 | 28, 29 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<bool(IDocument *, const KTextEditor::Range &)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 30, 32 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<bool(IDocument *)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 30, 32 },
        }}),
        // Slot 'openDocument'
        QtMocHelpers::SlotData<KDevelop::IDocument *(const QUrl &, const QString &)>(22, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 20, 23 }, { QMetaType::QString, 33 },
        }}),
        // Slot 'closeAllDocuments'
        QtMocHelpers::SlotData<bool()>(34, 2, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IDocumentController, qt_meta_tag_ZN8KDevelop19IDocumentControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::IDocumentController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop19IDocumentControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop19IDocumentControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop19IDocumentControllerE_t>.metaTypes,
    nullptr
} };

void KDevelop::IDocumentController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IDocumentController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->documentActivated((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 1: _t->documentJumpPerformed((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[4]))); break;
        case 2: _t->documentSaved((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 3: _t->documentOpened((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 4: _t->documentLoaded((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 5: _t->textDocumentCreated((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 6: _t->documentClosed((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 7: _t->documentStateChanged((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 8: _t->documentContentChanged((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 9: _t->documentLoadedPrepare((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 10: _t->documentUrlChanged((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 11: { KDevelop::IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<DocumentActivationParams>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<KDevelop::IDocument**>(_a[0]) = std::move(_r); }  break;
        case 12: { KDevelop::IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<DocumentActivationParams>>(_a[3])));
            if (_a[0]) *reinterpret_cast<KDevelop::IDocument**>(_a[0]) = std::move(_r); }  break;
        case 13: { KDevelop::IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Cursor>>(_a[2])));
            if (_a[0]) *reinterpret_cast<KDevelop::IDocument**>(_a[0]) = std::move(_r); }  break;
        case 14: { KDevelop::IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<DocumentActivationParams>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[5])));
            if (_a[0]) *reinterpret_cast<KDevelop::IDocument**>(_a[0]) = std::move(_r); }  break;
        case 15: { KDevelop::IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<DocumentActivationParams>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<KDevelop::IDocument**>(_a[0]) = std::move(_r); }  break;
        case 16: { KDevelop::IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<DocumentActivationParams>>(_a[3])));
            if (_a[0]) *reinterpret_cast<KDevelop::IDocument**>(_a[0]) = std::move(_r); }  break;
        case 17: { KDevelop::IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])));
            if (_a[0]) *reinterpret_cast<KDevelop::IDocument**>(_a[0]) = std::move(_r); }  break;
        case 18: { KDevelop::IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KDevelop::IDocument**>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<DocumentActivationParams>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: { bool _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<DocumentActivationParams>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 21: { bool _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::Range>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<IDocument*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { KDevelop::IDocument* _r = _t->openDocument((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<KDevelop::IDocument**>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->closeAllDocuments();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IDocumentController::*)(KDevelop::IDocument * )>(_a, &IDocumentController::documentActivated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDocumentController::*)(KDevelop::IDocument * , KTextEditor::Cursor , KDevelop::IDocument * , KTextEditor::Cursor )>(_a, &IDocumentController::documentJumpPerformed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDocumentController::*)(KDevelop::IDocument * )>(_a, &IDocumentController::documentSaved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDocumentController::*)(KDevelop::IDocument * )>(_a, &IDocumentController::documentOpened, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDocumentController::*)(KDevelop::IDocument * )>(_a, &IDocumentController::documentLoaded, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDocumentController::*)(KDevelop::IDocument * )>(_a, &IDocumentController::textDocumentCreated, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDocumentController::*)(KDevelop::IDocument * )>(_a, &IDocumentController::documentClosed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDocumentController::*)(KDevelop::IDocument * )>(_a, &IDocumentController::documentStateChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDocumentController::*)(KDevelop::IDocument * )>(_a, &IDocumentController::documentContentChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDocumentController::*)(KDevelop::IDocument * )>(_a, &IDocumentController::documentLoadedPrepare, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (IDocumentController::*)(KDevelop::IDocument * , const QUrl & )>(_a, &IDocumentController::documentUrlChanged, 10))
            return;
    }
}

const QMetaObject *KDevelop::IDocumentController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::IDocumentController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop19IDocumentControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDevelop::IDocumentController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::IDocumentController::documentActivated(KDevelop::IDocument * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDevelop::IDocumentController::documentJumpPerformed(KDevelop::IDocument * _t1, KTextEditor::Cursor _t2, KDevelop::IDocument * _t3, KTextEditor::Cursor _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void KDevelop::IDocumentController::documentSaved(KDevelop::IDocument * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KDevelop::IDocumentController::documentOpened(KDevelop::IDocument * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KDevelop::IDocumentController::documentLoaded(KDevelop::IDocument * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KDevelop::IDocumentController::textDocumentCreated(KDevelop::IDocument * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KDevelop::IDocumentController::documentClosed(KDevelop::IDocument * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KDevelop::IDocumentController::documentStateChanged(KDevelop::IDocument * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KDevelop::IDocumentController::documentContentChanged(KDevelop::IDocument * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KDevelop::IDocumentController::documentLoadedPrepare(KDevelop::IDocument * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KDevelop::IDocumentController::documentUrlChanged(KDevelop::IDocument * _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}
QT_WARNING_POP
