/********************************************************************************
** Form generated from reading UI file 'mesonoptionsview.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MESONOPTIONSVIEW_H
#define UI_MESONOPTIONSVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MesonOptionsView
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *c_main;
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *t_core;
    QVBoxLayout *verticalLayout_3;
    QScrollArea *s_core;
    QWidget *c_core;
    QVBoxLayout *l_core;
    QSpacerItem *verticalSpacer;
    QWidget *t_backend;
    QVBoxLayout *verticalLayout_5;
    QScrollArea *s_backend;
    QWidget *c_backend;
    QVBoxLayout *l_backend;
    QSpacerItem *verticalSpacer_2;
    QWidget *t_base;
    QVBoxLayout *verticalLayout_8;
    QScrollArea *s_base;
    QWidget *c_base;
    QVBoxLayout *l_base;
    QSpacerItem *verticalSpacer_3;
    QWidget *t_compiler;
    QVBoxLayout *verticalLayout_16;
    QScrollArea *s_compiler;
    QWidget *c_compiler;
    QVBoxLayout *l_compiler;
    QSpacerItem *verticalSpacer_4;
    QWidget *t_directory;
    QVBoxLayout *verticalLayout_15;
    QScrollArea *s_directory;
    QWidget *c_directory;
    QVBoxLayout *l_directory;
    QSpacerItem *verticalSpacer_5;
    QWidget *t_user;
    QVBoxLayout *verticalLayout_14;
    QScrollArea *s_user;
    QWidget *c_user;
    QVBoxLayout *l_user;
    QSpacerItem *verticalSpacer_6;
    QWidget *t_test;
    QVBoxLayout *verticalLayout_13;
    QScrollArea *s_test;
    QWidget *c_test;
    QVBoxLayout *l_test;
    QSpacerItem *verticalSpacer_7;

    void setupUi(QWidget *MesonOptionsView)
    {
        if (MesonOptionsView->objectName().isEmpty())
            MesonOptionsView->setObjectName("MesonOptionsView");
        MesonOptionsView->resize(660, 600);
        verticalLayout_2 = new QVBoxLayout(MesonOptionsView);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        c_main = new QGroupBox(MesonOptionsView);
        c_main->setObjectName("c_main");
        verticalLayout = new QVBoxLayout(c_main);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(6, -1, -1, -1);
        tabWidget = new QTabWidget(c_main);
        tabWidget->setObjectName("tabWidget");
        t_core = new QWidget();
        t_core->setObjectName("t_core");
        verticalLayout_3 = new QVBoxLayout(t_core);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        s_core = new QScrollArea(t_core);
        s_core->setObjectName("s_core");
        s_core->setFrameShape(QFrame::NoFrame);
        s_core->setWidgetResizable(true);
        s_core->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        c_core = new QWidget();
        c_core->setObjectName("c_core");
        c_core->setGeometry(QRect(0, 0, 636, 522));
        l_core = new QVBoxLayout(c_core);
        l_core->setObjectName("l_core");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        l_core->addItem(verticalSpacer);

        s_core->setWidget(c_core);

        verticalLayout_3->addWidget(s_core);

        tabWidget->addTab(t_core, QString());
        t_backend = new QWidget();
        t_backend->setObjectName("t_backend");
        verticalLayout_5 = new QVBoxLayout(t_backend);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        s_backend = new QScrollArea(t_backend);
        s_backend->setObjectName("s_backend");
        s_backend->setFrameShape(QFrame::NoFrame);
        s_backend->setWidgetResizable(true);
        s_backend->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        c_backend = new QWidget();
        c_backend->setObjectName("c_backend");
        c_backend->setGeometry(QRect(0, 0, 100, 30));
        l_backend = new QVBoxLayout(c_backend);
        l_backend->setObjectName("l_backend");
        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        l_backend->addItem(verticalSpacer_2);

        s_backend->setWidget(c_backend);

        verticalLayout_5->addWidget(s_backend);

        tabWidget->addTab(t_backend, QString());
        t_base = new QWidget();
        t_base->setObjectName("t_base");
        verticalLayout_8 = new QVBoxLayout(t_base);
        verticalLayout_8->setObjectName("verticalLayout_8");
        verticalLayout_8->setContentsMargins(0, 0, 0, 0);
        s_base = new QScrollArea(t_base);
        s_base->setObjectName("s_base");
        s_base->setFrameShape(QFrame::NoFrame);
        s_base->setWidgetResizable(true);
        s_base->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        c_base = new QWidget();
        c_base->setObjectName("c_base");
        c_base->setGeometry(QRect(0, 0, 100, 30));
        l_base = new QVBoxLayout(c_base);
        l_base->setObjectName("l_base");
        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        l_base->addItem(verticalSpacer_3);

        s_base->setWidget(c_base);

        verticalLayout_8->addWidget(s_base);

        tabWidget->addTab(t_base, QString());
        t_compiler = new QWidget();
        t_compiler->setObjectName("t_compiler");
        verticalLayout_16 = new QVBoxLayout(t_compiler);
        verticalLayout_16->setObjectName("verticalLayout_16");
        verticalLayout_16->setContentsMargins(0, 0, 0, 0);
        s_compiler = new QScrollArea(t_compiler);
        s_compiler->setObjectName("s_compiler");
        s_compiler->setFrameShape(QFrame::NoFrame);
        s_compiler->setWidgetResizable(true);
        s_compiler->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        c_compiler = new QWidget();
        c_compiler->setObjectName("c_compiler");
        c_compiler->setGeometry(QRect(0, 0, 100, 30));
        l_compiler = new QVBoxLayout(c_compiler);
        l_compiler->setObjectName("l_compiler");
        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        l_compiler->addItem(verticalSpacer_4);

        s_compiler->setWidget(c_compiler);

        verticalLayout_16->addWidget(s_compiler);

        tabWidget->addTab(t_compiler, QString());
        t_directory = new QWidget();
        t_directory->setObjectName("t_directory");
        verticalLayout_15 = new QVBoxLayout(t_directory);
        verticalLayout_15->setObjectName("verticalLayout_15");
        verticalLayout_15->setContentsMargins(0, 0, 0, 0);
        s_directory = new QScrollArea(t_directory);
        s_directory->setObjectName("s_directory");
        s_directory->setFrameShape(QFrame::NoFrame);
        s_directory->setWidgetResizable(true);
        s_directory->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        c_directory = new QWidget();
        c_directory->setObjectName("c_directory");
        c_directory->setGeometry(QRect(0, 0, 100, 30));
        l_directory = new QVBoxLayout(c_directory);
        l_directory->setObjectName("l_directory");
        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        l_directory->addItem(verticalSpacer_5);

        s_directory->setWidget(c_directory);

        verticalLayout_15->addWidget(s_directory);

        tabWidget->addTab(t_directory, QString());
        t_user = new QWidget();
        t_user->setObjectName("t_user");
        verticalLayout_14 = new QVBoxLayout(t_user);
        verticalLayout_14->setObjectName("verticalLayout_14");
        verticalLayout_14->setContentsMargins(0, 0, 0, 0);
        s_user = new QScrollArea(t_user);
        s_user->setObjectName("s_user");
        s_user->setFrameShape(QFrame::NoFrame);
        s_user->setWidgetResizable(true);
        s_user->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        c_user = new QWidget();
        c_user->setObjectName("c_user");
        c_user->setGeometry(QRect(0, 0, 100, 30));
        l_user = new QVBoxLayout(c_user);
        l_user->setObjectName("l_user");
        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        l_user->addItem(verticalSpacer_6);

        s_user->setWidget(c_user);

        verticalLayout_14->addWidget(s_user);

        tabWidget->addTab(t_user, QString());
        t_test = new QWidget();
        t_test->setObjectName("t_test");
        verticalLayout_13 = new QVBoxLayout(t_test);
        verticalLayout_13->setObjectName("verticalLayout_13");
        verticalLayout_13->setContentsMargins(0, 0, 0, 0);
        s_test = new QScrollArea(t_test);
        s_test->setObjectName("s_test");
        s_test->setFrameShape(QFrame::NoFrame);
        s_test->setWidgetResizable(true);
        s_test->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        c_test = new QWidget();
        c_test->setObjectName("c_test");
        c_test->setGeometry(QRect(0, 0, 100, 30));
        l_test = new QVBoxLayout(c_test);
        l_test->setObjectName("l_test");
        verticalSpacer_7 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        l_test->addItem(verticalSpacer_7);

        s_test->setWidget(c_test);

        verticalLayout_13->addWidget(s_test);

        tabWidget->addTab(t_test, QString());

        verticalLayout->addWidget(tabWidget);


        verticalLayout_2->addWidget(c_main);


        retranslateUi(MesonOptionsView);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MesonOptionsView);
    } // setupUi

    void retranslateUi(QWidget *MesonOptionsView)
    {
        c_main->setTitle(tr2i18n("Meson Options", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(t_core), tr2i18n("Core", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(t_backend), tr2i18n("Backend", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(t_base), tr2i18n("Base", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(t_compiler), tr2i18n("Compiler", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(t_directory), tr2i18n("Directories", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(t_user), tr2i18n("Project", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(t_test), tr2i18n("Testing", nullptr));
        (void)MesonOptionsView;
    } // retranslateUi

};

namespace Ui {
    class MesonOptionsView: public Ui_MesonOptionsView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MESONOPTIONSVIEW_H

