/****************************************************************************
** Meta object code from reading C++ file 'patchreview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/patchreview/patchreview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'patchreview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17PatchReviewPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto PatchReviewPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN17PatchReviewPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PatchReviewPlugin",
        "startingNewReview",
        "",
        "patchChanged",
        "updateReview",
        "cancelReview",
        "notifyPatchChanged",
        "highlightPatch",
        "updateKompareModel",
        "forceUpdate",
        "areaChanged",
        "Sublime::Area*",
        "area",
        "executeFileReviewAction",
        "documentClosed",
        "KDevelop::IDocument*",
        "textDocumentCreated",
        "documentSaved",
        "closeReview"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'startingNewReview'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'patchChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateReview'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cancelReview'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'notifyPatchChanged'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'highlightPatch'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateKompareModel'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'forceUpdate'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'areaChanged'
        QtMocHelpers::SlotData<void(Sublime::Area *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'executeFileReviewAction'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'documentClosed'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 2 },
        }}),
        // Slot 'textDocumentCreated'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 2 },
        }}),
        // Slot 'documentSaved'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 15, 2 },
        }}),
        // Slot 'closeReview'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PatchReviewPlugin, qt_meta_tag_ZN17PatchReviewPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PatchReviewPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<KDevelop::IPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PatchReviewPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PatchReviewPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17PatchReviewPluginE_t>.metaTypes,
    nullptr
} };

void PatchReviewPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PatchReviewPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->startingNewReview(); break;
        case 1: _t->patchChanged(); break;
        case 2: _t->updateReview(); break;
        case 3: _t->cancelReview(); break;
        case 4: _t->notifyPatchChanged(); break;
        case 5: _t->highlightPatch(); break;
        case 6: _t->updateKompareModel(); break;
        case 7: _t->forceUpdate(); break;
        case 8: _t->areaChanged((*reinterpret_cast<std::add_pointer_t<Sublime::Area*>>(_a[1]))); break;
        case 9: _t->executeFileReviewAction(); break;
        case 10: _t->documentClosed((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 11: _t->textDocumentCreated((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 12: _t->documentSaved((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 13: _t->closeReview(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PatchReviewPlugin::*)()>(_a, &PatchReviewPlugin::startingNewReview, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PatchReviewPlugin::*)()>(_a, &PatchReviewPlugin::patchChanged, 1))
            return;
    }
}

const QMetaObject *PatchReviewPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PatchReviewPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PatchReviewPluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KDevelop::IPatchReview"))
        return static_cast< KDevelop::IPatchReview*>(this);
    if (!strcmp(_clname, "KDevelop::ILanguageSupport"))
        return static_cast< KDevelop::ILanguageSupport*>(this);
    if (!strcmp(_clname, "org.kdevelop.IPatchReview"))
        return static_cast< KDevelop::IPatchReview*>(this);
    if (!strcmp(_clname, "org.kdevelop.ILanguageSupport"))
        return static_cast< KDevelop::ILanguageSupport*>(this);
    return KDevelop::IPlugin::qt_metacast(_clname);
}

int PatchReviewPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDevelop::IPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void PatchReviewPlugin::startingNewReview()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PatchReviewPlugin::patchChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
