// This file is generated by kconfig_compiler_kf6 from clangtidyprojectconfig.kcfg.
// All changes you do to this file will be lost.
#ifndef CLANGTIDYPROJECTSETTINGS_H
#define CLANGTIDYPROJECTSETTINGS_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class ClangTidyProjectSettings : public KConfigSkeleton
{
  public:

    ClangTidyProjectSettings( );
    ~ClangTidyProjectSettings() override;

    /**
      Set AdditionalParameters
    */
    void setAdditionalParameters( const QString & v )
    {
      if (!isAdditionalParametersImmutable())
        mAdditionalParameters = v;
    }

    /**
      Get AdditionalParameters
    */
    QString additionalParameters() const
    {
      return mAdditionalParameters;
    }

    /**
      Is AdditionalParameters Immutable
    */
    bool isAdditionalParametersImmutable() const
    {
      return isImmutable( QStringLiteral( "additionalParameters" ) );
    }

    /**
      Set CheckSystemHeaders
    */
    void setCheckSystemHeaders( bool v )
    {
      if (!isCheckSystemHeadersImmutable())
        mCheckSystemHeaders = v;
    }

    /**
      Get CheckSystemHeaders
    */
    bool checkSystemHeaders() const
    {
      return mCheckSystemHeaders;
    }

    /**
      Is CheckSystemHeaders Immutable
    */
    bool isCheckSystemHeadersImmutable() const
    {
      return isImmutable( QStringLiteral( "checkSystemHeaders" ) );
    }

    /**
      Set UseConfigFile
    */
    void setUseConfigFile( bool v )
    {
      if (!isUseConfigFileImmutable())
        mUseConfigFile = v;
    }

    /**
      Get UseConfigFile
    */
    bool useConfigFile() const
    {
      return mUseConfigFile;
    }

    /**
      Is UseConfigFile Immutable
    */
    bool isUseConfigFileImmutable() const
    {
      return isImmutable( QStringLiteral( "useConfigFile" ) );
    }

    /**
      Set HeaderFilter
    */
    void setHeaderFilter( const QString & v )
    {
      if (!isHeaderFilterImmutable())
        mHeaderFilter = v;
    }

    /**
      Get HeaderFilter
    */
    QString headerFilter() const
    {
      return mHeaderFilter;
    }

    /**
      Is HeaderFilter Immutable
    */
    bool isHeaderFilterImmutable() const
    {
      return isImmutable( QStringLiteral( "headerFilter" ) );
    }

    /**
      Set CheckSetSelection
    */
    void setCheckSetSelection( const QString & v )
    {
      if (!isCheckSetSelectionImmutable())
        mCheckSetSelection = v;
    }

    /**
      Get CheckSetSelection
    */
    QString checkSetSelection() const
    {
      return mCheckSetSelection;
    }

    /**
      Is CheckSetSelection Immutable
    */
    bool isCheckSetSelectionImmutable() const
    {
      return isImmutable( QStringLiteral( "checkSetSelection" ) );
    }

    /**
      Set EnabledChecks
    */
    void setEnabledChecks( const QString & v )
    {
      if (!isEnabledChecksImmutable())
        mEnabledChecks = v;
    }

    /**
      Get EnabledChecks
    */
    QString enabledChecks() const
    {
      return mEnabledChecks;
    }

    /**
      Is EnabledChecks Immutable
    */
    bool isEnabledChecksImmutable() const
    {
      return isImmutable( QStringLiteral( "enabledChecks" ) );
    }

  protected:

    // ClangTidy
    QString mAdditionalParameters;
    bool mCheckSystemHeaders;
    bool mUseConfigFile;
    QString mHeaderFilter;
    QString mCheckSetSelection;
    QString mEnabledChecks;
};

#endif

