/********************************************************************************
** Form generated from reading UI file 'mesonrewriterpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MESONREWRITERPAGE_H
#define UI_MESONREWRITERPAGE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MesonRewriterPage
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *c_tabs;
    QWidget *t_project;
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *c_projectRoot;
    QHBoxLayout *c_projectName;
    QLabel *l_dispProject;
    QLabel *l_project;
    QVBoxLayout *c_project;
    QFrame *c_prSep;
    QVBoxLayout *c_defOptsRoot;
    QHBoxLayout *c_defOptTitle;
    QSpacerItem *s_defOptTitle1;
    QLabel *l_defOpts;
    QSpacerItem *s_defOptTitle2;
    QScrollArea *scroll_defOpts;
    QWidget *c_scrollDefOpts;
    QVBoxLayout *verticalLayout_3;
    QVBoxLayout *c_defOpts;
    QPushButton *b_newOpt;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *c_status;
    QLabel *l_status;
    QLabel *l_changed;

    void setupUi(QWidget *MesonRewriterPage)
    {
        if (MesonRewriterPage->objectName().isEmpty())
            MesonRewriterPage->setObjectName("MesonRewriterPage");
        MesonRewriterPage->resize(977, 657);
        verticalLayout = new QVBoxLayout(MesonRewriterPage);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        c_tabs = new QTabWidget(MesonRewriterPage);
        c_tabs->setObjectName("c_tabs");
        t_project = new QWidget();
        t_project->setObjectName("t_project");
        verticalLayout_2 = new QVBoxLayout(t_project);
        verticalLayout_2->setObjectName("verticalLayout_2");
        c_projectRoot = new QVBoxLayout();
        c_projectRoot->setObjectName("c_projectRoot");
        c_projectName = new QHBoxLayout();
        c_projectName->setObjectName("c_projectName");
        l_dispProject = new QLabel(t_project);
        l_dispProject->setObjectName("l_dispProject");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(l_dispProject->sizePolicy().hasHeightForWidth());
        l_dispProject->setSizePolicy(sizePolicy);
        l_dispProject->setMinimumSize(QSize(150, 0));

        c_projectName->addWidget(l_dispProject);

        l_project = new QLabel(t_project);
        l_project->setObjectName("l_project");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(l_project->sizePolicy().hasHeightForWidth());
        l_project->setSizePolicy(sizePolicy1);

        c_projectName->addWidget(l_project);


        c_projectRoot->addLayout(c_projectName);

        c_project = new QVBoxLayout();
        c_project->setObjectName("c_project");

        c_projectRoot->addLayout(c_project);


        verticalLayout_2->addLayout(c_projectRoot);

        c_prSep = new QFrame(t_project);
        c_prSep->setObjectName("c_prSep");
        c_prSep->setFrameShape(QFrame::Shape::HLine);
        c_prSep->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout_2->addWidget(c_prSep);

        c_defOptsRoot = new QVBoxLayout();
        c_defOptsRoot->setObjectName("c_defOptsRoot");
        c_defOptTitle = new QHBoxLayout();
        c_defOptTitle->setObjectName("c_defOptTitle");
        s_defOptTitle1 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        c_defOptTitle->addItem(s_defOptTitle1);

        l_defOpts = new QLabel(t_project);
        l_defOpts->setObjectName("l_defOpts");

        c_defOptTitle->addWidget(l_defOpts);

        s_defOptTitle2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        c_defOptTitle->addItem(s_defOptTitle2);


        c_defOptsRoot->addLayout(c_defOptTitle);

        scroll_defOpts = new QScrollArea(t_project);
        scroll_defOpts->setObjectName("scroll_defOpts");
        scroll_defOpts->setWidgetResizable(true);
        c_scrollDefOpts = new QWidget();
        c_scrollDefOpts->setObjectName("c_scrollDefOpts");
        c_scrollDefOpts->setGeometry(QRect(0, 0, 939, 487));
        verticalLayout_3 = new QVBoxLayout(c_scrollDefOpts);
        verticalLayout_3->setObjectName("verticalLayout_3");
        c_defOpts = new QVBoxLayout();
        c_defOpts->setObjectName("c_defOpts");

        verticalLayout_3->addLayout(c_defOpts);

        b_newOpt = new QPushButton(c_scrollDefOpts);
        b_newOpt->setObjectName("b_newOpt");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        b_newOpt->setIcon(icon);

        verticalLayout_3->addWidget(b_newOpt);

        verticalSpacer = new QSpacerItem(20, 423, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        scroll_defOpts->setWidget(c_scrollDefOpts);

        c_defOptsRoot->addWidget(scroll_defOpts);


        verticalLayout_2->addLayout(c_defOptsRoot);

        c_tabs->addTab(t_project, QString());

        verticalLayout->addWidget(c_tabs);

        c_status = new QHBoxLayout();
        c_status->setObjectName("c_status");
        l_status = new QLabel(MesonRewriterPage);
        l_status->setObjectName("l_status");

        c_status->addWidget(l_status);

        l_changed = new QLabel(MesonRewriterPage);
        l_changed->setObjectName("l_changed");
        l_changed->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        c_status->addWidget(l_changed);


        verticalLayout->addLayout(c_status);


        retranslateUi(MesonRewriterPage);
        QObject::connect(b_newOpt, SIGNAL(clicked()), MesonRewriterPage, SLOT(newOption()));

        c_tabs->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MesonRewriterPage);
    } // setupUi

    void retranslateUi(QWidget *MesonRewriterPage)
    {
        MesonRewriterPage->setWindowTitle(tr2i18n("Meson project settings", nullptr));
        l_dispProject->setText(tr2i18n("Name:", nullptr));
        l_project->setText(tr2i18n("<html><head/><body><h3>projectName</h3></body></html>", nullptr));
        l_defOpts->setText(tr2i18n("Project default options", nullptr));
        b_newOpt->setText(tr2i18n("New Option", nullptr));
        c_tabs->setTabText(c_tabs->indexOf(t_project), tr2i18n("Project", nullptr));
#if QT_CONFIG(tooltip)
        c_tabs->setTabToolTip(c_tabs->indexOf(t_project), tr2i18n("Project settings", nullptr));
#endif // QT_CONFIG(tooltip)
        l_status->setText(tr2i18n("Status message...", nullptr));
        l_changed->setText(tr2i18n("Num changed", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MesonRewriterPage: public Ui_MesonRewriterPage {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MESONREWRITERPAGE_H

