/********************************************************************************
** Form generated from reading UI file 'dvcsimportmetadatawidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DVCSIMPORTMETADATAWIDGET_H
#define UI_DVCSIMPORTMETADATAWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KTextEdit"
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_DvcsImportMetadataWidget
{
public:
    QFormLayout *formLayout;
    QLabel *labelUrl;
    KUrlRequester *sourceLoc;
    QLabel *label;
    KTextEdit *message;

    void setupUi(QWidget *DvcsImportMetadataWidget)
    {
        if (DvcsImportMetadataWidget->objectName().isEmpty())
            DvcsImportMetadataWidget->setObjectName("DvcsImportMetadataWidget");
        DvcsImportMetadataWidget->resize(581, 37);
        formLayout = new QFormLayout(DvcsImportMetadataWidget);
        formLayout->setContentsMargins(0, 0, 0, 0);
        formLayout->setObjectName("formLayout");
        labelUrl = new QLabel(DvcsImportMetadataWidget);
        labelUrl->setObjectName("labelUrl");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelUrl);

        sourceLoc = new KUrlRequester(DvcsImportMetadataWidget);
        sourceLoc->setObjectName("sourceLoc");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, sourceLoc);

        label = new QLabel(DvcsImportMetadataWidget);
        label->setObjectName("label");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label);

        message = new KTextEdit(DvcsImportMetadataWidget);
        message->setObjectName("message");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(1);
        sizePolicy.setHeightForWidth(message->sizePolicy().hasHeightForWidth());
        message->setSizePolicy(sizePolicy);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, message);


        retranslateUi(DvcsImportMetadataWidget);

        QMetaObject::connectSlotsByName(DvcsImportMetadataWidget);
    } // setupUi

    void retranslateUi(QWidget *DvcsImportMetadataWidget)
    {
        labelUrl->setText(tr2i18n("Source directory:", "@label:textbox"));
        label->setText(tr2i18n("Commit message:", "@label:textbox"));
        (void)DvcsImportMetadataWidget;
    } // retranslateUi

};

namespace Ui {
    class DvcsImportMetadataWidget: public Ui_DvcsImportMetadataWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DVCSIMPORTMETADATAWIDGET_H

