/********************************************************************************
** Form generated from reading UI file 'templateselection.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEMPLATESELECTION_H
#define UI_TEMPLATESELECTION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "util/multilevellistview.h"

QT_BEGIN_NAMESPACE

class Ui_TemplateSelection
{
public:
    QVBoxLayout *verticalLayout;
    KDevelop::MultiLevelListView *view;
    QFrame *line;
    QLabel *previewLabel;
    QTabWidget *tabWidget;

    void setupUi(QWidget *TemplateSelection)
    {
        if (TemplateSelection->objectName().isEmpty())
            TemplateSelection->setObjectName("TemplateSelection");
        TemplateSelection->resize(600, 600);
        verticalLayout = new QVBoxLayout(TemplateSelection);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        view = new KDevelop::MultiLevelListView(TemplateSelection);
        view->setObjectName("view");

        verticalLayout->addWidget(view);

        line = new QFrame(TemplateSelection);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        previewLabel = new QLabel(TemplateSelection);
        previewLabel->setObjectName("previewLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(previewLabel->sizePolicy().hasHeightForWidth());
        previewLabel->setSizePolicy(sizePolicy);
        previewLabel->setText(QString::fromUtf8(""));
        previewLabel->setWordWrap(true);

        verticalLayout->addWidget(previewLabel);

        tabWidget = new QTabWidget(TemplateSelection);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setDocumentMode(true);

        verticalLayout->addWidget(tabWidget);


        retranslateUi(TemplateSelection);

        QMetaObject::connectSlotsByName(TemplateSelection);
    } // setupUi

    void retranslateUi(QWidget *TemplateSelection)
    {
        (void)TemplateSelection;
    } // retranslateUi

};

namespace Ui {
    class TemplateSelection: public Ui_TemplateSelection {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TEMPLATESELECTION_H

