/****************************************************************************
** Meta object code from reading C++ file 'projectchangesmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/kdevplatform/project/projectchangesmodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'projectchangesmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop19ProjectChangesModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::ProjectChangesModel::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop19ProjectChangesModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::ProjectChangesModel",
        "reloadAll",
        "",
        "reload",
        "QList<KDevelop::IProject*>",
        "p",
        "QList<QUrl>",
        "addProject",
        "KDevelop::IProject*",
        "removeProject",
        "statusReady",
        "KJob*",
        "job",
        "documentSaved",
        "KDevelop::IDocument*",
        "itemsAdded",
        "QModelIndex",
        "idx",
        "start",
        "end",
        "jobUnregistered",
        "repositoryBranchChanged",
        "QUrl",
        "url",
        "branchNameReady",
        "KDevelop::VcsJob*"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'reloadAll'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reload'
        QtMocHelpers::SlotData<void(const QList<KDevelop::IProject*> &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'reload'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 5 },
        }}),
        // Slot 'addProject'
        QtMocHelpers::SlotData<void(KDevelop::IProject *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 5 },
        }}),
        // Slot 'removeProject'
        QtMocHelpers::SlotData<void(KDevelop::IProject *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 5 },
        }}),
        // Slot 'statusReady'
        QtMocHelpers::SlotData<void(KJob *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'documentSaved'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Slot 'itemsAdded'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::Int, 18 }, { QMetaType::Int, 19 },
        }}),
        // Slot 'jobUnregistered'
        QtMocHelpers::SlotData<void(KJob *)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 2 },
        }}),
        // Slot 'repositoryBranchChanged'
        QtMocHelpers::SlotData<void(const QUrl &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'branchNameReady'
        QtMocHelpers::SlotData<void(KDevelop::VcsJob *)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProjectChangesModel, qt_meta_tag_ZN8KDevelop19ProjectChangesModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::ProjectChangesModel::staticMetaObject = { {
    QMetaObject::SuperData::link<VcsFileChangesModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop19ProjectChangesModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop19ProjectChangesModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop19ProjectChangesModelE_t>.metaTypes,
    nullptr
} };

void KDevelop::ProjectChangesModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProjectChangesModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->reloadAll(); break;
        case 1: _t->reload((*reinterpret_cast<std::add_pointer_t<QList<KDevelop::IProject*>>>(_a[1]))); break;
        case 2: _t->reload((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 3: _t->addProject((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 4: _t->removeProject((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 5: _t->statusReady((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 6: _t->documentSaved((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 7: _t->itemsAdded((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 8: _t->jobUnregistered((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 9: _t->repositoryBranchChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 10: _t->branchNameReady((*reinterpret_cast<std::add_pointer_t<KDevelop::VcsJob*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *KDevelop::ProjectChangesModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::ProjectChangesModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop19ProjectChangesModelE_t>.strings))
        return static_cast<void*>(this);
    return VcsFileChangesModel::qt_metacast(_clname);
}

int KDevelop::ProjectChangesModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = VcsFileChangesModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}
QT_WARNING_POP
