/********************************************************************************
** Form generated from reading UI file 'projectconfigpage.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTCONFIGPAGE_H
#define UI_PROJECTCONFIGPAGE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KMessageWidget"

namespace cppcheck {

class Ui_ProjectConfigPage
{
public:
    QVBoxLayout *verticalLayout_5;
    QTabWidget *tabWidget;
    QWidget *tabChecks;
    QVBoxLayout *verticalLayout_6;
    QGridLayout *gridLayout;
    QCheckBox *kcfg_checkUnusedFunction;
    QCheckBox *kcfg_inconclusiveAnalysis;
    QCheckBox *kcfg_checkInformation;
    QCheckBox *kcfg_checkMissingInclude;
    QCheckBox *kcfg_checkPerformance;
    QCheckBox *kcfg_forceCheck;
    QCheckBox *kcfg_checkPortability;
    QCheckBox *kcfg_checkStyle;
    QCheckBox *kcfg_checkConfig;
    QWidget *tabIncludes;
    QVBoxLayout *verticalLayout_3;
    QCheckBox *kcfg_useProjectIncludes;
    QCheckBox *kcfg_useSystemIncludes;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    QLineEdit *kcfg_ignoredIncludes;
    QSpacerItem *verticalSpacer;
    QWidget *tabExtra;
    QVBoxLayout *verticalLayout_4;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *extraParametersLayout;
    QLabel *extraLabel;
    QLineEdit *kcfg_extraParameters;
    QSpacerItem *verticalSpacer_2;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLineEdit *commandLineFilter;
    QCheckBox *commandLineBreaks;
    QPlainTextEdit *commandLine;
    KMessageWidget *messageWidget;

    void setupUi(QWidget *cppcheck__ProjectConfigPage)
    {
        if (cppcheck__ProjectConfigPage->objectName().isEmpty())
            cppcheck__ProjectConfigPage->setObjectName("cppcheck__ProjectConfigPage");
        cppcheck__ProjectConfigPage->resize(443, 502);
        verticalLayout_5 = new QVBoxLayout(cppcheck__ProjectConfigPage);
        verticalLayout_5->setObjectName("verticalLayout_5");
        verticalLayout_5->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(cppcheck__ProjectConfigPage);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy);
        tabChecks = new QWidget();
        tabChecks->setObjectName("tabChecks");
        verticalLayout_6 = new QVBoxLayout(tabChecks);
        verticalLayout_6->setObjectName("verticalLayout_6");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        kcfg_checkUnusedFunction = new QCheckBox(tabChecks);
        kcfg_checkUnusedFunction->setObjectName("kcfg_checkUnusedFunction");
        kcfg_checkUnusedFunction->setChecked(false);

        gridLayout->addWidget(kcfg_checkUnusedFunction, 2, 0, 1, 1);

        kcfg_inconclusiveAnalysis = new QCheckBox(tabChecks);
        kcfg_inconclusiveAnalysis->setObjectName("kcfg_inconclusiveAnalysis");

        gridLayout->addWidget(kcfg_inconclusiveAnalysis, 3, 0, 1, 1);

        kcfg_checkInformation = new QCheckBox(tabChecks);
        kcfg_checkInformation->setObjectName("kcfg_checkInformation");
        kcfg_checkInformation->setChecked(false);

        gridLayout->addWidget(kcfg_checkInformation, 1, 1, 1, 1);

        kcfg_checkMissingInclude = new QCheckBox(tabChecks);
        kcfg_checkMissingInclude->setObjectName("kcfg_checkMissingInclude");
        kcfg_checkMissingInclude->setChecked(false);

        gridLayout->addWidget(kcfg_checkMissingInclude, 2, 1, 1, 1);

        kcfg_checkPerformance = new QCheckBox(tabChecks);
        kcfg_checkPerformance->setObjectName("kcfg_checkPerformance");
        kcfg_checkPerformance->setChecked(false);

        gridLayout->addWidget(kcfg_checkPerformance, 0, 1, 1, 1);

        kcfg_forceCheck = new QCheckBox(tabChecks);
        kcfg_forceCheck->setObjectName("kcfg_forceCheck");

        gridLayout->addWidget(kcfg_forceCheck, 3, 1, 1, 1);

        kcfg_checkPortability = new QCheckBox(tabChecks);
        kcfg_checkPortability->setObjectName("kcfg_checkPortability");
        kcfg_checkPortability->setChecked(false);

        gridLayout->addWidget(kcfg_checkPortability, 1, 0, 1, 1);

        kcfg_checkStyle = new QCheckBox(tabChecks);
        kcfg_checkStyle->setObjectName("kcfg_checkStyle");
        kcfg_checkStyle->setChecked(false);

        gridLayout->addWidget(kcfg_checkStyle, 0, 0, 1, 1);

        kcfg_checkConfig = new QCheckBox(tabChecks);
        kcfg_checkConfig->setObjectName("kcfg_checkConfig");

        gridLayout->addWidget(kcfg_checkConfig, 4, 0, 1, 1);


        verticalLayout_6->addLayout(gridLayout);

        tabWidget->addTab(tabChecks, QString());
        tabIncludes = new QWidget();
        tabIncludes->setObjectName("tabIncludes");
        verticalLayout_3 = new QVBoxLayout(tabIncludes);
        verticalLayout_3->setObjectName("verticalLayout_3");
        kcfg_useProjectIncludes = new QCheckBox(tabIncludes);
        kcfg_useProjectIncludes->setObjectName("kcfg_useProjectIncludes");
        kcfg_useProjectIncludes->setChecked(false);

        verticalLayout_3->addWidget(kcfg_useProjectIncludes);

        kcfg_useSystemIncludes = new QCheckBox(tabIncludes);
        kcfg_useSystemIncludes->setObjectName("kcfg_useSystemIncludes");
        kcfg_useSystemIncludes->setEnabled(false);
        kcfg_useSystemIncludes->setCheckable(true);
        kcfg_useSystemIncludes->setChecked(false);

        verticalLayout_3->addWidget(kcfg_useSystemIncludes);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label = new QLabel(tabIncludes);
        label->setObjectName("label");

        horizontalLayout_2->addWidget(label);

        kcfg_ignoredIncludes = new QLineEdit(tabIncludes);
        kcfg_ignoredIncludes->setObjectName("kcfg_ignoredIncludes");

        horizontalLayout_2->addWidget(kcfg_ignoredIncludes);


        verticalLayout_3->addLayout(horizontalLayout_2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer);

        tabWidget->addTab(tabIncludes, QString());
        tabExtra = new QWidget();
        tabExtra->setObjectName("tabExtra");
        verticalLayout_4 = new QVBoxLayout(tabExtra);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        extraParametersLayout = new QHBoxLayout();
        extraParametersLayout->setObjectName("extraParametersLayout");
        extraParametersLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        extraLabel = new QLabel(tabExtra);
        extraLabel->setObjectName("extraLabel");

        extraParametersLayout->addWidget(extraLabel);

        kcfg_extraParameters = new QLineEdit(tabExtra);
        kcfg_extraParameters->setObjectName("kcfg_extraParameters");

        extraParametersLayout->addWidget(kcfg_extraParameters);


        verticalLayout->addLayout(extraParametersLayout);


        verticalLayout_4->addLayout(verticalLayout);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer_2);

        tabWidget->addTab(tabExtra, QString());

        verticalLayout_5->addWidget(tabWidget);

        groupBox_2 = new QGroupBox(cppcheck__ProjectConfigPage);
        groupBox_2->setObjectName("groupBox_2");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy1);
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        commandLineFilter = new QLineEdit(groupBox_2);
        commandLineFilter->setObjectName("commandLineFilter");
        commandLineFilter->setClearButtonEnabled(true);

        horizontalLayout->addWidget(commandLineFilter);

        commandLineBreaks = new QCheckBox(groupBox_2);
        commandLineBreaks->setObjectName("commandLineBreaks");
        commandLineBreaks->setChecked(true);

        horizontalLayout->addWidget(commandLineBreaks);


        verticalLayout_2->addLayout(horizontalLayout);

        commandLine = new QPlainTextEdit(groupBox_2);
        commandLine->setObjectName("commandLine");
        commandLine->setEnabled(true);
        commandLine->setReadOnly(true);

        verticalLayout_2->addWidget(commandLine);


        verticalLayout_5->addWidget(groupBox_2);

        messageWidget = new KMessageWidget(cppcheck__ProjectConfigPage);
        messageWidget->setObjectName("messageWidget");
        messageWidget->setWordWrap(true);
        messageWidget->setCloseButtonVisible(false);
        messageWidget->setMessageType(KMessageWidget::Error);

        verticalLayout_5->addWidget(messageWidget);

#if QT_CONFIG(shortcut)
        label->setBuddy(kcfg_ignoredIncludes);
        extraLabel->setBuddy(kcfg_extraParameters);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(tabWidget, kcfg_checkStyle);
        QWidget::setTabOrder(kcfg_checkStyle, kcfg_checkPerformance);
        QWidget::setTabOrder(kcfg_checkPerformance, kcfg_checkPortability);
        QWidget::setTabOrder(kcfg_checkPortability, kcfg_checkInformation);
        QWidget::setTabOrder(kcfg_checkInformation, kcfg_checkUnusedFunction);
        QWidget::setTabOrder(kcfg_checkUnusedFunction, kcfg_checkMissingInclude);
        QWidget::setTabOrder(kcfg_checkMissingInclude, kcfg_inconclusiveAnalysis);
        QWidget::setTabOrder(kcfg_inconclusiveAnalysis, kcfg_forceCheck);
        QWidget::setTabOrder(kcfg_forceCheck, kcfg_checkConfig);
        QWidget::setTabOrder(kcfg_checkConfig, kcfg_useProjectIncludes);
        QWidget::setTabOrder(kcfg_useProjectIncludes, kcfg_useSystemIncludes);
        QWidget::setTabOrder(kcfg_useSystemIncludes, kcfg_ignoredIncludes);
        QWidget::setTabOrder(kcfg_ignoredIncludes, kcfg_extraParameters);
        QWidget::setTabOrder(kcfg_extraParameters, commandLineBreaks);
        QWidget::setTabOrder(commandLineBreaks, commandLine);

        retranslateUi(cppcheck__ProjectConfigPage);
        QObject::connect(kcfg_useProjectIncludes, &QCheckBox::toggled, kcfg_useSystemIncludes, &QCheckBox::setEnabled);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(cppcheck__ProjectConfigPage);
    } // setupUi

    void retranslateUi(QWidget *cppcheck__ProjectConfigPage)
    {
#if QT_CONFIG(tooltip)
        kcfg_checkUnusedFunction->setToolTip(tr2i18n("Check for unused functions. It is recommend to only enable this when the whole program is scanned", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_checkUnusedFunction->setText(tr2i18n("Unused function", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_inconclusiveAnalysis->setToolTip(tr2i18n("Allow that Cppcheck reports even though the analysis is inconclusive. There are false positives with this option. Each result must be carefully investigated before you know if it is good or bad.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_inconclusiveAnalysis->setText(tr2i18n("Inconclusive analysis", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_checkInformation->setToolTip(tr2i18n("Enable information messages", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_checkInformation->setText(tr2i18n("Information", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_checkMissingInclude->setToolTip(tr2i18n("Warn if there are missing includes. For detailed information use 'check-config'", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_checkMissingInclude->setText(tr2i18n("Missing include", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_checkPerformance->setToolTip(tr2i18n("Enable performance messages", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_checkPerformance->setText(tr2i18n("Performance", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_forceCheck->setToolTip(tr2i18n("<p>Force checking of files that have a lot of configurations. Error is printed if such a file is found so there is no reason to use this by default. If used together with '--max-configs=', the last option is the one that is effective.<br/><br/>Be careful with using this option - it can dramatically slow checking.</p>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_forceCheck->setText(tr2i18n("Force checking", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_checkPortability->setToolTip(tr2i18n("Enable portability messages", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_checkPortability->setText(tr2i18n("Portability", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_checkStyle->setToolTip(tr2i18n("Enable all coding style checks. All messages with the severities 'style', 'performance' and 'portability' are enabled.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_checkStyle->setText(tr2i18n("Style", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_checkConfig->setToolTip(tr2i18n("Check Cppcheck configuration. The normal code analysis is disabled by this flag.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_checkConfig->setText(tr2i18n("Check config", "@option:check"));
        tabWidget->setTabText(tabWidget->indexOf(tabChecks), tr2i18n("Checks", "@title:tab"));
#if QT_CONFIG(tooltip)
        kcfg_useProjectIncludes->setToolTip(tr2i18n("Add 'project' include directories to Cppcheck arguments. This option adds only paths related with project's root and build directories.", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_useProjectIncludes->setText(tr2i18n("Use 'project' include dirs", "@option:check"));
#if QT_CONFIG(tooltip)
        kcfg_useSystemIncludes->setToolTip(tr2i18n("<p>Add other, 'system' include directories to Cppcheck arguments.<br/><br/>Be careful with using this option - it can dramatically slow checking.</p>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        kcfg_useSystemIncludes->setText(tr2i18n("Use 'system' include dirs", "@option:check"));
        label->setText(tr2i18n("&Ignored includes:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_ignoredIncludes->setToolTip(tr2i18n("<html>\n"
"\n"
"<p>Defines semicolon-separated list of ignored include directories.</p>\n"
"\n"
"<p>You can use the following placeholders:</p>\n"
"\n"
"<p><b><tt>%p</tt></b> - Gets replaced by the URL of the project's root directory.</p>\n"
"\n"
"<p><b><tt>%b</tt></b> - Gets replaced by the URL of the project's build directory.</p>\n"
"\n"
"</html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(tabIncludes), tr2i18n("Include Directories", "@title:tab"));
        extraLabel->setText(tr2i18n("Ex&tra parameters:", "@label:textbox"));
#if QT_CONFIG(tooltip)
        kcfg_extraParameters->setToolTip(tr2i18n("<html>\n"
"\n"
"<p>Defines additional parameters for cppcheck (see documentation).</p>\n"
"\n"
"<p>You can use the following placeholders:</p>\n"
"\n"
"<p><b><tt>%p</tt></b> - Gets replaced by the URL of the project's root directory.</p>\n"
"\n"
"<p><b><tt>%b</tt></b> - Gets replaced by the URL of the project's build directory.</p>\n"
"\n"
"</html>", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        tabWidget->setTabText(tabWidget->indexOf(tabExtra), tr2i18n("Extra Parameters", "@title:tab"));
        groupBox_2->setTitle(tr2i18n("Command Line", "@title:group"));
        commandLineFilter->setPlaceholderText(tr2i18n("Search...", "@info:placeholder"));
        commandLineBreaks->setText(tr2i18n("Break lines", "@option:check"));
        messageWidget->setText(QString());
        (void)cppcheck__ProjectConfigPage;
    } // retranslateUi

};

} // namespace cppcheck

namespace cppcheck {
namespace Ui {
    class ProjectConfigPage: public Ui_ProjectConfigPage {};
} // namespace Ui
} // namespace cppcheck

#endif // PROJECTCONFIGPAGE_H

