/********************************************************************************
** Form generated from reading UI file 'vcseventwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VCSEVENTWIDGET_H
#define UI_VCSEVENTWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_VcsEventWidget
{
public:
    QHBoxLayout *horizontalLayout;
    QSplitter *splitter_2;
    QTreeView *eventView;
    QSplitter *splitter;
    QTreeView *itemEventView;
    QTextBrowser *message;

    void setupUi(QWidget *VcsEventWidget)
    {
        if (VcsEventWidget->objectName().isEmpty())
            VcsEventWidget->setObjectName("VcsEventWidget");
        VcsEventWidget->resize(814, 392);
        VcsEventWidget->setMinimumSize(QSize(814, 392));
        horizontalLayout = new QHBoxLayout(VcsEventWidget);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        splitter_2 = new QSplitter(VcsEventWidget);
        splitter_2->setObjectName("splitter_2");
        splitter_2->setOrientation(Qt::Vertical);
        eventView = new QTreeView(splitter_2);
        eventView->setObjectName("eventView");
        eventView->setAlternatingRowColors(true);
        eventView->setSelectionMode(QAbstractItemView::ExtendedSelection);
        eventView->setSelectionBehavior(QAbstractItemView::SelectRows);
        eventView->setRootIsDecorated(false);
        eventView->setUniformRowHeights(true);
        eventView->setSortingEnabled(false);
        eventView->setWordWrap(true);
        splitter_2->addWidget(eventView);
        splitter = new QSplitter(splitter_2);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        itemEventView = new QTreeView(splitter);
        itemEventView->setObjectName("itemEventView");
        itemEventView->setEnabled(false);
        itemEventView->setEditTriggers(QAbstractItemView::NoEditTriggers);
        itemEventView->setAlternatingRowColors(true);
        itemEventView->setSelectionMode(QAbstractItemView::NoSelection);
        itemEventView->setSelectionBehavior(QAbstractItemView::SelectRows);
        itemEventView->setTextElideMode(Qt::ElideRight);
        itemEventView->setRootIsDecorated(false);
        splitter->addWidget(itemEventView);
        message = new QTextBrowser(splitter);
        message->setObjectName("message");
        message->setEnabled(false);
        message->setOpenLinks(false);
        splitter->addWidget(message);
        splitter_2->addWidget(splitter);

        horizontalLayout->addWidget(splitter_2);

        QWidget::setTabOrder(eventView, message);

        retranslateUi(VcsEventWidget);

        QMetaObject::connectSlotsByName(VcsEventWidget);
    } // setupUi

    void retranslateUi(QWidget *VcsEventWidget)
    {
        (void)VcsEventWidget;
    } // retranslateUi

};

namespace Ui {
    class VcsEventWidget: public Ui_VcsEventWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VCSEVENTWIDGET_H

