/********************************************************************************
** Form generated from reading UI file 'templateconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEMPLATECONFIG_H
#define UI_TEMPLATECONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_TemplateConfig
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;

    void setupUi(QWidget *TemplateConfig)
    {
        if (TemplateConfig->objectName().isEmpty())
            TemplateConfig->setObjectName("TemplateConfig");
        TemplateConfig->resize(542, 396);
        verticalLayout = new QVBoxLayout(TemplateConfig);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(TemplateConfig);
        tabWidget->setObjectName("tabWidget");

        verticalLayout->addWidget(tabWidget);


        retranslateUi(TemplateConfig);

        QMetaObject::connectSlotsByName(TemplateConfig);
    } // setupUi

    void retranslateUi(QWidget *TemplateConfig)
    {
        (void)TemplateConfig;
    } // retranslateUi

};

namespace Ui {
    class TemplateConfig: public Ui_TemplateConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TEMPLATECONFIG_H

