/****************************************************************************
** Meta object code from reading C++ file 'abstractnavigationwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/kdevplatform/language/duchain/navigation/abstractnavigationwidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractnavigationwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop24AbstractNavigationWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::AbstractNavigationWidget::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop24AbstractNavigationWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::AbstractNavigationWidget",
        "sizeHintChanged",
        "",
        "contextChanged",
        "wasInitial",
        "isInitial",
        "next",
        "previous",
        "up",
        "down",
        "accept",
        "back",
        "resetNavigationState",
        "embeddedWidgetRight",
        "embeddedWidgetLeft",
        "embeddedWidgetAccept",
        "embeddedWidgetUp",
        "embeddedWidgetDown",
        "navigateDeclaration",
        "KDevelop::IndexedDeclaration",
        "decl"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sizeHintChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contextChanged'
        QtMocHelpers::SignalData<void(bool, bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'next'
        QtMocHelpers::SlotData<bool()>(6, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'previous'
        QtMocHelpers::SlotData<bool()>(7, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'up'
        QtMocHelpers::SlotData<bool()>(8, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'down'
        QtMocHelpers::SlotData<bool()>(9, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'back'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetNavigationState'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'embeddedWidgetRight'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'embeddedWidgetLeft'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'embeddedWidgetAccept'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'embeddedWidgetUp'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'embeddedWidgetDown'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'navigateDeclaration'
        QtMocHelpers::SlotData<void(const KDevelop::IndexedDeclaration &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractNavigationWidget, qt_meta_tag_ZN8KDevelop24AbstractNavigationWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::AbstractNavigationWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop24AbstractNavigationWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop24AbstractNavigationWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop24AbstractNavigationWidgetE_t>.metaTypes,
    nullptr
} };

void KDevelop::AbstractNavigationWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractNavigationWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sizeHintChanged(); break;
        case 1: _t->contextChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: { bool _r = _t->next();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->previous();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->up();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->down();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->accept(); break;
        case 7: _t->back(); break;
        case 8: _t->resetNavigationState(); break;
        case 9: _t->embeddedWidgetRight(); break;
        case 10: _t->embeddedWidgetLeft(); break;
        case 11: _t->embeddedWidgetAccept(); break;
        case 12: _t->embeddedWidgetUp(); break;
        case 13: _t->embeddedWidgetDown(); break;
        case 14: _t->navigateDeclaration((*reinterpret_cast<std::add_pointer_t<KDevelop::IndexedDeclaration>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IndexedDeclaration >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractNavigationWidget::*)()>(_a, &AbstractNavigationWidget::sizeHintChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractNavigationWidget::*)(bool , bool )>(_a, &AbstractNavigationWidget::contextChanged, 1))
            return;
    }
}

const QMetaObject *KDevelop::AbstractNavigationWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::AbstractNavigationWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop24AbstractNavigationWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QuickOpenEmbeddedWidgetInterface"))
        return static_cast< QuickOpenEmbeddedWidgetInterface*>(this);
    if (!strcmp(_clname, "org.kdevelop.QuickOpenEmbeddedWidgetInterface"))
        return static_cast< KDevelop::QuickOpenEmbeddedWidgetInterface*>(this);
    return QWidget::qt_metacast(_clname);
}

int KDevelop::AbstractNavigationWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::AbstractNavigationWidget::sizeHintChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KDevelop::AbstractNavigationWidget::contextChanged(bool _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
