/********************************************************************************
** Form generated from reading UI file 'cmakebuildsettings.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CMAKEBUILDSETTINGS_H
#define UI_CMAKEBUILDSETTINGS_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"
#include "KUrlRequester"
#include "shell/environmentconfigurebutton.h"
#include "util/environmentselectionwidget.h"

QT_BEGIN_NAMESPACE

class Ui_CMakeBuildSettings
{
public:
    QVBoxLayout *vboxLayout;
    QHBoxLayout *hboxLayout;
    KComboBox *buildDirs;
    QPushButton *addBuildDir;
    QPushButton *removeBuildDir;
    QGroupBox *groupBox;
    QVBoxLayout *vboxLayout1;
    QTableView *cacheList;
    QLabel *label_6;
    QLabel *commentText;
    QPushButton *showAdvanced;
    QGroupBox *advancedBox;
    QFormLayout *formLayout;
    QLabel *installationPrefixLabel;
    KUrlRequester *installationPrefix;
    QLabel *buildTypeLabel;
    QComboBox *buildType;
    QLabel *extraArgumentsLabel;
    KComboBox *extraArguments;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout;
    KDevelop::EnvironmentSelectionWidget *environment;
    KDevelop::EnvironmentConfigureButton *configureEnvironment;
    QCheckBox *showInternal;
    QCheckBox *autoConfigureOnCMakeListsChanges;
    KUrlRequester *cMakeExecutable;
    QLabel *label;

    void setupUi(QWidget *CMakeBuildSettings)
    {
        if (CMakeBuildSettings->objectName().isEmpty())
            CMakeBuildSettings->setObjectName("CMakeBuildSettings");
        CMakeBuildSettings->resize(605, 607);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(CMakeBuildSettings->sizePolicy().hasHeightForWidth());
        CMakeBuildSettings->setSizePolicy(sizePolicy);
        vboxLayout = new QVBoxLayout(CMakeBuildSettings);
        vboxLayout->setObjectName("vboxLayout");
        vboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout = new QHBoxLayout();
        hboxLayout->setObjectName("hboxLayout");
        buildDirs = new KComboBox(CMakeBuildSettings);
        buildDirs->setObjectName("buildDirs");

        hboxLayout->addWidget(buildDirs);

        addBuildDir = new QPushButton(CMakeBuildSettings);
        addBuildDir->setObjectName("addBuildDir");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(addBuildDir->sizePolicy().hasHeightForWidth());
        addBuildDir->setSizePolicy(sizePolicy1);
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addBuildDir->setIcon(icon);

        hboxLayout->addWidget(addBuildDir);

        removeBuildDir = new QPushButton(CMakeBuildSettings);
        removeBuildDir->setObjectName("removeBuildDir");
        sizePolicy1.setHeightForWidth(removeBuildDir->sizePolicy().hasHeightForWidth());
        removeBuildDir->setSizePolicy(sizePolicy1);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        removeBuildDir->setIcon(icon1);

        hboxLayout->addWidget(removeBuildDir);


        vboxLayout->addLayout(hboxLayout);

        groupBox = new QGroupBox(CMakeBuildSettings);
        groupBox->setObjectName("groupBox");
        vboxLayout1 = new QVBoxLayout(groupBox);
        vboxLayout1->setObjectName("vboxLayout1");
        cacheList = new QTableView(groupBox);
        cacheList->setObjectName("cacheList");

        vboxLayout1->addWidget(cacheList);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");
        QFont font;
        font.setBold(true);
        label_6->setFont(font);

        vboxLayout1->addWidget(label_6);

        commentText = new QLabel(groupBox);
        commentText->setObjectName("commentText");

        vboxLayout1->addWidget(commentText);


        vboxLayout->addWidget(groupBox);

        showAdvanced = new QPushButton(CMakeBuildSettings);
        showAdvanced->setObjectName("showAdvanced");
        showAdvanced->setCheckable(true);
        showAdvanced->setFlat(false);

        vboxLayout->addWidget(showAdvanced);

        advancedBox = new QGroupBox(CMakeBuildSettings);
        advancedBox->setObjectName("advancedBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(advancedBox->sizePolicy().hasHeightForWidth());
        advancedBox->setSizePolicy(sizePolicy2);
        formLayout = new QFormLayout(advancedBox);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        installationPrefixLabel = new QLabel(advancedBox);
        installationPrefixLabel->setObjectName("installationPrefixLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, installationPrefixLabel);

        installationPrefix = new KUrlRequester(advancedBox);
        installationPrefix->setObjectName("installationPrefix");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, installationPrefix);

        buildTypeLabel = new QLabel(advancedBox);
        buildTypeLabel->setObjectName("buildTypeLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, buildTypeLabel);

        buildType = new QComboBox(advancedBox);
        buildType->addItem(QString::fromUtf8("Debug"));
        buildType->addItem(QString::fromUtf8("Release"));
        buildType->addItem(QString::fromUtf8("RelWithDebInfo"));
        buildType->addItem(QString::fromUtf8("MinSizeRel"));
        buildType->setObjectName("buildType");
        buildType->setEditable(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, buildType);

        extraArgumentsLabel = new QLabel(advancedBox);
        extraArgumentsLabel->setObjectName("extraArgumentsLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, extraArgumentsLabel);

        extraArguments = new KComboBox(advancedBox);
        extraArguments->setObjectName("extraArguments");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(extraArguments->sizePolicy().hasHeightForWidth());
        extraArguments->setSizePolicy(sizePolicy3);
        extraArguments->setEditable(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, extraArguments);

        label_2 = new QLabel(advancedBox);
        label_2->setObjectName("label_2");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        environment = new KDevelop::EnvironmentSelectionWidget(advancedBox);
        environment->setObjectName("environment");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(environment->sizePolicy().hasHeightForWidth());
        environment->setSizePolicy(sizePolicy4);

        horizontalLayout->addWidget(environment);

        configureEnvironment = new KDevelop::EnvironmentConfigureButton(advancedBox);
        configureEnvironment->setObjectName("configureEnvironment");

        horizontalLayout->addWidget(configureEnvironment);


        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        showInternal = new QCheckBox(advancedBox);
        showInternal->setObjectName("showInternal");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, showInternal);

        autoConfigureOnCMakeListsChanges = new QCheckBox(advancedBox);
        autoConfigureOnCMakeListsChanges->setObjectName("autoConfigureOnCMakeListsChanges");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, autoConfigureOnCMakeListsChanges);

        cMakeExecutable = new KUrlRequester(advancedBox);
        cMakeExecutable->setObjectName("cMakeExecutable");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, cMakeExecutable);

        label = new QLabel(advancedBox);
        label->setObjectName("label");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label);


        vboxLayout->addWidget(advancedBox);


        retranslateUi(CMakeBuildSettings);

        QMetaObject::connectSlotsByName(CMakeBuildSettings);
    } // setupUi

    void retranslateUi(QWidget *CMakeBuildSettings)
    {
        addBuildDir->setText(QString());
        removeBuildDir->setText(QString());
        groupBox->setTitle(tr2i18n("Cache Values", "@title:group"));
        label_6->setText(tr2i18n("Comment:", "@label"));
        commentText->setText(QString());
        showAdvanced->setText(tr2i18n("Show Advanced", "@action:button"));
        advancedBox->setTitle(tr2i18n("Advanced", "@title:group"));
        installationPrefixLabel->setText(tr2i18n("Installation prefix:", "@label:chooser"));
        buildTypeLabel->setText(tr2i18n("Build type:", "@label:listbox"));

        extraArgumentsLabel->setText(tr2i18n("Extra arguments:", "@label:listbox"));
        label_2->setText(tr2i18n("Configure environment:", "@label:chooser"));
#if QT_CONFIG(tooltip)
        environment->setToolTip(tr2i18n("Select an environment to be used", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        showInternal->setText(tr2i18n("Show advanced values", "@option:check"));
        autoConfigureOnCMakeListsChanges->setText(tr2i18n("Automatically reconfigure when CMake project files change", "@option:check"));
        label->setText(tr2i18n("CMake executable:", "@label:chooser"));
        (void)CMakeBuildSettings;
    } // retranslateUi

};

namespace Ui {
    class CMakeBuildSettings: public Ui_CMakeBuildSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CMAKEBUILDSETTINGS_H

