/********************************************************************************
** Form generated from reading UI file 'templatepreviewtoolview.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEMPLATEPREVIEWTOOLVIEW_H
#define UI_TEMPLATEPREVIEWTOOLVIEW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KMessageWidget"
#include "templatepreview.h"

QT_BEGIN_NAMESPACE

class Ui_TemplatePreviewToolView
{
public:
    QVBoxLayout *verticalLayout;
    KMessageWidget *messageWidget;
    TemplatePreview *preview;
    QGroupBox *groupBox_2;
    QVBoxLayout *verticalLayout_2;
    QRadioButton *projectRadioButton;
    QRadioButton *classRadioButton;
    QHBoxLayout *horizontalLayout;
    QLabel *emptyLinesPolicyLabel;
    QComboBox *emptyLinesPolicyComboBox;
    QSpacerItem *horizontalSpacer;

    void setupUi(QWidget *TemplatePreviewToolView)
    {
        if (TemplatePreviewToolView->objectName().isEmpty())
            TemplatePreviewToolView->setObjectName("TemplatePreviewToolView");
        TemplatePreviewToolView->resize(686, 571);
        verticalLayout = new QVBoxLayout(TemplatePreviewToolView);
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        verticalLayout->setObjectName("verticalLayout");
        messageWidget = new KMessageWidget(TemplatePreviewToolView);
        messageWidget->setObjectName("messageWidget");
        messageWidget->setWordWrap(true);

        verticalLayout->addWidget(messageWidget);

        preview = new TemplatePreview(TemplatePreviewToolView);
        preview->setObjectName("preview");

        verticalLayout->addWidget(preview);

        groupBox_2 = new QGroupBox(TemplatePreviewToolView);
        groupBox_2->setObjectName("groupBox_2");
        groupBox_2->setFlat(true);
        verticalLayout_2 = new QVBoxLayout(groupBox_2);
        verticalLayout_2->setObjectName("verticalLayout_2");
        projectRadioButton = new QRadioButton(groupBox_2);
        projectRadioButton->setObjectName("projectRadioButton");
        projectRadioButton->setChecked(true);

        verticalLayout_2->addWidget(projectRadioButton);

        classRadioButton = new QRadioButton(groupBox_2);
        classRadioButton->setObjectName("classRadioButton");

        verticalLayout_2->addWidget(classRadioButton);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        emptyLinesPolicyLabel = new QLabel(groupBox_2);
        emptyLinesPolicyLabel->setObjectName("emptyLinesPolicyLabel");
        emptyLinesPolicyLabel->setEnabled(false);
        emptyLinesPolicyLabel->setWordWrap(true);

        horizontalLayout->addWidget(emptyLinesPolicyLabel);

        emptyLinesPolicyComboBox = new QComboBox(groupBox_2);
        emptyLinesPolicyComboBox->addItem(QString());
        emptyLinesPolicyComboBox->addItem(QString());
        emptyLinesPolicyComboBox->addItem(QString());
        emptyLinesPolicyComboBox->setObjectName("emptyLinesPolicyComboBox");
        emptyLinesPolicyComboBox->setEnabled(false);

        horizontalLayout->addWidget(emptyLinesPolicyComboBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_2->addLayout(horizontalLayout);


        verticalLayout->addWidget(groupBox_2);

#if QT_CONFIG(shortcut)
        emptyLinesPolicyLabel->setBuddy(emptyLinesPolicyComboBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(TemplatePreviewToolView);
        QObject::connect(classRadioButton, &QRadioButton::toggled, emptyLinesPolicyComboBox, &QComboBox::setEnabled);
        QObject::connect(classRadioButton, &QRadioButton::toggled, emptyLinesPolicyLabel, &QLabel::setEnabled);

        QMetaObject::connectSlotsByName(TemplatePreviewToolView);
    } // setupUi

    void retranslateUi(QWidget *TemplatePreviewToolView)
    {
        groupBox_2->setTitle(tr2i18n("Template Type", "@title:group"));
        projectRadioButton->setText(tr2i18n("Project template", "@option:radio"));
        classRadioButton->setText(tr2i18n("Class template", "@option:radio"));
        emptyLinesPolicyLabel->setText(tr2i18n("&Empty lines policy:", "@label:listbox"));
        emptyLinesPolicyComboBox->setItemText(0, tr2i18n("Keep Empty Lines", "@item:inlistbox empty line policy"));
        emptyLinesPolicyComboBox->setItemText(1, tr2i18n("Remove Repeated Empty Lines", "@item:inlistbox empty line policy"));
        emptyLinesPolicyComboBox->setItemText(2, tr2i18n("Remove All Empty Lines", "@item:inlistbox empty line policy"));

        (void)TemplatePreviewToolView;
    } // retranslateUi

};

namespace Ui {
    class TemplatePreviewToolView: public Ui_TemplatePreviewToolView {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TEMPLATEPREVIEWTOOLVIEW_H

