/****************************************************************************
** Meta object code from reading C++ file 'svninternaljobbase.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/subversion/svninternaljobbase.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'svninternaljobbase.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18SvnInternalJobBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto SvnInternalJobBase::qt_create_metaobjectdata<qt_meta_tag_ZN18SvnInternalJobBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SvnInternalJobBase",
        "needLogin",
        "",
        "showNotification",
        "needCommitMessage",
        "needSslServerTrust",
        "needSslClientCert",
        "needSslClientCertPassword",
        "started",
        "succeeded",
        "failed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'needLogin'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'showNotification'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'needCommitMessage'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'needSslServerTrust'
        QtMocHelpers::SignalData<void(const QStringList &, const QString &, const QString &, const QString &, const QString &, const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'needSslClientCert'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'needSslClientCertPassword'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'started'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'succeeded'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'failed'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SvnInternalJobBase, qt_meta_tag_ZN18SvnInternalJobBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SvnInternalJobBase::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SvnInternalJobBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SvnInternalJobBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18SvnInternalJobBaseE_t>.metaTypes,
    nullptr
} };

void SvnInternalJobBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SvnInternalJobBase *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->needLogin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->showNotification((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->needCommitMessage(); break;
        case 3: _t->needSslServerTrust((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[7]))); break;
        case 4: _t->needSslClientCert((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->needSslClientCertPassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->started(); break;
        case 7: _t->succeeded(); break;
        case 8: _t->failed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SvnInternalJobBase::*)(const QString & )>(_a, &SvnInternalJobBase::needLogin, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SvnInternalJobBase::*)(const QString & , const QString & )>(_a, &SvnInternalJobBase::showNotification, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SvnInternalJobBase::*)()>(_a, &SvnInternalJobBase::needCommitMessage, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SvnInternalJobBase::*)(const QStringList & , const QString & , const QString & , const QString & , const QString & , const QString & , const QString & )>(_a, &SvnInternalJobBase::needSslServerTrust, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SvnInternalJobBase::*)(const QString & )>(_a, &SvnInternalJobBase::needSslClientCert, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SvnInternalJobBase::*)(const QString & )>(_a, &SvnInternalJobBase::needSslClientCertPassword, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SvnInternalJobBase::*)()>(_a, &SvnInternalJobBase::started, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SvnInternalJobBase::*)()>(_a, &SvnInternalJobBase::succeeded, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SvnInternalJobBase::*)()>(_a, &SvnInternalJobBase::failed, 8))
            return;
    }
}

const QMetaObject *SvnInternalJobBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SvnInternalJobBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18SvnInternalJobBaseE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ThreadWeaver::Job"))
        return static_cast< ThreadWeaver::Job*>(this);
    if (!strcmp(_clname, "svn::ContextListener"))
        return static_cast< svn::ContextListener*>(this);
    return QObject::qt_metacast(_clname);
}

int SvnInternalJobBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void SvnInternalJobBase::needLogin(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SvnInternalJobBase::showNotification(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void SvnInternalJobBase::needCommitMessage()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SvnInternalJobBase::needSslServerTrust(const QStringList & _t1, const QString & _t2, const QString & _t3, const QString & _t4, const QString & _t5, const QString & _t6, const QString & _t7)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4, _t5, _t6, _t7);
}

// SIGNAL 4
void SvnInternalJobBase::needSslClientCert(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void SvnInternalJobBase::needSslClientCertPassword(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void SvnInternalJobBase::started()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void SvnInternalJobBase::succeeded()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void SvnInternalJobBase::failed()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
