/********************************************************************************
** Form generated from reading UI file 'defineswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DEFINESWIDGET_H
#define UI_DEFINESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_DefinesWidget
{
public:
    QVBoxLayout *widgetLayout;
    QTableView *defines;

    void setupUi(QWidget *DefinesWidget)
    {
        if (DefinesWidget->objectName().isEmpty())
            DefinesWidget->setObjectName("DefinesWidget");
        DefinesWidget->resize(685, 627);
        widgetLayout = new QVBoxLayout(DefinesWidget);
        widgetLayout->setContentsMargins(0, 0, 0, 0);
        widgetLayout->setObjectName("widgetLayout");
        defines = new QTableView(DefinesWidget);
        defines->setObjectName("defines");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(8);
        sizePolicy.setHeightForWidth(defines->sizePolicy().hasHeightForWidth());
        defines->setSizePolicy(sizePolicy);
        defines->setSelectionBehavior(QAbstractItemView::SelectRows);
        defines->verticalHeader()->setVisible(false);

        widgetLayout->addWidget(defines);


        retranslateUi(DefinesWidget);

        QMetaObject::connectSlotsByName(DefinesWidget);
    } // setupUi

    void retranslateUi(QWidget *DefinesWidget)
    {
        (void)DefinesWidget;
    } // retranslateUi

};

namespace Ui {
    class DefinesWidget: public Ui_DefinesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // DEFINESWIDGET_H

