/********************************************************************************
** Form generated from reading UI file 'rebasedialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_REBASEDIALOG_H
#define UI_REBASEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_RebaseDialog
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    QComboBox *branches;
    QPushButton *rebaseButton;
    QSpacerItem *verticalSpacer;
    QPushButton *pushButton_2;

    void setupUi(QDialog *RebaseDialog)
    {
        if (RebaseDialog->objectName().isEmpty())
            RebaseDialog->setObjectName("RebaseDialog");
        RebaseDialog->resize(535, 92);
        gridLayout = new QGridLayout(RebaseDialog);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(RebaseDialog);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        branches = new QComboBox(RebaseDialog);
        branches->setObjectName("branches");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(branches->sizePolicy().hasHeightForWidth());
        branches->setSizePolicy(sizePolicy);

        gridLayout->addWidget(branches, 0, 1, 1, 1);

        rebaseButton = new QPushButton(RebaseDialog);
        rebaseButton->setObjectName("rebaseButton");

        gridLayout->addWidget(rebaseButton, 0, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 2, 1, 1);

        pushButton_2 = new QPushButton(RebaseDialog);
        pushButton_2->setObjectName("pushButton_2");

        gridLayout->addWidget(pushButton_2, 2, 2, 1, 1);

#if QT_CONFIG(shortcut)
        label->setBuddy(branches);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(branches, rebaseButton);
        QWidget::setTabOrder(rebaseButton, pushButton_2);

        retranslateUi(RebaseDialog);
        QObject::connect(pushButton_2, &QPushButton::clicked, RebaseDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(RebaseDialog);
    } // setupUi

    void retranslateUi(QDialog *RebaseDialog)
    {
        RebaseDialog->setWindowTitle(tr2i18n("Rebase", "@title:window"));
        label->setText(tr2i18n("Base branch:", "@label:listbox"));
        rebaseButton->setText(tr2i18n("Rebase", "@action:button"));
        pushButton_2->setText(tr2i18n("Cancel", "@action:button"));
    } // retranslateUi

};

namespace Ui {
    class RebaseDialog: public Ui_RebaseDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // REBASEDIALOG_H

