// This file is generated by kconfig_compiler_kf6 from clangtidyprojectconfig.kcfg.
// All changes you do to this file will be lost.

#include "clangtidyprojectconfig.h"

ClangTidyProjectSettings::ClangTidyProjectSettings( )
  : KConfigSkeleton()
{
  setCurrentGroup( QStringLiteral( "ClangTidy" ) );

  KConfigSkeleton::ItemString  *itemAdditionalParameters;
  itemAdditionalParameters = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "AdditionalParameters" ), mAdditionalParameters );
  addItem( itemAdditionalParameters, QStringLiteral( "additionalParameters" ) );
  KConfigSkeleton::ItemBool  *itemCheckSystemHeaders;
  itemCheckSystemHeaders = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "CheckSystemHeaders" ), mCheckSystemHeaders, false );
  addItem( itemCheckSystemHeaders, QStringLiteral( "checkSystemHeaders" ) );
  KConfigSkeleton::ItemBool  *itemUseConfigFile;
  itemUseConfigFile = new KConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "UseConfigFile" ), mUseConfigFile, true );
  addItem( itemUseConfigFile, QStringLiteral( "useConfigFile" ) );
  KConfigSkeleton::ItemString  *itemHeaderFilter;
  itemHeaderFilter = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "HeaderFilter" ), mHeaderFilter, QStringLiteral( ".*" ) );
  addItem( itemHeaderFilter, QStringLiteral( "headerFilter" ) );
  KConfigSkeleton::ItemString  *itemCheckSetSelection;
  itemCheckSetSelection = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "CheckSetSelection" ), mCheckSetSelection );
  addItem( itemCheckSetSelection, QStringLiteral( "checkSetSelection" ) );
  KConfigSkeleton::ItemString  *itemEnabledChecks;
  itemEnabledChecks = new KConfigSkeleton::ItemString( currentGroup(), QStringLiteral( "EnabledChecks" ), mEnabledChecks );
  addItem( itemEnabledChecks, QStringLiteral( "enabledChecks" ) );
}

ClangTidyProjectSettings::~ClangTidyProjectSettings()
{
}

