/****************************************************************************
** Meta object code from reading C++ file 'ktexteditorpluginintegration.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/kdevplatform/shell/ktexteditorpluginintegration.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ktexteditorpluginintegration.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22KTextEditorIntegration11ApplicationE_t {};
} // unnamed namespace

template <> constexpr inline auto KTextEditorIntegration::Application::qt_create_metaobjectdata<qt_meta_tag_ZN22KTextEditorIntegration11ApplicationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTextEditorIntegration::Application",
        "activeMainWindow",
        "KTextEditor::MainWindow*",
        "",
        "mainWindows",
        "QList<KTextEditor::MainWindow*>",
        "plugin",
        "KTextEditor::Plugin*",
        "id",
        "documents",
        "QList<KTextEditor::Document*>",
        "openUrl",
        "KTextEditor::Document*",
        "QUrl",
        "url",
        "encoding",
        "findUrl",
        "closeDocument",
        "document",
        "quit"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'activeMainWindow'
        QtMocHelpers::SlotData<KTextEditor::MainWindow *() const>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'mainWindows'
        QtMocHelpers::SlotData<QList<KTextEditor::MainWindow*>() const>(4, 3, QMC::AccessPublic, 0x80000000 | 5),
        // Slot 'plugin'
        QtMocHelpers::SlotData<KTextEditor::Plugin *(const QString &) const>(6, 3, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'documents'
        QtMocHelpers::SlotData<QList<KTextEditor::Document*>()>(9, 3, QMC::AccessPublic, 0x80000000 | 10),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<KTextEditor::Document *(const QUrl &, const QString &)>(11, 3, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 13, 14 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<KTextEditor::Document *(const QUrl &)>(11, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 12, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'findUrl'
        QtMocHelpers::SlotData<KTextEditor::Document *(const QUrl &) const>(16, 3, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'closeDocument'
        QtMocHelpers::SlotData<bool(KTextEditor::Document *) const>(17, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 12, 18 },
        }}),
        // Slot 'quit'
        QtMocHelpers::SlotData<bool() const>(19, 3, QMC::AccessPublic, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Application, qt_meta_tag_ZN22KTextEditorIntegration11ApplicationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTextEditorIntegration::Application::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KTextEditorIntegration11ApplicationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KTextEditorIntegration11ApplicationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22KTextEditorIntegration11ApplicationE_t>.metaTypes,
    nullptr
} };

void KTextEditorIntegration::Application::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Application *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { KTextEditor::MainWindow* _r = _t->activeMainWindow();
            if (_a[0]) *reinterpret_cast<KTextEditor::MainWindow**>(_a[0]) = std::move(_r); }  break;
        case 1: { QList<KTextEditor::MainWindow*> _r = _t->mainWindows();
            if (_a[0]) *reinterpret_cast<QList<KTextEditor::MainWindow*>*>(_a[0]) = std::move(_r); }  break;
        case 2: { KTextEditor::Plugin* _r = _t->plugin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KTextEditor::Plugin**>(_a[0]) = std::move(_r); }  break;
        case 3: { QList<KTextEditor::Document*> _r = _t->documents();
            if (_a[0]) *reinterpret_cast<QList<KTextEditor::Document*>*>(_a[0]) = std::move(_r); }  break;
        case 4: { KTextEditor::Document* _r = _t->openUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<KTextEditor::Document**>(_a[0]) = std::move(_r); }  break;
        case 5: { KTextEditor::Document* _r = _t->openUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KTextEditor::Document**>(_a[0]) = std::move(_r); }  break;
        case 6: { KTextEditor::Document* _r = _t->findUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KTextEditor::Document**>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->closeDocument((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->quit();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *KTextEditorIntegration::Application::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditorIntegration::Application::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KTextEditorIntegration11ApplicationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KTextEditorIntegration::Application::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN22KTextEditorIntegration10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto KTextEditorIntegration::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN22KTextEditorIntegration10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTextEditorIntegration::MainWindow",
        "createToolView",
        "QWidget*",
        "",
        "KTextEditor::Plugin*",
        "plugin",
        "identifier",
        "KTextEditor::MainWindow::ToolViewPosition",
        "pos",
        "QIcon",
        "icon",
        "text",
        "guiFactory",
        "KXMLGUIFactory*",
        "window",
        "views",
        "QList<KTextEditor::View*>",
        "activeView",
        "KTextEditor::View*",
        "activateView",
        "KTextEditor::Document*",
        "document",
        "pluginView",
        "id",
        "splitView",
        "Qt::Orientation",
        "orientation",
        "closeView",
        "kteView",
        "closeSplitView",
        "viewsInSameSplitView",
        "kteView1",
        "kteView2",
        "createViewBar",
        "view",
        "deleteViewBar",
        "showViewBar",
        "hideViewBar",
        "addWidgetToViewBar",
        "widget",
        "openUrl",
        "QUrl",
        "url",
        "encoding",
        "showToolView",
        "showMessage",
        "QVariantMap",
        "message"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'createToolView'
        QtMocHelpers::SlotData<QWidget *(KTextEditor::Plugin *, const QString &, KTextEditor::MainWindow::ToolViewPosition, const QIcon &, const QString &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 }, { QMetaType::QString, 6 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
            { QMetaType::QString, 11 },
        }}),
        // Slot 'guiFactory'
        QtMocHelpers::SlotData<KXMLGUIFactory *() const>(12, 3, QMC::AccessPublic, 0x80000000 | 13),
        // Slot 'window'
        QtMocHelpers::SlotData<QWidget *() const>(14, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'views'
        QtMocHelpers::SlotData<QList<KTextEditor::View*>() const>(15, 3, QMC::AccessPublic, 0x80000000 | 16),
        // Slot 'activeView'
        QtMocHelpers::SlotData<KTextEditor::View *() const>(17, 3, QMC::AccessPublic, 0x80000000 | 18),
        // Slot 'activateView'
        QtMocHelpers::SlotData<KTextEditor::View *(KTextEditor::Document *)>(19, 3, QMC::AccessPublic, 0x80000000 | 18, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'pluginView'
        QtMocHelpers::SlotData<QObject *(const QString &) const>(22, 3, QMC::AccessPublic, QMetaType::QObjectStar, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'splitView'
        QtMocHelpers::SlotData<void(Qt::Orientation)>(24, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'closeView'
        QtMocHelpers::SlotData<bool(KTextEditor::View *)>(27, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 18, 28 },
        }}),
        // Slot 'closeSplitView'
        QtMocHelpers::SlotData<bool(KTextEditor::View *)>(29, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 18, 28 },
        }}),
        // Slot 'viewsInSameSplitView'
        QtMocHelpers::SlotData<bool(KTextEditor::View *, KTextEditor::View *) const>(30, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 18, 31 }, { 0x80000000 | 18, 32 },
        }}),
        // Slot 'createViewBar'
        QtMocHelpers::SlotData<QWidget *(KTextEditor::View *)>(33, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 18, 34 },
        }}),
        // Slot 'deleteViewBar'
        QtMocHelpers::SlotData<void(KTextEditor::View *)>(35, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 34 },
        }}),
        // Slot 'showViewBar'
        QtMocHelpers::SlotData<void(KTextEditor::View *)>(36, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 34 },
        }}),
        // Slot 'hideViewBar'
        QtMocHelpers::SlotData<void(KTextEditor::View *)>(37, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 34 },
        }}),
        // Slot 'addWidgetToViewBar'
        QtMocHelpers::SlotData<void(KTextEditor::View *, QWidget *)>(38, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 34 }, { 0x80000000 | 2, 39 },
        }}),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<KTextEditor::View *(const QUrl &, const QString &)>(40, 3, QMC::AccessPublic, 0x80000000 | 18, {{
            { 0x80000000 | 41, 42 }, { QMetaType::QString, 43 },
        }}),
        // Slot 'openUrl'
        QtMocHelpers::SlotData<KTextEditor::View *(const QUrl &)>(40, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 18, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'showToolView'
        QtMocHelpers::SlotData<bool(QWidget *)>(44, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 2, 39 },
        }}),
        // Slot 'showMessage'
        QtMocHelpers::SlotData<bool(const QVariantMap &)>(45, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 46, 47 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN22KTextEditorIntegration10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTextEditorIntegration::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KTextEditorIntegration10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KTextEditorIntegration10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22KTextEditorIntegration10MainWindowE_t>.metaTypes,
    nullptr
} };

void KTextEditorIntegration::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QWidget* _r = _t->createToolView((*reinterpret_cast<std::add_pointer_t<KTextEditor::Plugin*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::MainWindow::ToolViewPosition>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QIcon>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QWidget**>(_a[0]) = std::move(_r); }  break;
        case 1: { KXMLGUIFactory* _r = _t->guiFactory();
            if (_a[0]) *reinterpret_cast<KXMLGUIFactory**>(_a[0]) = std::move(_r); }  break;
        case 2: { QWidget* _r = _t->window();
            if (_a[0]) *reinterpret_cast<QWidget**>(_a[0]) = std::move(_r); }  break;
        case 3: { QList<KTextEditor::View*> _r = _t->views();
            if (_a[0]) *reinterpret_cast<QList<KTextEditor::View*>*>(_a[0]) = std::move(_r); }  break;
        case 4: { KTextEditor::View* _r = _t->activeView();
            if (_a[0]) *reinterpret_cast<KTextEditor::View**>(_a[0]) = std::move(_r); }  break;
        case 5: { KTextEditor::View* _r = _t->activateView((*reinterpret_cast<std::add_pointer_t<KTextEditor::Document*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KTextEditor::View**>(_a[0]) = std::move(_r); }  break;
        case 6: { QObject* _r = _t->pluginView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QObject**>(_a[0]) = std::move(_r); }  break;
        case 7: _t->splitView((*reinterpret_cast<std::add_pointer_t<Qt::Orientation>>(_a[1]))); break;
        case 8: { bool _r = _t->closeView((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->closeSplitView((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->viewsInSameSplitView((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { QWidget* _r = _t->createViewBar((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QWidget**>(_a[0]) = std::move(_r); }  break;
        case 12: _t->deleteViewBar((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 13: _t->showViewBar((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 14: _t->hideViewBar((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1]))); break;
        case 15: _t->addWidgetToViewBar((*reinterpret_cast<std::add_pointer_t<KTextEditor::View*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        case 16: { KTextEditor::View* _r = _t->openUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<KTextEditor::View**>(_a[0]) = std::move(_r); }  break;
        case 17: { KTextEditor::View* _r = _t->openUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KTextEditor::View**>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->showToolView((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { bool _r = _t->showMessage((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KTextEditor::Plugin* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *KTextEditorIntegration::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditorIntegration::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KTextEditorIntegration10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KTextEditorIntegration::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN22KTextEditorIntegration6PluginE_t {};
} // unnamed namespace

template <> constexpr inline auto KTextEditorIntegration::Plugin::qt_create_metaobjectdata<qt_meta_tag_ZN22KTextEditorIntegration6PluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KTextEditorIntegration::Plugin"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Plugin, qt_meta_tag_ZN22KTextEditorIntegration6PluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KTextEditorIntegration::Plugin::staticMetaObject = { {
    QMetaObject::SuperData::link<KDevelop::IPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KTextEditorIntegration6PluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KTextEditorIntegration6PluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22KTextEditorIntegration6PluginE_t>.metaTypes,
    nullptr
} };

void KTextEditorIntegration::Plugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Plugin *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *KTextEditorIntegration::Plugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KTextEditorIntegration::Plugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KTextEditorIntegration6PluginE_t>.strings))
        return static_cast<void*>(this);
    return KDevelop::IPlugin::qt_metacast(_clname);
}

int KTextEditorIntegration::Plugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDevelop::IPlugin::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
