/********************************************************************************
** Form generated from reading UI file 'androidpreferences.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ANDROIDPREFERENCES_H
#define UI_ANDROIDPREFERENCES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_AndroidPreferences
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    KUrlRequester *kcfg_cmakeToolchain;
    QLabel *label_2;
    KUrlRequester *kcfg_ndk;
    QLabel *label_3;
    KUrlRequester *kcfg_sdk;
    QLabel *label_4;
    QLineEdit *kcfg_arch;
    QLabel *label_5;
    QLineEdit *kcfg_toolchain;
    QLabel *label_6;
    QLineEdit *kcfg_abi;

    void setupUi(QWidget *AndroidPreferences)
    {
        if (AndroidPreferences->objectName().isEmpty())
            AndroidPreferences->setObjectName("AndroidPreferences");
        AndroidPreferences->resize(400, 300);
        formLayout = new QFormLayout(AndroidPreferences);
        formLayout->setObjectName("formLayout");
        formLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(AndroidPreferences);
        label->setObjectName("label");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label);

        kcfg_cmakeToolchain = new KUrlRequester(AndroidPreferences);
        kcfg_cmakeToolchain->setObjectName("kcfg_cmakeToolchain");
        kcfg_cmakeToolchain->setMode(KFile::File|KFile::ExistingOnly|KFile::LocalOnly);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_cmakeToolchain);

        label_2 = new QLabel(AndroidPreferences);
        label_2->setObjectName("label_2");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_ndk = new KUrlRequester(AndroidPreferences);
        kcfg_ndk->setObjectName("kcfg_ndk");
        kcfg_ndk->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_ndk);

        label_3 = new QLabel(AndroidPreferences);
        label_3->setObjectName("label_3");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_sdk = new KUrlRequester(AndroidPreferences);
        kcfg_sdk->setObjectName("kcfg_sdk");
        kcfg_sdk->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_sdk);

        label_4 = new QLabel(AndroidPreferences);
        label_4->setObjectName("label_4");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_4);

        kcfg_arch = new QLineEdit(AndroidPreferences);
        kcfg_arch->setObjectName("kcfg_arch");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_arch);

        label_5 = new QLabel(AndroidPreferences);
        label_5->setObjectName("label_5");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_5);

        kcfg_toolchain = new QLineEdit(AndroidPreferences);
        kcfg_toolchain->setObjectName("kcfg_toolchain");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, kcfg_toolchain);

        label_6 = new QLabel(AndroidPreferences);
        label_6->setObjectName("label_6");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_6);

        kcfg_abi = new QLineEdit(AndroidPreferences);
        kcfg_abi->setObjectName("kcfg_abi");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, kcfg_abi);


        retranslateUi(AndroidPreferences);

        QMetaObject::connectSlotsByName(AndroidPreferences);
    } // setupUi

    void retranslateUi(QWidget *AndroidPreferences)
    {
#if QT_CONFIG(whatsthis)
        label->setWhatsThis(tr2i18n("Android KDE extra-cmake-modules toolchain file", "@info:whatsthis"));
#endif // QT_CONFIG(whatsthis)
        label->setText(tr2i18n("Android toolchain:", "@label:textbox"));
        label_2->setText(tr2i18n("Android NDK:", "@label:textbox"));
        label_3->setText(tr2i18n("Android SDK:", "@label:textbox"));
        label_4->setText(tr2i18n("Architecture:", "@label:textbox"));
        label_5->setText(tr2i18n("Toolchain:", "@label:textbox"));
        label_6->setText(tr2i18n("ABI:", "@label:textbox"));
        (void)AndroidPreferences;
    } // retranslateUi

};

namespace Ui {
    class AndroidPreferences: public Ui_AndroidPreferences {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ANDROIDPREFERENCES_H

