/********************************************************************************
** Form generated from reading UI file 'licensechooser.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LICENSECHOOSER_H
#define UI_LICENSECHOOSER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"
#include "KTextEdit"

QT_BEGIN_NAMESPACE

class Ui_LicenseChooserDialog
{
public:
    QHBoxLayout *horizontalLayout;
    QGroupBox *groupBox;
    QVBoxLayout *verticalLayout;
    QWidget *widget;
    QFormLayout *formLayout;
    QLabel *label;
    KComboBox *licenseComboBox;
    QCheckBox *saveLicense;
    QLineEdit *licenseName;
    KTextEdit *licenseTextEdit;
    QLabel *label_2;

    void setupUi(QWidget *LicenseChooserDialog)
    {
        if (LicenseChooserDialog->objectName().isEmpty())
            LicenseChooserDialog->setObjectName("LicenseChooserDialog");
        LicenseChooserDialog->resize(419, 284);
        horizontalLayout = new QHBoxLayout(LicenseChooserDialog);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox = new QGroupBox(LicenseChooserDialog);
        groupBox->setObjectName("groupBox");
        verticalLayout = new QVBoxLayout(groupBox);
        verticalLayout->setObjectName("verticalLayout");
        widget = new QWidget(groupBox);
        widget->setObjectName("widget");
        formLayout = new QFormLayout(widget);
        formLayout->setObjectName("formLayout");
        label = new QLabel(widget);
        label->setObjectName("label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        licenseComboBox = new KComboBox(widget);
        licenseComboBox->setObjectName("licenseComboBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(licenseComboBox->sizePolicy().hasHeightForWidth());
        licenseComboBox->setSizePolicy(sizePolicy1);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, licenseComboBox);

        saveLicense = new QCheckBox(widget);
        saveLicense->setObjectName("saveLicense");
        saveLicense->setEnabled(false);
        saveLicense->setCheckable(true);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, saveLicense);

        licenseName = new QLineEdit(widget);
        licenseName->setObjectName("licenseName");
        licenseName->setEnabled(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, licenseName);


        verticalLayout->addWidget(widget);

        licenseTextEdit = new KTextEdit(groupBox);
        licenseTextEdit->setObjectName("licenseTextEdit");
        licenseTextEdit->setAcceptRichText(false);

        verticalLayout->addWidget(licenseTextEdit);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");
        label_2->setTextFormat(Qt::RichText);
        label_2->setWordWrap(true);

        verticalLayout->addWidget(label_2);


        horizontalLayout->addWidget(groupBox);


        retranslateUi(LicenseChooserDialog);

        QMetaObject::connectSlotsByName(LicenseChooserDialog);
    } // setupUi

    void retranslateUi(QWidget *LicenseChooserDialog)
    {
        groupBox->setTitle(tr2i18n("Choose the license under which to place the generated content.", nullptr));
        label->setText(tr2i18n("License type:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        saveLicense->setToolTip(tr2i18n("Enable if you want to save this license for future use", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        saveLicense->setText(tr2i18n("Save license", "@option:check"));
        label_2->setText(tr2i18n("<p>You can use <code>&lt;year&gt;</code>, <code>&lt;month&gt;</code>, <code>&lt;day&gt;</code> and <code>&lt;copyright holder&gt;</code> as placeholders.</p>", nullptr));
        (void)LicenseChooserDialog;
    } // retranslateUi

};

namespace Ui {
    class LicenseChooserDialog: public Ui_LicenseChooserDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LICENSECHOOSER_H

