/****************************************************************************
** Meta object code from reading C++ file 'committoolview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/git/committoolview.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'committoolview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14CommitToolViewE_t {};
} // unnamed namespace

template <> constexpr inline auto CommitToolView::qt_create_metaobjectdata<qt_meta_tag_ZN14CommitToolViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CommitToolView",
        "showDiff",
        "",
        "QUrl",
        "url",
        "RepoStatusModel::Areas",
        "area",
        "showSource",
        "updateDiff",
        "updateProjectDiffs",
        "KDevelop::IProject*",
        "project",
        "updateUrlDiffs",
        "popupContextMenu",
        "QPoint",
        "pos",
        "dblClicked",
        "QModelIndex",
        "idx",
        "clicked",
        "activateProject",
        "stageSelectedFiles",
        "QList<QUrl>",
        "urls",
        "unstageSelectedFiles",
        "revertSelectedFiles",
        "commitActiveProject"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showDiff'
        QtMocHelpers::SignalData<void(const QUrl &, const RepoStatusModel::Areas)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'showSource'
        QtMocHelpers::SignalData<void(const QUrl &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'updateDiff'
        QtMocHelpers::SignalData<void(const QUrl &, const RepoStatusModel::Areas)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'updateProjectDiffs'
        QtMocHelpers::SignalData<void(KDevelop::IProject *)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'updateUrlDiffs'
        QtMocHelpers::SignalData<void(const QUrl &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'popupContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'dblClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'clicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'activateProject'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Slot 'stageSelectedFiles'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'unstageSelectedFiles'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'revertSelectedFiles'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'commitActiveProject'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CommitToolView, qt_meta_tag_ZN14CommitToolViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CommitToolView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CommitToolViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CommitToolViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14CommitToolViewE_t>.metaTypes,
    nullptr
} };

void CommitToolView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CommitToolView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showDiff((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<RepoStatusModel::Areas>>(_a[2]))); break;
        case 1: _t->showSource((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 2: _t->updateDiff((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<RepoStatusModel::Areas>>(_a[2]))); break;
        case 3: _t->updateProjectDiffs((*reinterpret_cast<std::add_pointer_t<KDevelop::IProject*>>(_a[1]))); break;
        case 4: _t->updateUrlDiffs((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->popupContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 6: _t->dblClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 7: _t->clicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 8: _t->activateProject((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 9: _t->stageSelectedFiles((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 10: _t->unstageSelectedFiles((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 11: _t->revertSelectedFiles((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 12: _t->commitActiveProject(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CommitToolView::*)(const QUrl & , const RepoStatusModel::Areas )>(_a, &CommitToolView::showDiff, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommitToolView::*)(const QUrl & )>(_a, &CommitToolView::showSource, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommitToolView::*)(const QUrl & , const RepoStatusModel::Areas )>(_a, &CommitToolView::updateDiff, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommitToolView::*)(KDevelop::IProject * )>(_a, &CommitToolView::updateProjectDiffs, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CommitToolView::*)(const QUrl & )>(_a, &CommitToolView::updateUrlDiffs, 4))
            return;
    }
}

const QMetaObject *CommitToolView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CommitToolView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14CommitToolViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int CommitToolView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void CommitToolView::showDiff(const QUrl & _t1, const RepoStatusModel::Areas _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void CommitToolView::showSource(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void CommitToolView::updateDiff(const QUrl & _t1, const RepoStatusModel::Areas _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void CommitToolView::updateProjectDiffs(KDevelop::IProject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void CommitToolView::updateUrlDiffs(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
