/********************************************************************************
** Form generated from reading UI file 'sourceformatterselectionedit.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SOURCEFORMATTERSELECTIONEDIT_H
#define UI_SOURCEFORMATTERSELECTIONEDIT_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KComboBox"

namespace KDevelop {

class Ui_SourceFormatterSelectionEdit
{
public:
    QGridLayout *mainLayout;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *usageHelpButton;
    KComboBox *cbLanguages;
    QVBoxLayout *verticalLayout;
    QLabel *descriptionLabel;
    QWidget *previewArea;
    QVBoxLayout *verticalLayout_2;
    QLabel *previewLabel;
    QWidget *textEditor;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout;
    KComboBox *cbFormatters;
    QToolButton *formatterDescriptionButton;
    QLabel *usageHintLabel;
    QLabel *label_2;
    QGridLayout *gridLayout;
    QPushButton *btnNewStyle;
    QPushButton *btnEditStyle;
    QPushButton *btnDelStyle;
    QListWidget *styleList;

    void setupUi(QWidget *KDevelop__SourceFormatterSelectionEdit)
    {
        if (KDevelop__SourceFormatterSelectionEdit->objectName().isEmpty())
            KDevelop__SourceFormatterSelectionEdit->setObjectName("KDevelop__SourceFormatterSelectionEdit");
        KDevelop__SourceFormatterSelectionEdit->resize(509, 344);
        mainLayout = new QGridLayout(KDevelop__SourceFormatterSelectionEdit);
        mainLayout->setObjectName("mainLayout");
        mainLayout->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(KDevelop__SourceFormatterSelectionEdit);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);
        label->setMargin(4);

        mainLayout->addWidget(label, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        usageHelpButton = new QToolButton(KDevelop__SourceFormatterSelectionEdit);
        usageHelpButton->setObjectName("usageHelpButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("dialog-question")));
        usageHelpButton->setIcon(icon);
        usageHelpButton->setIconSize(QSize(22, 22));

        horizontalLayout_2->addWidget(usageHelpButton);

        cbLanguages = new KComboBox(KDevelop__SourceFormatterSelectionEdit);
        cbLanguages->setObjectName("cbLanguages");

        horizontalLayout_2->addWidget(cbLanguages);


        mainLayout->addLayout(horizontalLayout_2, 0, 1, 1, 1);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(12);
        verticalLayout->setObjectName("verticalLayout");
        descriptionLabel = new QLabel(KDevelop__SourceFormatterSelectionEdit);
        descriptionLabel->setObjectName("descriptionLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(descriptionLabel->sizePolicy().hasHeightForWidth());
        descriptionLabel->setSizePolicy(sizePolicy);
        descriptionLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        descriptionLabel->setWordWrap(true);

        verticalLayout->addWidget(descriptionLabel);

        previewArea = new QWidget(KDevelop__SourceFormatterSelectionEdit);
        previewArea->setObjectName("previewArea");
        verticalLayout_2 = new QVBoxLayout(previewArea);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        previewLabel = new QLabel(previewArea);
        previewLabel->setObjectName("previewLabel");

        verticalLayout_2->addWidget(previewLabel);

        textEditor = new QWidget(previewArea);
        textEditor->setObjectName("textEditor");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(textEditor->sizePolicy().hasHeightForWidth());
        textEditor->setSizePolicy(sizePolicy1);

        verticalLayout_2->addWidget(textEditor);


        verticalLayout->addWidget(previewArea);

        verticalLayout->setStretch(1, 1);

        mainLayout->addLayout(verticalLayout, 0, 2, 4, 1);

        label_4 = new QLabel(KDevelop__SourceFormatterSelectionEdit);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);
        label_4->setMargin(4);

        mainLayout->addWidget(label_4, 1, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        cbFormatters = new KComboBox(KDevelop__SourceFormatterSelectionEdit);
        cbFormatters->setObjectName("cbFormatters");

        horizontalLayout->addWidget(cbFormatters);

        formatterDescriptionButton = new QToolButton(KDevelop__SourceFormatterSelectionEdit);
        formatterDescriptionButton->setObjectName("formatterDescriptionButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("dialog-information")));
        formatterDescriptionButton->setIcon(icon1);
        formatterDescriptionButton->setIconSize(QSize(22, 22));

        horizontalLayout->addWidget(formatterDescriptionButton);


        mainLayout->addLayout(horizontalLayout, 1, 1, 1, 1);

        usageHintLabel = new QLabel(KDevelop__SourceFormatterSelectionEdit);
        usageHintLabel->setObjectName("usageHintLabel");
        usageHintLabel->setText(QString::fromUtf8("<usage hint>"));
        usageHintLabel->setWordWrap(true);

        mainLayout->addWidget(usageHintLabel, 2, 1, 1, 1);

        label_2 = new QLabel(KDevelop__SourceFormatterSelectionEdit);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing);
        label_2->setMargin(4);
        label_2->setIndent(-1);

        mainLayout->addWidget(label_2, 3, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        btnNewStyle = new QPushButton(KDevelop__SourceFormatterSelectionEdit);
        btnNewStyle->setObjectName("btnNewStyle");

        gridLayout->addWidget(btnNewStyle, 0, 0, 1, 1);

        btnEditStyle = new QPushButton(KDevelop__SourceFormatterSelectionEdit);
        btnEditStyle->setObjectName("btnEditStyle");

        gridLayout->addWidget(btnEditStyle, 0, 1, 1, 1);

        btnDelStyle = new QPushButton(KDevelop__SourceFormatterSelectionEdit);
        btnDelStyle->setObjectName("btnDelStyle");

        gridLayout->addWidget(btnDelStyle, 0, 2, 1, 1);

        styleList = new QListWidget(KDevelop__SourceFormatterSelectionEdit);
        styleList->setObjectName("styleList");
        styleList->setSelectionBehavior(QAbstractItemView::SelectRows);
        styleList->setSortingEnabled(false);

        gridLayout->addWidget(styleList, 1, 0, 1, 3);


        mainLayout->addLayout(gridLayout, 3, 1, 1, 1);


        retranslateUi(KDevelop__SourceFormatterSelectionEdit);

        QMetaObject::connectSlotsByName(KDevelop__SourceFormatterSelectionEdit);
    } // setupUi

    void retranslateUi(QWidget *KDevelop__SourceFormatterSelectionEdit)
    {
        label->setText(tr2i18n("Language:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        usageHelpButton->setToolTip(tr2i18n("How to configure formatting styles", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        usageHelpButton->setWhatsThis(tr2i18n("<p>Select languages you use one by one from the <i>Language</i> combobox below, pick the desired formatter and style for each. <i>Ctrl+Click</i> a selected style to unselect it.</p>\n"
"<p>Configuring the right formatter and style for each used language is very important: not only explicit <i>Reformat Source</i>/<i>Line</i>/<i>Files...</i> actions are affected, but also the formatting of auto-generated, auto-refactored or auto-fixed code (for example, <i>Rename</i> context menu action).</p>\n"
"<p>Note that KDevelop formats all <i>*.h</i> files with formatter and style configured for <i>C</i> language, even C++ headers that belong to a pure C++ project. This occurs because source formatter maps MIME types to languages.</p>", nullptr));
#endif // QT_CONFIG(whatsthis)
        usageHelpButton->setText(QString());
        descriptionLabel->setText(QString());
        previewLabel->setText(tr2i18n("Preview:", "@label"));
        label_4->setText(tr2i18n("Formatter:", "@label:listbox"));
#if QT_CONFIG(tooltip)
        formatterDescriptionButton->setToolTip(tr2i18n("Description of a selected formatter", nullptr));
#endif // QT_CONFIG(tooltip)
        formatterDescriptionButton->setText(QString());
        label_2->setText(tr2i18n("Style:", "@label:listbox"));
        btnNewStyle->setText(tr2i18n("New", "@action:button"));
        btnEditStyle->setText(tr2i18n("Edit...", "@action:button"));
        btnDelStyle->setText(tr2i18n("Delete", "@action:button"));
        (void)KDevelop__SourceFormatterSelectionEdit;
    } // retranslateUi

};

} // namespace KDevelop

namespace KDevelop {
namespace Ui {
    class SourceFormatterSelectionEdit: public Ui_SourceFormatterSelectionEdit {};
} // namespace Ui
} // namespace KDevelop

#endif // SOURCEFORMATTERSELECTIONEDIT_H

