// This file is generated by kconfig_compiler_kf6 from sessionconfig.kcfg.
// All changes you do to this file will be lost.

#include "sessionconfig.h"

#include <qglobal.h>
#include <QFile>

class SessionConfigHelper
{
  public:
    SessionConfigHelper() noexcept : q(nullptr) {}
    ~SessionConfigHelper() noexcept { delete q; q = nullptr; }
    SessionConfigHelper(const SessionConfigHelper&) = delete;
    SessionConfigHelper& operator=(const SessionConfigHelper&) = delete;
    SessionConfig *q;
};
Q_GLOBAL_STATIC(SessionConfigHelper, s_globalSessionConfig)
SessionConfig *SessionConfig::self()
{
  if (!s_globalSessionConfig()->q) {
    new SessionConfig;
    s_globalSessionConfig()->q->read();
  }

  return s_globalSessionConfig()->q;
}

SessionConfig::SessionConfig( )
  : SessionConfigSkeleton( QStringLiteral( "kdeveloprc" ) )
{
  Q_ASSERT(!s_globalSessionConfig()->q);
  s_globalSessionConfig()->q = this;
  setCurrentGroup( QStringLiteral( "Clang Settings" ) );

  SessionConfigSkeleton::ItemBool  *itemMacros;
  itemMacros = new SessionConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "macros" ), mMacros, true );
  addItem( itemMacros, QStringLiteral( "macros" ) );
  SessionConfigSkeleton::ItemBool  *itemLookAhead;
  itemLookAhead = new SessionConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "lookAhead" ), mLookAhead, false );
  addItem( itemLookAhead, QStringLiteral( "lookAhead" ) );
  SessionConfigSkeleton::ItemBool  *itemForwardDeclare;
  itemForwardDeclare = new SessionConfigSkeleton::ItemBool( currentGroup(), QStringLiteral( "forwardDeclare" ), mForwardDeclare, true );
  addItem( itemForwardDeclare, QStringLiteral( "forwardDeclare" ) );
}

SessionConfig::~SessionConfig()
{
  if (s_globalSessionConfig.exists() && !s_globalSessionConfig.isDestroyed()) {
    s_globalSessionConfig()->q = nullptr;
  }
}

