/****************************************************************************
** Meta object code from reading C++ file 'midebugger.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/debuggercommon/midebugger.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'midebugger.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6KDevMI10MIDebuggerE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevMI::MIDebugger::qt_create_metaobjectdata<qt_meta_tag_ZN6KDevMI10MIDebuggerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevMI::MIDebugger",
        "ready",
        "",
        "exited",
        "abnormal",
        "msg",
        "programStopped",
        "MI::AsyncRecord",
        "r",
        "programRunning",
        "streamRecord",
        "MI::StreamRecord",
        "s",
        "notification",
        "n",
        "error",
        "MI::ResultRecord",
        "applicationOutput",
        "userCommandOutput",
        "internalCommandOutput",
        "debuggerInternalOutput",
        "readyReadStandardOutput",
        "readyReadStandardError",
        "processFinished",
        "exitCode",
        "QProcess::ExitStatus",
        "exitStatus",
        "processErrored",
        "QProcess::ProcessError"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'exited'
        QtMocHelpers::SignalData<void(bool, const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'programStopped'
        QtMocHelpers::SignalData<void(const MI::AsyncRecord &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'programRunning'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'streamRecord'
        QtMocHelpers::SignalData<void(const MI::StreamRecord &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'notification'
        QtMocHelpers::SignalData<void(const MI::AsyncRecord &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 14 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const MI::ResultRecord &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 12 },
        }}),
        // Signal 'applicationOutput'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'userCommandOutput'
        QtMocHelpers::SignalData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'internalCommandOutput'
        QtMocHelpers::SignalData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Signal 'debuggerInternalOutput'
        QtMocHelpers::SignalData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'readyReadStandardOutput'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'readyReadStandardError'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'processFinished'
        QtMocHelpers::SlotData<void(int, QProcess::ExitStatus)>(23, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'processErrored'
        QtMocHelpers::SlotData<void(QProcess::ProcessError)>(27, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 28, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MIDebugger, qt_meta_tag_ZN6KDevMI10MIDebuggerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevMI::MIDebugger::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KDevMI10MIDebuggerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KDevMI10MIDebuggerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6KDevMI10MIDebuggerE_t>.metaTypes,
    nullptr
} };

void KDevMI::MIDebugger::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MIDebugger *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ready(); break;
        case 1: _t->exited((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->programStopped((*reinterpret_cast<std::add_pointer_t<MI::AsyncRecord>>(_a[1]))); break;
        case 3: _t->programRunning(); break;
        case 4: _t->streamRecord((*reinterpret_cast<std::add_pointer_t<MI::StreamRecord>>(_a[1]))); break;
        case 5: _t->notification((*reinterpret_cast<std::add_pointer_t<MI::AsyncRecord>>(_a[1]))); break;
        case 6: _t->error((*reinterpret_cast<std::add_pointer_t<MI::ResultRecord>>(_a[1]))); break;
        case 7: _t->applicationOutput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->userCommandOutput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->internalCommandOutput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->debuggerInternalOutput((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->readyReadStandardOutput(); break;
        case 12: _t->readyReadStandardError(); break;
        case 13: _t->processFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QProcess::ExitStatus>>(_a[2]))); break;
        case 14: _t->processErrored((*reinterpret_cast<std::add_pointer_t<QProcess::ProcessError>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MIDebugger::*)()>(_a, &MIDebugger::ready, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugger::*)(bool , const QString & )>(_a, &MIDebugger::exited, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugger::*)(const MI::AsyncRecord & )>(_a, &MIDebugger::programStopped, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugger::*)()>(_a, &MIDebugger::programRunning, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugger::*)(const MI::StreamRecord & )>(_a, &MIDebugger::streamRecord, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugger::*)(const MI::AsyncRecord & )>(_a, &MIDebugger::notification, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugger::*)(const MI::ResultRecord & )>(_a, &MIDebugger::error, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugger::*)(const QString & )>(_a, &MIDebugger::applicationOutput, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugger::*)(const QString & )>(_a, &MIDebugger::userCommandOutput, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugger::*)(const QString & )>(_a, &MIDebugger::internalCommandOutput, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MIDebugger::*)(const QString & )>(_a, &MIDebugger::debuggerInternalOutput, 10))
            return;
    }
}

const QMetaObject *KDevMI::MIDebugger::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevMI::MIDebugger::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6KDevMI10MIDebuggerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KDevMI::MIDebugger::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void KDevMI::MIDebugger::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KDevMI::MIDebugger::exited(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KDevMI::MIDebugger::programStopped(const MI::AsyncRecord & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KDevMI::MIDebugger::programRunning()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KDevMI::MIDebugger::streamRecord(const MI::StreamRecord & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KDevMI::MIDebugger::notification(const MI::AsyncRecord & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KDevMI::MIDebugger::error(const MI::ResultRecord & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KDevMI::MIDebugger::applicationOutput(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KDevMI::MIDebugger::userCommandOutput(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KDevMI::MIDebugger::internalCommandOutput(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KDevMI::MIDebugger::debuggerInternalOutput(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}
QT_WARNING_POP
