/********************************************************************************
** Form generated from reading UI file 'stashmanagerdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_STASHMANAGERDIALOG_H
#define UI_STASHMANAGERDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_StashManager
{
public:
    QGridLayout *gridLayout;
    QPushButton *drop;
    QPushButton *pop;
    QPushButton *show;
    QDialogButtonBox *buttonBox;
    QListView *stashView;
    QPushButton *apply;
    QSpacerItem *verticalSpacer;
    QPushButton *branch;

    void setupUi(QWidget *StashManager)
    {
        if (StashManager->objectName().isEmpty())
            StashManager->setObjectName("StashManager");
        StashManager->resize(558, 445);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(StashManager->sizePolicy().hasHeightForWidth());
        StashManager->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(StashManager);
        gridLayout->setObjectName("gridLayout");
        drop = new QPushButton(StashManager);
        drop->setObjectName("drop");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        drop->setIcon(icon);

        gridLayout->addWidget(drop, 5, 1, 1, 1);

        pop = new QPushButton(StashManager);
        pop->setObjectName("pop");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("vcs-stash-pop")));
        pop->setIcon(icon1);

        gridLayout->addWidget(pop, 2, 1, 1, 1);

        show = new QPushButton(StashManager);
        show->setObjectName("show");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("document-preview")));
        show->setIcon(icon2);

        gridLayout->addWidget(show, 0, 1, 1, 1);

        buttonBox = new QDialogButtonBox(StashManager);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 7, 1, 1, 1);

        stashView = new QListView(StashManager);
        stashView->setObjectName("stashView");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(stashView->sizePolicy().hasHeightForWidth());
        stashView->setSizePolicy(sizePolicy1);
        stashView->setEditTriggers(QAbstractItemView::NoEditTriggers);

        gridLayout->addWidget(stashView, 0, 0, 8, 1);

        apply = new QPushButton(StashManager);
        apply->setObjectName("apply");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("dialog-ok-apply")));
        apply->setIcon(icon3);

        gridLayout->addWidget(apply, 1, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 77, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 6, 1, 1, 1);

        branch = new QPushButton(StashManager);
        branch->setObjectName("branch");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("vcs-branch")));
        branch->setIcon(icon4);

        gridLayout->addWidget(branch, 3, 1, 1, 1);


        retranslateUi(StashManager);

        QMetaObject::connectSlotsByName(StashManager);
    } // setupUi

    void retranslateUi(QWidget *StashManager)
    {
#if QT_CONFIG(tooltip)
        drop->setToolTip(tr2i18n("Remove the selected stash", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        drop->setText(tr2i18n("Drop", "@action:button"));
#if QT_CONFIG(tooltip)
        pop->setToolTip(tr2i18n("Apply stash's patch and drop the stash", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        pop->setText(tr2i18n("Pop", "@action:button"));
#if QT_CONFIG(tooltip)
        show->setToolTip(tr2i18n("Show the content of the stash", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        show->setText(tr2i18n("Show", "@action:button"));
#if QT_CONFIG(tooltip)
        apply->setToolTip(tr2i18n("Apply stash's patch", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        apply->setText(tr2i18n("Apply", "@action:button"));
#if QT_CONFIG(tooltip)
        branch->setToolTip(tr2i18n("Create a new branch and apply the stash there, then drop the stash", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        branch->setText(tr2i18n("Branch", "@action:button"));
        (void)StashManager;
    } // retranslateUi

};

namespace Ui {
    class StashManager: public Ui_StashManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // STASHMANAGERDIALOG_H

