// THIS FILE IS GENERATED BY kdev-pg-qt 2.4.0
// WARNING! All changes made in this file will be lost!

#ifndef QMAKE_DEFAULT_VISITOR_H_INCLUDED
#define QMAKE_DEFAULT_VISITOR_H_INCLUDED

#include "qmakevisitor.h"

namespace QMake
{

class  DefaultVisitor: public Visitor
{
public:
    void visitArgumentList(ArgumentListAst *node) override;
    void visitElseBody(ElseBodyAst *node) override;
    void visitFunctionArguments(FunctionArgumentsAst *node) override;
    void visitIfElse(IfElseAst *node) override;
    void visitItem(ItemAst *node) override;
    void visitOp(OpAst *node) override;
    void visitOrOperator(OrOperatorAst *node) override;
    void visitProject(ProjectAst *node) override;
    void visitScope(ScopeAst *node) override;
    void visitScopeBody(ScopeBodyAst *node) override;
    void visitStatement(StatementAst *node) override;
    void visitValue(ValueAst *node) override;
    void visitValueList(ValueListAst *node) override;
    void visitVariableAssignment(VariableAssignmentAst *node) override;
};

} // end of namespace QMake

#endif

