/********************************************************************************
** Form generated from reading UI file 'localpatchwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LOCALPATCHWIDGET_H
#define UI_LOCALPATCHWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KUrlRequester"

QT_BEGIN_NAMESPACE

class Ui_LocalPatchWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *localPatchOptions;
    QFormLayout *formLayout;
    QLabel *label;
    KUrlRequester *baseDir;
    QTabWidget *tabWidget;
    QWidget *fileTab;
    QVBoxLayout *verticalLayout_2;
    KUrlRequester *filename;
    QWidget *commandTab;
    QHBoxLayout *horizontalLayout;
    QLineEdit *command;
    QCheckBox *applied;

    void setupUi(QWidget *LocalPatchWidget)
    {
        if (LocalPatchWidget->objectName().isEmpty())
            LocalPatchWidget->setObjectName("LocalPatchWidget");
        LocalPatchWidget->resize(400, 300);
        verticalLayout = new QVBoxLayout(LocalPatchWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        localPatchOptions = new QGroupBox(LocalPatchWidget);
        localPatchOptions->setObjectName("localPatchOptions");
        formLayout = new QFormLayout(localPatchOptions);
        formLayout->setObjectName("formLayout");
        formLayout->setFieldGrowthPolicy(QFormLayout::ExpandingFieldsGrow);
        label = new QLabel(localPatchOptions);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        baseDir = new KUrlRequester(localPatchOptions);
        baseDir->setObjectName("baseDir");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, baseDir);

        tabWidget = new QTabWidget(localPatchOptions);
        tabWidget->setObjectName("tabWidget");
        fileTab = new QWidget();
        fileTab->setObjectName("fileTab");
        verticalLayout_2 = new QVBoxLayout(fileTab);
        verticalLayout_2->setObjectName("verticalLayout_2");
        filename = new KUrlRequester(fileTab);
        filename->setObjectName("filename");

        verticalLayout_2->addWidget(filename);

        tabWidget->addTab(fileTab, QString());
        commandTab = new QWidget();
        commandTab->setObjectName("commandTab");
        horizontalLayout = new QHBoxLayout(commandTab);
        horizontalLayout->setObjectName("horizontalLayout");
        command = new QLineEdit(commandTab);
        command->setObjectName("command");

        horizontalLayout->addWidget(command);

        tabWidget->addTab(commandTab, QString());

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, tabWidget);

        applied = new QCheckBox(localPatchOptions);
        applied->setObjectName("applied");
        applied->setChecked(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, applied);


        verticalLayout->addWidget(localPatchOptions);


        retranslateUi(LocalPatchWidget);

        tabWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(LocalPatchWidget);
    } // setupUi

    void retranslateUi(QWidget *LocalPatchWidget)
    {
        localPatchOptions->setTitle(tr2i18n("Patch", "@title:group"));
        label->setText(tr2i18n("Base directory:", "@label:textbox"));
        baseDir->setPlaceholderText(tr2i18n("/path/to/patch/base", "@info:placeholder"));
        filename->setPlaceholderText(tr2i18n("/path/to/patch", "@info:placeholder"));
        tabWidget->setTabText(tabWidget->indexOf(fileTab), tr2i18n("From File", "@title:tab"));
        command->setPlaceholderText(tr2i18n("Enter command to take output from...", "@info:placeholder"));
        tabWidget->setTabText(tabWidget->indexOf(commandTab), tr2i18n("From Command", "@title:tab"));
#if QT_CONFIG(tooltip)
        applied->setToolTip(tr2i18n("Patch is already applied on local version", "@info:tooltip"));
#endif // QT_CONFIG(tooltip)
        applied->setText(tr2i18n("Already applied", "@option:check"));
        (void)LocalPatchWidget;
    } // retranslateUi

};

namespace Ui {
    class LocalPatchWidget: public Ui_LocalPatchWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LOCALPATCHWIDGET_H

