/****************************************************************************
** Meta object code from reading C++ file 'gitplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/git/gitplugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'gitplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11StandardJobE_t {};
} // unnamed namespace

template <> constexpr inline auto StandardJob::qt_create_metaobjectdata<qt_meta_tag_ZN11StandardJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "StandardJob",
        "result",
        "",
        "KJob*"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'result'
        QtMocHelpers::SlotData<void(KJob *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<StandardJob, qt_meta_tag_ZN11StandardJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject StandardJob::staticMetaObject = { {
    QMetaObject::SuperData::link<KDevelop::VcsJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11StandardJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11StandardJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11StandardJobE_t>.metaTypes,
    nullptr
} };

void StandardJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<StandardJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->result((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *StandardJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *StandardJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11StandardJobE_t>.strings))
        return static_cast<void*>(this);
    return KDevelop::VcsJob::qt_metacast(_clname);
}

int StandardJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDevelop::VcsJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN9GitPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto GitPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN9GitPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GitPlugin",
        "repositoryBranchChanged",
        "",
        "QUrl",
        "repository",
        "parseGitBlameOutput",
        "KDevelop::DVcsJob*",
        "job",
        "parseGitLogOutput",
        "parseGitDiffOutput",
        "parseGitRepoLocationOutput",
        "parseGitStatusOutput",
        "parseGitStatusOutput_old",
        "parseGitVersionOutput",
        "parseGitBranchOutput",
        "parseGitCurrentBranch",
        "parseGitStashList",
        "KDevelop::VcsJob*",
        "ctxRebase",
        "ctxPushStash",
        "ctxPopStash",
        "ctxStashManager",
        "fileChanged",
        "file",
        "delayedBranchChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'repositoryBranchChanged'
        QtMocHelpers::SignalData<void(const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'parseGitBlameOutput'
        QtMocHelpers::SlotData<void(KDevelop::DVcsJob *)>(5, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'parseGitLogOutput'
        QtMocHelpers::SlotData<void(KDevelop::DVcsJob *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'parseGitDiffOutput'
        QtMocHelpers::SlotData<void(KDevelop::DVcsJob *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'parseGitRepoLocationOutput'
        QtMocHelpers::SlotData<void(KDevelop::DVcsJob *)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'parseGitStatusOutput'
        QtMocHelpers::SlotData<void(KDevelop::DVcsJob *)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'parseGitStatusOutput_old'
        QtMocHelpers::SlotData<void(KDevelop::DVcsJob *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'parseGitVersionOutput'
        QtMocHelpers::SlotData<void(KDevelop::DVcsJob *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'parseGitBranchOutput'
        QtMocHelpers::SlotData<void(KDevelop::DVcsJob *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'parseGitCurrentBranch'
        QtMocHelpers::SlotData<void(KDevelop::DVcsJob *)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'parseGitStashList'
        QtMocHelpers::SlotData<void(KDevelop::VcsJob *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 17, 7 },
        }}),
        // Slot 'ctxRebase'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'ctxPushStash'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'ctxPopStash'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'ctxStashManager'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fileChanged'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'delayedBranchChanged'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GitPlugin, qt_meta_tag_ZN9GitPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GitPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<KDevelop::DistributedVersionControlPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9GitPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9GitPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9GitPluginE_t>.metaTypes,
    nullptr
} };

void GitPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GitPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->repositoryBranchChanged((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 1: _t->parseGitBlameOutput((*reinterpret_cast<std::add_pointer_t<KDevelop::DVcsJob*>>(_a[1]))); break;
        case 2: _t->parseGitLogOutput((*reinterpret_cast<std::add_pointer_t<KDevelop::DVcsJob*>>(_a[1]))); break;
        case 3: _t->parseGitDiffOutput((*reinterpret_cast<std::add_pointer_t<KDevelop::DVcsJob*>>(_a[1]))); break;
        case 4: _t->parseGitRepoLocationOutput((*reinterpret_cast<std::add_pointer_t<KDevelop::DVcsJob*>>(_a[1]))); break;
        case 5: _t->parseGitStatusOutput((*reinterpret_cast<std::add_pointer_t<KDevelop::DVcsJob*>>(_a[1]))); break;
        case 6: _t->parseGitStatusOutput_old((*reinterpret_cast<std::add_pointer_t<KDevelop::DVcsJob*>>(_a[1]))); break;
        case 7: _t->parseGitVersionOutput((*reinterpret_cast<std::add_pointer_t<KDevelop::DVcsJob*>>(_a[1]))); break;
        case 8: _t->parseGitBranchOutput((*reinterpret_cast<std::add_pointer_t<KDevelop::DVcsJob*>>(_a[1]))); break;
        case 9: _t->parseGitCurrentBranch((*reinterpret_cast<std::add_pointer_t<KDevelop::DVcsJob*>>(_a[1]))); break;
        case 10: _t->parseGitStashList((*reinterpret_cast<std::add_pointer_t<KDevelop::VcsJob*>>(_a[1]))); break;
        case 11: _t->ctxRebase(); break;
        case 12: _t->ctxPushStash(); break;
        case 13: _t->ctxPopStash(); break;
        case 14: _t->ctxStashManager(); break;
        case 15: _t->fileChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->delayedBranchChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::VcsJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GitPlugin::*)(const QUrl & )>(_a, &GitPlugin::repositoryBranchChanged, 0))
            return;
    }
}

const QMetaObject *GitPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GitPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9GitPluginE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KDevelop::IContentAwareVersionControl"))
        return static_cast< KDevelop::IContentAwareVersionControl*>(this);
    if (!strcmp(_clname, "org.kdevelop.IBasicVersionControl"))
        return static_cast< KDevelop::IBasicVersionControl*>(this);
    if (!strcmp(_clname, "org.kdevelop.IDistributedVersionControl"))
        return static_cast< KDevelop::IDistributedVersionControl*>(this);
    if (!strcmp(_clname, "org.kdevelop.IContentAwareVersionControl"))
        return static_cast< KDevelop::IContentAwareVersionControl*>(this);
    return KDevelop::DistributedVersionControlPlugin::qt_metacast(_clname);
}

int GitPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDevelop::DistributedVersionControlPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void GitPlugin::repositoryBranchChanged(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
