/****************************************************************************
** Meta object code from reading C++ file 'sourceformattercontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/kdevplatform/shell/sourceformattercontroller.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sourceformattercontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KDevelop25SourceFormatterControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto KDevelop::SourceFormatterController::qt_create_metaobjectdata<qt_meta_tag_ZN8KDevelop25SourceFormatterControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KDevelop::SourceFormatterController",
        "formatterLoaded",
        "",
        "KDevelop::ISourceFormatter*",
        "ifmt",
        "formatterUnloading",
        "updateFormatTextAction",
        "beautifySource",
        "beautifyLine",
        "formatFiles",
        "documentLoaded",
        "QPointer<KDevelop::TextDocument>",
        "doc",
        "pluginLoaded",
        "KDevelop::IPlugin*",
        "plugin",
        "unloadingPlugin"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'formatterLoaded'
        QtMocHelpers::SignalData<void(KDevelop::ISourceFormatter *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'formatterUnloading'
        QtMocHelpers::SignalData<void(KDevelop::ISourceFormatter *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'updateFormatTextAction'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'beautifySource'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'beautifyLine'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'formatFiles'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'documentLoaded'
        QtMocHelpers::SlotData<void(const QPointer<KDevelop::TextDocument> &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'pluginLoaded'
        QtMocHelpers::SlotData<void(KDevelop::IPlugin *)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'unloadingPlugin'
        QtMocHelpers::SlotData<void(KDevelop::IPlugin *)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SourceFormatterController, qt_meta_tag_ZN8KDevelop25SourceFormatterControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KDevelop::SourceFormatterController::staticMetaObject = { {
    QMetaObject::SuperData::link<ISourceFormatterController::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop25SourceFormatterControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop25SourceFormatterControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KDevelop25SourceFormatterControllerE_t>.metaTypes,
    nullptr
} };

void KDevelop::SourceFormatterController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SourceFormatterController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->formatterLoaded((*reinterpret_cast<std::add_pointer_t<KDevelop::ISourceFormatter*>>(_a[1]))); break;
        case 1: _t->formatterUnloading((*reinterpret_cast<std::add_pointer_t<KDevelop::ISourceFormatter*>>(_a[1]))); break;
        case 2: _t->updateFormatTextAction(); break;
        case 3: _t->beautifySource(); break;
        case 4: _t->beautifyLine(); break;
        case 5: _t->formatFiles(); break;
        case 6: _t->documentLoaded((*reinterpret_cast<std::add_pointer_t<QPointer<KDevelop::TextDocument>>>(_a[1]))); break;
        case 7: _t->pluginLoaded((*reinterpret_cast<std::add_pointer_t<KDevelop::IPlugin*>>(_a[1]))); break;
        case 8: _t->unloadingPlugin((*reinterpret_cast<std::add_pointer_t<KDevelop::IPlugin*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SourceFormatterController::*)(KDevelop::ISourceFormatter * )>(_a, &SourceFormatterController::formatterLoaded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SourceFormatterController::*)(KDevelop::ISourceFormatter * )>(_a, &SourceFormatterController::formatterUnloading, 1))
            return;
    }
}

const QMetaObject *KDevelop::SourceFormatterController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KDevelop::SourceFormatterController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KDevelop25SourceFormatterControllerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "KXMLGUIClient"))
        return static_cast< KXMLGUIClient*>(this);
    return ISourceFormatterController::qt_metacast(_clname);
}

int KDevelop::SourceFormatterController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ISourceFormatterController::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KDevelop::SourceFormatterController::formatterLoaded(KDevelop::ISourceFormatter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KDevelop::SourceFormatterController::formatterUnloading(KDevelop::ISourceFormatter * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
