/********************************************************************************
** Form generated from reading UI file 'batchedit.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BATCHEDIT_H
#define UI_BATCHEDIT_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_BatchEdit
{
public:
    QVBoxLayout *verticalLayout;
    QPlainTextEdit *textEdit;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *BatchEdit)
    {
        if (BatchEdit->objectName().isEmpty())
            BatchEdit->setObjectName("BatchEdit");
        BatchEdit->resize(600, 400);
        verticalLayout = new QVBoxLayout(BatchEdit);
        verticalLayout->setObjectName("verticalLayout");
        textEdit = new QPlainTextEdit(BatchEdit);
        textEdit->setObjectName("textEdit");

        verticalLayout->addWidget(textEdit);

        buttonBox = new QDialogButtonBox(BatchEdit);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(BatchEdit);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, BatchEdit, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, BatchEdit, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(BatchEdit);
    } // setupUi

    void retranslateUi(QDialog *BatchEdit)
    {
        (void)BatchEdit;
    } // retranslateUi

};

namespace Ui {
    class BatchEdit: public Ui_BatchEdit {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BATCHEDIT_H

