// This file is generated by kconfig_compiler_kf6 from projectconfig.kcfg.
// All changes you do to this file will be lost.
#ifndef SOURCEFORMATTER_PROJECTCONFIG_H
#define SOURCEFORMATTER_PROJECTCONFIG_H

#include <qglobal.h>
#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

namespace SourceFormatter {

class ProjectConfig : public KConfigSkeleton
{
  public:

    ProjectConfig( );
    ~ProjectConfig() override;

    /**
      Get UseDefault
    */
    bool useDefault() const
    {
      return mUseDefault;
    }

    /**
      Is UseDefault Immutable
    */
    bool isUseDefaultImmutable() const
    {
      return isImmutable( QStringLiteral( "useDefault" ) );
    }

    /**
      Get ModelinesEnabled
    */
    bool modelinesEnabled() const
    {
      return mModelinesEnabled;
    }

    /**
      Is ModelinesEnabled Immutable
    */
    bool isModelinesEnabledImmutable() const
    {
      return isImmutable( QStringLiteral( "modelinesEnabled" ) );
    }

    /**
      Get OverrideKateIndentation
    */
    bool overrideKateIndentation() const
    {
      return mOverrideKateIndentation;
    }

    /**
      Is OverrideKateIndentation Immutable
    */
    bool isOverrideKateIndentationImmutable() const
    {
      return isImmutable( QStringLiteral( "overrideKateIndentation" ) );
    }

  protected:

    // SourceFormatter
    bool mUseDefault;
    bool mModelinesEnabled;
    bool mOverrideKateIndentation;
};

}

#endif

