/********************************************************************************
** Form generated from reading UI file 'projectfiltersettings.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTFILTERSETTINGS_H
#define UI_PROJECTFILTERSETTINGS_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KMessageWidget"

QT_BEGIN_NAMESPACE

class Ui_ProjectFilterSettings
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QTreeView *filters;
    QVBoxLayout *verticalLayout;
    QPushButton *add;
    QPushButton *remove;
    QPushButton *moveUp;
    QPushButton *moveDown;
    QSpacerItem *verticalSpacer;
    KMessageWidget *messageWidget;

    void setupUi(QWidget *ProjectFilterSettings)
    {
        if (ProjectFilterSettings->objectName().isEmpty())
            ProjectFilterSettings->setObjectName("ProjectFilterSettings");
        ProjectFilterSettings->resize(696, 400);
        verticalLayout_2 = new QVBoxLayout(ProjectFilterSettings);
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label = new QLabel(ProjectFilterSettings);
        label->setObjectName("label");

        verticalLayout_2->addWidget(label);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        filters = new QTreeView(ProjectFilterSettings);
        filters->setObjectName("filters");

        horizontalLayout->addWidget(filters);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        add = new QPushButton(ProjectFilterSettings);
        add->setObjectName("add");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        add->setIcon(icon);

        verticalLayout->addWidget(add);

        remove = new QPushButton(ProjectFilterSettings);
        remove->setObjectName("remove");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        remove->setIcon(icon1);

        verticalLayout->addWidget(remove);

        moveUp = new QPushButton(ProjectFilterSettings);
        moveUp->setObjectName("moveUp");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("arrow-up")));
        moveUp->setIcon(icon2);

        verticalLayout->addWidget(moveUp);

        moveDown = new QPushButton(ProjectFilterSettings);
        moveDown->setObjectName("moveDown");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("arrow-down")));
        moveDown->setIcon(icon3);

        verticalLayout->addWidget(moveDown);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        horizontalLayout->addLayout(verticalLayout);


        verticalLayout_2->addLayout(horizontalLayout);

        messageWidget = new KMessageWidget(ProjectFilterSettings);
        messageWidget->setObjectName("messageWidget");

        verticalLayout_2->addWidget(messageWidget);


        retranslateUi(ProjectFilterSettings);

        add->setDefault(true);


        QMetaObject::connectSlotsByName(ProjectFilterSettings);
    } // setupUi

    void retranslateUi(QWidget *ProjectFilterSettings)
    {
        label->setText(tr2i18n("Configure which files and folders inside the project folder should be included or excluded:", nullptr));
        add->setText(tr2i18n("Add", "@action:button"));
        remove->setText(tr2i18n("Remove", "@action:button"));
        moveUp->setText(tr2i18n("Move Up", "@action:button"));
        moveDown->setText(tr2i18n("Move Down", "@action:button"));
        (void)ProjectFilterSettings;
    } // retranslateUi

};

namespace Ui {
    class ProjectFilterSettings: public Ui_ProjectFilterSettings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROJECTFILTERSETTINGS_H

