/********************************************************************************
** Form generated from reading UI file 'custombuildsystemconfigwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMBUILDSYSTEMCONFIGWIDGET_H
#define UI_CUSTOMBUILDSYSTEMCONFIGWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "configwidget.h"

QT_BEGIN_NAMESPACE

class Ui_CustomBuildSystemConfigWidget
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *currentConfig;
    QPushButton *addConfig;
    QPushButton *removeConfig;
    QFrame *line;
    ConfigWidget *configWidget;

    void setupUi(QWidget *CustomBuildSystemConfigWidget)
    {
        if (CustomBuildSystemConfigWidget->objectName().isEmpty())
            CustomBuildSystemConfigWidget->setObjectName("CustomBuildSystemConfigWidget");
        CustomBuildSystemConfigWidget->resize(648, 508);
        verticalLayout = new QVBoxLayout(CustomBuildSystemConfigWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(CustomBuildSystemConfigWidget);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        currentConfig = new QComboBox(CustomBuildSystemConfigWidget);
        currentConfig->setObjectName("currentConfig");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(currentConfig->sizePolicy().hasHeightForWidth());
        currentConfig->setSizePolicy(sizePolicy);
        currentConfig->setEditable(true);
        currentConfig->setInsertPolicy(QComboBox::NoInsert);

        horizontalLayout->addWidget(currentConfig);

        addConfig = new QPushButton(CustomBuildSystemConfigWidget);
        addConfig->setObjectName("addConfig");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        addConfig->setIcon(icon);

        horizontalLayout->addWidget(addConfig);

        removeConfig = new QPushButton(CustomBuildSystemConfigWidget);
        removeConfig->setObjectName("removeConfig");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        removeConfig->setIcon(icon1);

        horizontalLayout->addWidget(removeConfig);


        verticalLayout->addLayout(horizontalLayout);

        line = new QFrame(CustomBuildSystemConfigWidget);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        configWidget = new ConfigWidget(CustomBuildSystemConfigWidget);
        configWidget->setObjectName("configWidget");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(configWidget->sizePolicy().hasHeightForWidth());
        configWidget->setSizePolicy(sizePolicy1);

        verticalLayout->addWidget(configWidget);


        retranslateUi(CustomBuildSystemConfigWidget);

        QMetaObject::connectSlotsByName(CustomBuildSystemConfigWidget);
    } // setupUi

    void retranslateUi(QWidget *CustomBuildSystemConfigWidget)
    {
        label->setText(tr2i18n("Build configuration:", "@label:listbox"));
        addConfig->setText(tr2i18n("Add", "@action:button"));
        removeConfig->setText(tr2i18n("Remove", "@action:button"));
        (void)CustomBuildSystemConfigWidget;
    } // retranslateUi

};

namespace Ui {
    class CustomBuildSystemConfigWidget: public Ui_CustomBuildSystemConfigWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUSTOMBUILDSYSTEMCONFIGWIDGET_H

