/****************************************************************************
** Meta object code from reading C++ file 'problemreporterplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kdevelop-26.07.90/plugins/problemreporter/problemreporterplugin.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'problemreporterplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21ProblemReporterPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto ProblemReporterPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN21ProblemReporterPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProblemReporterPlugin",
        "updateReady",
        "",
        "KDevelop::IndexedString",
        "url",
        "KDevelop::ReferencedTopDUContext",
        "updateHighlight",
        "documentClosed",
        "KDevelop::IDocument*",
        "textDocumentCreated",
        "document",
        "documentUrlChanged",
        "QUrl",
        "previousUrl",
        "documentActivated",
        "showModel",
        "id"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'updateReady'
        QtMocHelpers::SlotData<void(const KDevelop::IndexedString &, const KDevelop::ReferencedTopDUContext &)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 2 },
        }}),
        // Slot 'updateHighlight'
        QtMocHelpers::SlotData<void(const KDevelop::IndexedString &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'documentClosed'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 2 },
        }}),
        // Slot 'textDocumentCreated'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 10 },
        }}),
        // Slot 'documentUrlChanged'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *, const QUrl &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 10 }, { 0x80000000 | 12, 13 },
        }}),
        // Slot 'documentActivated'
        QtMocHelpers::SlotData<void(KDevelop::IDocument *)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 10 },
        }}),
        // Slot 'showModel'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProblemReporterPlugin, qt_meta_tag_ZN21ProblemReporterPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProblemReporterPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<KDevelop::IPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ProblemReporterPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ProblemReporterPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ProblemReporterPluginE_t>.metaTypes,
    nullptr
} };

void ProblemReporterPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProblemReporterPlugin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateReady((*reinterpret_cast<std::add_pointer_t<KDevelop::IndexedString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KDevelop::ReferencedTopDUContext>>(_a[2]))); break;
        case 1: _t->updateHighlight((*reinterpret_cast<std::add_pointer_t<KDevelop::IndexedString>>(_a[1]))); break;
        case 2: _t->documentClosed((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 3: _t->textDocumentCreated((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 4: _t->documentUrlChanged((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 5: _t->documentActivated((*reinterpret_cast<std::add_pointer_t<KDevelop::IDocument*>>(_a[1]))); break;
        case 6: _t->showModel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IndexedString >(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::ReferencedTopDUContext >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KDevelop::IndexedString >(); break;
            }
            break;
        }
    }
}

const QMetaObject *ProblemReporterPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProblemReporterPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ProblemReporterPluginE_t>.strings))
        return static_cast<void*>(this);
    return KDevelop::IPlugin::qt_metacast(_clname);
}

int ProblemReporterPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KDevelop::IPlugin::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
