// THIS FILE IS GENERATED BY kdev-pg-qt 2.4.0
// WARNING! All changes made in this file will be lost!

#ifndef QMAKE_VISITOR_H_INCLUDED
#define QMAKE_VISITOR_H_INCLUDED

#include "qmakeast.h"

namespace QMake
{

class  Visitor
{
public:
    virtual ~Visitor() {}
    virtual void visitNode(AstNode *node);
    virtual void visitArgumentList(ArgumentListAst *) {}
    virtual void visitElseBody(ElseBodyAst *) {}
    virtual void visitFunctionArguments(FunctionArgumentsAst *) {}
    virtual void visitIfElse(IfElseAst *) {}
    virtual void visitItem(ItemAst *) {}
    virtual void visitOp(OpAst *) {}
    virtual void visitOrOperator(OrOperatorAst *) {}
    virtual void visitProject(ProjectAst *) {}
    virtual void visitScope(ScopeAst *) {}
    virtual void visitScopeBody(ScopeBodyAst *) {}
    virtual void visitStatement(StatementAst *) {}
    virtual void visitValue(ValueAst *) {}
    virtual void visitValueList(ValueListAst *) {}
    virtual void visitVariableAssignment(VariableAssignmentAst *) {}
};

} // end of namespace QMake

#endif

